<?php
/**
 * LazyestAdmin
 * 
 * This class contains all functions and actions required for Lazyest Gallery to work in the admin of WordPress
 * Thanks to:
 * Denis Howlett <feedback@isocra.com> // WWW: http://www.isocra.com/ for Table drag and Drop
 * Stuart Langridge, http://www.kryogenix.org/days/2007/04/07/sorttable-v2-making-your-tables-even-more-sortable for Table Sorting script
 * 
 * @package Lazyest Gallery
 * @author Marcel Brinkkemper
 * @copyright 2010
 * @access public
 * @since 0.16.0
 * 
 */
class LazyestAdmin extends LazyestGallery {
  
  var $plugin_basename;
  
  /**
   * LazyestAdmin::LazyestAdmin()
   * 
   * @return void
   */
  function LazyestAdmin() {
    $this->__construct();
  }
  
  /**
   * LazyestAdmin::__construct()
   * 
   * @return void
   */
  function __construct() {
    LazyestGallery::__construct();
    add_action( 'admin_menu', array( &$this, 'add_pages' ) );   
    add_action( 'admin_init', array( &$this, 'register_settings' ) );
    add_action( 'admin_init', array( &$this, 'register_scripts' ) );
    add_action( 'admin_head', array( &$this, 'styles' ) );     
    add_filter( 'admin_footer', array( &$this, 'write_quicktag' ) );  
  }
  
  /**
   * LazyestAdmin::lg_gallery_add_pages()
   * 
   * @return void
   */
  function add_pages() {    
   	if ( current_user_can ( 'manage_options' ) && function_exists ( 'add_options_page' ) ) {
      $menu_page_hookname = add_options_page( __('Lazyest Gallery Settings'), 'Lazyest Gallery', 'manage_options', 'lazyest-gallery', array( &$this , 'admin_page' ) );
    }
    if ( current_user_can( 'manage_lazyest_files' ) ) {
      $filemanager_page_hookname = add_menu_page( __('Lazyest Gallery'), __('Lazyest Gallery'), 'manage_lazyest_files', 'lazyest-filemanager', array( &$this , 'filemanager_page' ) );
      $theme_page_hookname = add_submenu_page('lazyest-filemanager', __('Themes'), __('Themes'), 'manage_lazyest_files', 'lazyest-themesmanager', array( &$this, 'themes_page') );        
      add_action( "admin_print_scripts-{$filemanager_page_hookname}", array( &$this,  'admin_js' ) );      
			add_filter ( "plugin_action_links-{$this->plugin_basename}", array( &$this, 'filter_plugin_actions' ) );
    }
  }
  
  /**
	 * LazyestAdmin::register_settings()
	 * 
	 * @return void
	 */
	function register_settings () {
		register_setting( 'lazyest-gallery' , 'lazyest-gallery' , array( &$this , 'update' ) );
	}
  
  /**
   * LazyestAdmin::register_scripts()
   * 
   * @return void
   */
  function register_scripts() {
      wp_register_script( 'lg_tablednd', $this->plugin_url . '/js/lazyest-tablednd.js', array(), LG_VERSION );
      wp_register_script( 'lg_sorttable', $this->plugin_url . '/js/lazyest-sorttable.js', array(), LG_VERSION, true );
  }
  
  
  
  /**
   * LazyestAdmin::update()
   * 
   * @param mixed $options
   * @return
   */
  function update( $options ) {
    global $wp_roles;
		if ( isset ( $options['delete'] ) && $options['delete'] == 'true' ) {
			delete_option ( 'lazyest-gallery' );
		} else if ( isset ( $options['default'] ) && $options['default'] == 'true' ) {
			return $this->defaults ();
		} else {		  
		  if ( isset( $options['gallery_folder'] ) ) {
		    $options['gallery_folder'] = trailingslashit( $options['gallery_folder'] );
		  }
      if ( isset( $options['gallery_prev'] ) ) {
		    $options['gallery_prev'] = trailingslashit( $options['gallery_prev'] );
		  }      
      if ( isset( $options['thumb_folder'] ) ) {
        $options['thumb_folder'] = trailingslashit( $options['thumb_folder'] );
      } 
      if ( isset( $options['slide_folder'] ) ) {
        $options['slide_folder'] = trailingslashit( $options['slide_folder'] );
      }       if ( !isset( $options['enable_cache'] ) ) {        
        $this->clear_cache( 'thumbs' );
      }           
		  if ( !isset( $options['enable_cache'] ) && isset( $options['use_cropping'] ) ) {
		    unset( $options['use_cropping'] );
		  }
      if ( !isset( $options[ 'enable_slides_cache' ] ) ) {
        $this->clear_cache( 'slides' ); 
      }
      if ( isset( $options['use_cropping'] ) ) {
        $options['enable_cache'] = 'TRUE';
      }
      if ( isset( $options['enable_slide_show'] ) ) {
        $options['enable_slides_cache'] = 'TRUE';
      }
      if( isset( $options['excluded_folders_string'] ) ) {
		    $excludefolder = 	explode( ',', $options['excluded_folders_string'] );
		    if( isset( $options['thumb_folder'] ) ) {
          $thumbfolder = untrailingslashit( $options['thumb_folder'] );
		    }
        $thumbfolder_found = false;
    		for ( $i=0; $i < sizeof( $excludefolder ); $i++ ) {
    			$excludefolder[$i] = untrailingslashit( $excludefolder[$i] );
			    if ( $excludefolder[$i] == $thumbfolder ) {
		        $thumbfolder_found = true;
			    }				      
		    }
		    if( !$thumbfolder_found ) {
          $excludefolder[]= $thumbfolder;
        }
		    $options['excluded_folders'] = $excludefolder;
        unset( $options['excluded_folders_string'] );
      }   
      
      // roles that can manage lazyest files
      foreach( $wp_roles->role_names as $role => $name ) { // clean up capabilities from wordpress roles
    		$name = translate_with_context( $name );
    		$arole = $wp_roles->get_role( $role );		
    		if ( $arole->has_cap( 'manage_lazyest_files' ) ) {
    		  $arole->remove_cap( 'manage_lazyest_files' );
    		}
      }    
    	$roles = array();
    	$keys = array_keys( $options );
    	foreach ( $keys as $key ) {
    		$is_role = strpos( $key, 'manager_roles_' );
    		if ( ( false !== $is_role ) ) {
    		  $arole = substr( $key, 14 );
          $roles[] = $arole;
    		}
    	} 
    	$options['manager_roles'] = $roles; 
      
      if ( $roles ) { // reinvoke roles
        foreach ( $roles as $role ) {
            $manager = $wp_roles->get_role( $role );
            $manager->add_cap( 'manage_lazyest_files' );
        }
      }    
      	  
			unset ( $options['delete'] , $options['default'], $options['update_options'] );  
			return $options;
		}
	}
  
  /**
   * LazyestAdmin::styles()
   * 
   * @return void
   */
  function styles() {
    echo "<link rel=\"stylesheet\" href=\"$this->plugin_url/css/_admin.css\" type=\"text/css\" />\n";
  }
  
  
  function write_quicktag() {
    
  }
  
  /**
   * LazyestAdmin::admin_js()
   * 
   * @return void
   */
  function admin_js() {
    if ( function_exists( 'wp_enqueue_script' ) ) {
      wp_enqueue_script( 'lg_tablednd' );
      wp_enqueue_script( 'lg_sorttable' );
    }   
  }
  
  /**
   * LazyestAdmin::filter_plugin_actions()
   * 
   * @param mixed $links
   * @return
   */
  function filter_plugin_actions ( $links ) { 
		$settings_link = '<a href="admin.php?page=lazyest-gallery">' . __( 'Settings' , $this->textdomain ) . '</a>'; 
		array_unshift ( $links, $settings_link ); 
		return $links;
	}
    
  /**
   * LazyestAdmin::create_gallery_folder()
   * 
   * @param string $foldername
   * @return void
   */
  function create_gallery_folder( $foldername ) {   
    $newpath = ABSPATH . $foldername;
    $directory_made = lg_make_directory( $newpath );
    $message = ( $directory_made ) ? __('Folder created successfully', $this->text_domain) : __( 'Lazyest Gallery cannot create folder: maybe it already exists or have bad permissions', $this->text_domain );
    $this->options_message( $mesage, $directory_made ); 
  }
  
  /**
   * LazyestAdmin::new_gallery_folder()
   * 
   * @param string $foldername
   * @return void
   */
  function new_gallery_folder( $foldername ) {
    if ( '' != $foldername ) {
      $sanitized_name = preg_replace('/[^0-9a-z\.\_\-\(\)\$ ]/i','',$folder_name);
			if ( $sanitized_name == $folder_name ) {
				$new_folder_path = $this->root . $foldername;
        $success = $this->make_directory( $new_folder_path ); 
				$message = ( $success ) ?  __( 'Folder created successfully', $this->text_domain ) : __( 'Lazyest Gallery cannot create folder: maybe it already exists or have bad permissions', $this->text_domain ) ;				 
			} else {
        $success = false;
				$message = __( 'Lazyest Gallery cannot use this foldername. Please do not use characters \\ / : * ? &amp; " &lt; &gt; | % ', $this->text_domain );
			}
		} else {
		  $success = false;
			$message = __( 'Lazyest Gallery cannot create a folder with no name.', $this->text_domain);
		}
    $this->options_message( $message, $success );     
  }
  
  /**
   * LazyestAdmin::insert_shortcode()
   * 
   * @param mixed $page_id
   * @return void
   */
  function insert_shortcode( $page_id ) {
    global $lg_gallery;
    $apage = get_page( $page_id );
    $apage->post_content .= '[lg_gallery]';
    wp_update_post( $apage );
    $lg_gallery->update_option( 'gallery_id', $page_id );
    $gallery_prev = ( strlen( $permalink ) != 0 ) ? get_option( 'siteurl' ) . '/' . get_page_uri( $page_ID ) . '/' : get_option( 'siteurl' ) . "?page_id=" . $page_ID;
    $lg_gallery->update_option( 'gallery_prev', $gallery_prev );
  }
  
  function filemanager_page() {
    if ( !current_user_can( 'manage_lazyest_files' ) ) {      
      wp_die( __('You do not have permission to manage the gallery.', $this->text_domain ) );
    }
   	if ( isset($_GET['edit'] ) ) {
  		$edit = $_GET['edit'];
  		switch ( $edit ) {
  			case 'comments' :
  				$this->commentor->edit_comments_form();
  				break;
  		}
		  return;
    }    
    $folderdir = stripslashes( rawurldecode( $_GET['folder'] ) );
    if ( '' == $folderdir ) {
      if ( $_GET['delete_folder'] ) {        
        $this->delete_folder();
      }
      $this->manage();
      return;
    }  
    include_once( $this->plugin_dir . '/inc/manager.php' ); 
    $folder = new LazyestAdminFolder( $folderdir );    
    if ( $folder->valid() ) {
      if ( isset( $_GET['upload'] ) && isset( $_POST['upload_folder'] ) && $folder->can_save() ) {
        $folder->uploadfiles();
      }
      if( isset( $_POST['update_folder'] ) || isset( $_POST['update_folder-s'] ) ) { 
        $folder->save_edits();
      }
      if ( isset( $_POST['sort_gallery_structure'] ) || isset( $_POST['sort_gallery_structure-s'] ) ) {
		    $folder->sort_subfolders();		
      }
      if ( isset( $_GET['file_to_delete'] ) ) {
        $folder->delete_file();
      }
      if ( isset(  $_GET['delete_folder'] ) ) {
        $folder->delete_folder();
      }   
      if ( isset( $_POST['create_new_folder'] ) ) {
        $foldername = $folder->curdir . $_POST['new_folder_name'];
        $this->new_gallery_folder( $foldername );
        if ( '/' == $folder->curdir ) $this->manage();
      }
      $folder->manage();   
    } else {
      wp_die( __( 'Lazyest Gallery cannot open folder ', $this->text_domain ) . $_GET[ 'folder' ] ); 
    }
  }
  
  /**
   * LazyestAdmin::manage()
   * 
   * @return void
   */
  function manage() { 
    if ( isset( $_POST['sort_gallery_structure'] ) || isset( $_POST['sort_gallery_structure-s'] ) ) {
		  $this->sort_subfolders();		
    }
  	$folders = $this->folders( 'root', 'hidden' );                 
 		$page_id = $this->get_option( 'gallery_id' );
  	$page = get_page( $page_id );    
    $post = $page;
	  setup_postdata( $page );
 		$parts = explode( ' ', $page->post_date );
  	$parts = explode( '-', $parts[0] );
  	$page_date = mktime( 0,0,0, (int) $parts[1], (int) $parts[2], (int) $parts[0] );  
		$total_count = 0;
    $can_save = true;
		for ( $i = 0; $i != count( $folders ); $i++ ) {
		  $folder = $folders[$i];
			$total_count += $folder->count( 'subfolders' );
      if ( !$folder->can_save() ) {
        $can_save = false;
      }
		}
		if ( 'TRUE' == $this->get_option( 'allow_comments' ) ) { 
		  $comment_count = $this->commentor->count_comments( -1 );
    } else {
      $comment_count = $page->comment_count;
    }
    
		$edit_link = get_edit_post_link( $page->ID );
    $title = esc_html( $page->post_title );
    $sortit = ( 'MANUAL' == $this->get_option( 'sort_alphabetically' ) ) && $can_save;
  	if ( 0 != count( $folders ) ) {
      ?>
        <div class="wrap">
          <div id="icon-upload" class="icon32"><br /></div>
          <h2><?php _e( 'Edit Lazyest Gallery Structure', $this->text_domain ); ?></h2>
          <div class="tablenav"></div>
          <br class="clear" />
          <table class="widefat">
            <thead>
              <tr>
                <th scope="col" id="title" class="manage-column column-title" style=""><?php _e( 'Title' ); ?></th>
                <th scope="col" id="author" class="manage-column column-author" style=""><?php _e( 'Author' ); ?></th>
                <th scope="col" id="date" class="manage-column column-date" style=""><?php _e( 'Date' ); ?></th>                
                <th scope="col" id="comments" class="manage-column column-comments num" style=""><div class="vers"><img alt="" src="images/comment-grey-bubble.png" /></div></th>
                <th scope="col" id="images" class="manage-column num"><?php _e( 'Images', $this->text_domain ); ?></th>
              </tr>
            </thead>
            <tbody>
              <tr>
                <td class="post-title page-title column-title"><strong><?php if ( current_user_can( 'edit_page', $page->ID ) && $post->post_status != 'trash' ) { ?><a class="row-title" href="<?php echo $edit_link; ?>" title="<?php echo esc_attr( sprintf( __( 'Edit &#8220;%s&#8221;' ), $title) ); ?>"><?php echo $title ?></a><?php } else { echo $title; }; ?></strong></td>
                <td class="author column-author"><a href="edit-pages.php?author=<?php the_author_meta('ID'); ?>"><?php the_author() ?></a></td>
                <td><?php echo date( get_option( 'date_format' ), $page_date ); ?></td>
                <td class="num"><div class="post-com-count-wrapper"><a class="post-com-count" href="admin.php?page=lazyest-filemanager&amp;edit=comments&amp;file="><span class="comment-count"><?php echo $comment_count ?></span></a></div></td>
                <td class="num"><strong><?php echo $total_count; ?></strong></td>
              </tr>
            </tbody>
          </table>
          <br />
          <form name="sort_gallery_form" method="post" id="sort_gallery_form" action="admin.php?page=lazyest-filemanager">
          <?php if ( function_exists('wp_nonce_field') ) wp_nonce_field('lg_sort_gallery_structure');  ?>
            <div class="tablenav">
              <?php if ( $sortit ) { ?>
              <input class="button-primary" type="submit" value="<?php _e( 'Save Gallery Order', $this->text_domain ); ?>" name="sort_gallery_structure" />
              <?php } ?>
            </div>
            <table class="widefat<?php if ( $sortit ) echo ' sortable'; ?>" id="sort_gallery">
              <thead>
                <tr>
                  <th scope="col" style="cursor:default" class="manage-column" title="<?php if ( $sortit ) _e( 'Click to Sort', $this->text_domain); ?>"><?php _e( 'Name', $this->text_domain ); ?></th>
                  <th scope="col" style="cursor:default" class="manage-colum" title="<?php if ( $sortit ) _e( 'Click to Sort', $this->text_domain); ?>"><?php _e( 'Caption', $this->text_domain ); ?></th>
                  <th scope="col" style="cursor:default" class="manage-column" title="<?php if ( $sortit ) _e( 'Click to Sort', $this->text_domain); ?>"><?php _e( 'Date',  $this->text_domain ); ?></th>
                  <th scope="col" class="sorttable_nosort" class="manage-column"><?php _e( 'Hidden', $this->text_domain ); ?></th>
        <?php                
    		if ( 'TRUE' == $this->get_option( 'allow_comments' ) ) {
  		  ?>
                  <th scope="col" class="num" title="<?php if ( $sortit ) _e( 'Click to Sort', $this->text_domain); ?>"><div class="vers"><img alt="<?php _e( 'Comments', $this->text_domain ); ?>" src="images/comment-grey-bubble.png"/></div></th>
        <?php 
    		}
        ?>
    		          <th scope="col" class="num" title="<?php if ( $sortit ) _e( 'Click to Sort', $this->text_domain); ?>"><?php _e( 'Images', $this->text_domain ); ?></th>
                </tr>
              </thead>
              <tbody id="folder_list" class="list:gal">
                
        <?php
        for ( $i = 0; $i != count( $folders ); $i++ ) { 
    		  $folder = $folders[$i];
    		  ?>
                <tr title="<?php if ( $sortit ) _e( 'Drag and Drop to Rearrange', $this->text_domain); ?>">
                  <td class="lg_foldercell" sorttable_customkey="<?php echo strtolower( $folder->form_name() ); ?>">  
                    <a title="<?php echo __( 'Edit', $this->text_domain ) . ' &quot;'. $folder->dirname() . '&quot;'; ?>" class="row-title" href="admin.php?page=lazyest-filemanager&amp;folder=<?php echo lg_nice_link( $folder->curdir ); ?>"><?php echo $folder->dirname(); ?></a>
                    <input type="hidden" name="index_<?php echo $folder->form_name() ?>" value="<?php echo $folder->order ?>" />                  
          <?php 
            $folder->list_folders( 'hidden', 'dirname', 'admin' );
          ?>      
                  </td>
                  <td sorttable_customkey="<?php echo esc_attr( strtolower( $folder->title() ) ); ?>">
                    <?php echo $folder->title(); ?>
                  </td>
                  <td class="date column-date" sorttable_customkey="<?php echo $folder->datetime; ?>">
                    <?php echo date( get_option( 'date_format' ), $folder->datetime ); ?>
                  </td>
                  <td class="check-column">
                    <input type="checkbox" name="visible_<?php echo $folder->form_name(); ?>" value="hidden" <?php checked( 'hidden',  $folder->visibility  ); ?> />
                  </td>
          <?php                 
    			if ( 'TRUE' == $this->get_option( 'allow_comments' ) ) { 
    				$comment_count = $this->commentor->count_comments( $folder->id );
            ?>
    				      <td class="num"><div class="post-com-count-wrapper"><a class="post-com-count" href="admin.php?page=lazyest-filemanager&amp;edit=comments&amp;file=<?php echo lg_nice_link( $folder->curdir ) ?>"><span class="comment-count"><?php echo $comment_count; ?></span></a></div></td>
            <?php
    			}
          $count = $folder->count();
          $subcount = $folder->count( 'subfolders' ) - $count;
          ?>
  		            <td class="num"><?php echo $count; if ( $subcount > 0 ) echo '<br />(' . $subcount . __( ' in subfolders', $lg_gallery->text_domain ) . ')'; ?></td>
                </tr>
        <?php              
    		}
        ?>
    		      </tbody>	
    		    </table>
        <?php if ( 7 < count( $folders ) ) { ?>
            <div class="tablenav">
              <input class="button-primary" name="sort_gallery_structure-s" type="submit" value="<?php _e( 'Save Gallery Order', $this->text_domain ); ?>" />
            </div>		
		    <?php } ?> 
          </form>
      
      <?php
  		if ( ( 'MANUAL' == $this->get_option( 'sort_alphabetically' ) ) && $can_save ) {
  		?>  
  			<script type="text/javascript">
          var sort_gallery = document.getElementById('sort_gallery');
          var structureDnD = new TableDnD();
          structureDnD.init(sort_gallery);
        </script>
      <?php      
      }
      ?>          
          <div class="tablenav"></div><br class="clear" />
        </div>
    <?php    
  	}	else {
 	  ?>
  		  <div class="wrap">
          <div class="tablenav"><br class="clear" /></div>
          <p><br /><?php _e( 'Could not find any image folders in your Gallery.', $this->text_domain ); ?><br />
          <?php _e( 'Please create a New Folder below', $this->text_domain ); ?></p>
          <div class="tablenav"><br class="clear" /></div>
        </div><br class="clear" />
    <?php        
  	}
    if ( $can_save ) {
      $this->add_folder();
    } 
  }
  
  function add_folder() {
    ?>
  	   <div class="wrap">
        <br class="clear" />
        <h2><?php _e( 'New Folder', $this->text_domain ); ?></h2>
        <form name="new_folder" id="new_folder" method="post" action="admin.php?page=lazyest-filemanager&amp;folder=/">
    <?php	if ( function_exists( 'wp_nonce_field' ) ) wp_nonce_field( 'lg_add_folder' ); ?>
          <table class="form-table">
            <tbody>
              <tr class="form-field form-required">
                <th scope="row" valign="top"><label for="new_folder_name"><?php _e( 'Folder Name', $this->text_domain ); ?></label></th>
                <td>
                  <input type="text" name="new_folder_name" id="new_folder_name" style="width:90%" /><br />
                  <input type="submit" style="width:128px" class="button" name="create_new_folder" value="<?php _e( 'New Folder', $this->text_domain ); ?>" />
                </td>
              </tr>
            </tbody>
          </table>
        </form>
      </div>
      <br class="clear" />
    <?php
  }
  
  /**
   * LazyestAdmin::themes_page()
   * 
   * @return void
   */
  function themes_page() {   
    if ( !current_user_can( 'edit_themes' ) ) {      
      wp_die( __( 'You do not have permission to change themes.', $this->text_domain ) );
    }
    $stylesheet =  $this->get_option( 'style_css' );
    if ( '' != $stylesheet ) {
      $style = '/css/' . $stylesheet;
    } else {
      $style = '/css/lazyest-style.css';
    }
    $style_file = $this->plugin_dir . $style;
    $handle = @fopen($style_file, 'r');
    if ( $handle ) {
    	$content = @fread( $handle, filesize( $style_file ) );
      @fclose( $handle );
      if ( $content ) {
        $content = htmlspecialchars($content);
        $success = true;
        $updated = false;
        if ( isset( $_POST['action'] ) ) {
          $success = $updated = false;
    		  $newcontent = stripslashes( $_POST['newcontent'] );
    		  if ( is_writeable( $style_file ) ) {
    			 $handle = @fopen( $style_file, 'w+' );
            if ( $handle ) {
      			 fwrite( $handle, $newcontent );
      			 fclose( $handle );
              $success = $updated = true;
            }
    		  }
    		  $content = htmlspecialchars( $newcontent );
          $message = ( $success ) ? __( 'File edited successfully', $this->text_domain ) : __( 'Error saving file', $this->text_domain );
        }
      }
    } else {
      $success = false;
      $message = __( 'Lazyest Gallery cannot open Stylesheet');
    }
    
    ?>
  	<div class="wrap">
      <div id="icon-themes" class="icon32"></div>
      <?php
      $title = ( is_writeable( $style_file) ) ? __( 'Edit Lazyest Gallery Stylesheet', $this->text_domain ) :__('Browse Lazyest Gallery Stylesheet', $this->text_domain ); 		
  		?>
      <h2><?php echo $title; ?></h2>
  		<?php if ( $updated || !$success )$this->options_message( $message, $success ); ?>  		
  		<div class="tablenav">
  			<div class="alignleft">
  				<p><big><strong><?php echo __('Stylesheet ' ); ?></strong>(<?php echo $this->get_option( 'style_css' );?>)</big></p>
  			</div>
  			<br class="clear" />
  		</div>
  		<br class="clear" />  		
  		<div class="templateside">
  		<form name="template" id="template" method="post" action="">
  				<textarea cols="80" rows="25" name="newcontent" id="newcontent" class="codepress css"><?php echo $content ?></textarea>
  				<input type="hidden" name="action" value="update" />
 			<?php if (is_writeable( $style_file ) ) { ?>
  				<p class="submit">
				    <input class="button-primary" type="submit" name="submit" value="<?php _e( 'Update File', $this->text_domain ); ?>" />
  				</p>
  			<?php } else { ?>
  				<p><em><?php _e( 'If this file were writable you could edit it.', $this->text_domain ); ?></em></p>
  			<?php } ?>
  		</form>
  		</div>
  	</div>
    <?php
  }
  
  function wizard_form() {
  	if ( isset( $_POST['update_wizard_options'])){
  		$user_ok = false;
  		$passwd_ok = false;
      $message = '';
  
  		if ( isset( $_POST['wizard_username'] ) && ( 0 != strlen( $_POST['wizard_username'] ) ) ) {
  			$this->update_option('wizard_user', $_POST['wizard_username'] );
  			$user_ok = true;
  		} else {
  		  $message = __( 'You have to provide a username!', $this->text_domain );
  		}
  
  		if ( isset( $_POST['wizard_password'] ) && ( 0 != strlen( $_POST['wizard_password'] ) ) ){
  			$this->update_option( 'wizard_password', base64_encode( $_POST['wizard_password'] ) );
  			$passwd_ok = true;
  		} else {
  		  $message .=  __( ' You have to provide a password!', $this->text_domain );		
  		}
  
      $success = $passwd_ok && $user_ok;
      if ( $success ) {
        $this->update_option( 'enable_mwp_support', TRUE );
      }
      $message = ( $success ) ? __( 'Wizard Settings successfully edited', $this->text_domain ) : $message;
      $this->options_message( $message, $success );
		}
    ?>
  	<div class="wrap">  
  	<fieldset class="options">
  			<h2><?php _e('Microsoft Publisher Wizard Options', $lg_text_domain) ?></h2>
  
  			<?php if ( ( 'test' == $this->get_option( 'wizard_user' ) ) || ( 'secret' == $this->get_option( 'wizard_password' ) ) ) { ?>
  			<div id="message" class='error fade'> //TODO:start here
  				<b><?php _e('It is highly recomended to change your Username and Password!', $lg_text_domain); ?></b>
  				<p><?php _e('Default Username and Passwords are:', $lg_text_domain); ?></p>
  					<ul>
  						<li><?php _e('Username:', $this->text_domain); ?> <code>test</code></li>
  						<li><?php _e('Password:', $this->text_domain); ?> <code>secret</code></li>
  					</ul>
  			</div>
  		<?php } ?>
  
  		<form action=""  method="post" enctype="multipart/form-data">
  			<table summary="wizard">
  				<tr>
  					<th><label for="wizard_username"><?php _e('Username:', $this->text_domain); ?></label></th><td><input type="text" name="wizard_username" id="wizard_username" value="<?php echo $this->get_option('wizard_user'); ?>"  size="25" class="code" /></td>
  				</tr>
  				<tr>
  					<th><label for="wizard_password"><?php _e('Password:', $this->text_domain); ?></label></th><td><input type="password" name="wizard_password" id="wizard_password" value="<?php echo $this->get_option('wizard_password'); ?>"  size="25" class="code" /></td>
  				</tr>
  				<tr>
  					<td style="vertical-align:middle"><?php _e('Download Registry File:', $this->text_domain); ?> &raquo;</td>
  					<td style="text-align:center;">
  						<a href="<?php echo $this->plugin_url; ?>/lazyest-wizard.php?step=reg">
  							<img src="<?php echo $this->plugin_url; ?>/images/reg.jpg" alt="Windows Registry File" />
  						</a>
  					</td>
  				</tr>
  			</table>
  			<input class="button" type="submit" name="update_wizard_options" value="<?php	_e( 'Update options', $this->text_domain)	?>" />
  		</form>
  	</fieldset>
  </div>
  <?php
    
  }
  
  /**
   * LazyestAdmin::admin_page()
   * 
   * @return void
   */   
  function admin_page() {    
    if ( !current_user_can( 'manage_options' ) ) {      
      wp_die( __( 'You do not have permission to change these settings.', $this->text_domain ) );
    }
    global $wp_roles;  
    if( isset( $_GET['edit_css'] ) ){
      $this-build_editcss_form();
    } else if ( isset( $_GET['xp_wiz'] ) ) {
        $this->wizard_form();  
    }	else {
      if ( isset( $_GET['lg_create_folder'] ) ) {
        $this->create_gallery_folder( $_GET['create_folder'] );  
      } 
      if ( isset( $_GET['insert_shortcode'] ) ) {
        $this->insert_shortcode( $_GET['insert_shortcode'] );  
      }
      if ( isset( $_GET['reset_options'] ) ) {
        $this->defaults();
        $this->store_options();
      }
      if ( isset( $_GET['clear_cache'] ) ) {
        $this->admin_clear_cache();
      }
      if ( isset( $_GET['replete_cache'] ) ) {
        $this->admin_replete_cache();
      }      
      ?>
      <script type="text/javascript">
      <!--           
      function lg_page_change() {
        var theID = document.getElementById('gallery_id').value;
        if ( theID != '-1' ) {   
          document.getElementById('gallery_prev').setAttribute('value', pageURLs[theID]);
          document.getElementById('gallery_prev_p').innerHTML = pageURLs[theID];
          if ( pageCodes[theID] ) {
            document.getElementById('lg_insertcode').style.display="none";
          } else {
            document.getElementById('lg_insertcode').style.display="block";
            document.getElementById('a_insert_shortcode').setAttribute('href','admin.php?page=lazyest-gallery&insert_shortcode='+theID);
          }
        } else {
          if ( window.confirm( "<?php _e('Are you sure you want to close this page?\n\nThe Changes you made will be lost if you navigate away from this page.\n\nClick OK to continue or Cancel to stay on the current page. '); ?>" ) )
            window.location="<?php echo get_option('siteurl') ?>/wp-admin/page-new.php";
        }
      }   
      
      function lg_random_change() {
        var theIcon = document.getElementById('folder_image').value;
        if ( theIcon == 'random_image' ) {
          document.getElementById( 'random_subfolder_div').style.display="block";
        } else {          
          document.getElementById( 'random_subfolder_div').style.display="none";
        }
      }         
      -->
      </script> 
      <div class="wrap">
      	<form method="post" action="options.php">      
  				<?php settings_fields( 'lazyest-gallery' ); ?>
      		<?php if ( function_exists( 'wp_nonce_field ') ) wp_nonce_field( 'lazyestgallery_options' ); ?>
      		<div id="icon-options-general" class="icon32"><br /></div><h2>Lazyest Gallery <?php _e( 'Settings' ); ?></h2>             
            <!-- Main Gallery Options -->
            <div id="lg_main_options">
              <div class="versions">
                <span id="lg-version-message"><?php echo __( 'You are using '); ?></span><strong><?php echo 'Lazyest Gallery ' . LG_VERSION; ?></strong>
              </div>
            <?php if ( $this->get_option('new_install ') == 'TRUE' ) { ?>
            <h1><?php _e( 'Welcome to Lazyest Gallery', $this->text_domain ); ?></h1>
            <h2><?php _e( 'This is the first time you use Lazyest Gallery', $this->text_domain ); ?></h2>
            <div class="update fade"><?php _e( 'Before you can enjoy all the features of Lazyest Gallery,', $this->text_domain ); ?><br /><?php _e( 'please enter the folder where you store your images, and your blog page where you show your Gallery', $this->text_domain ); ?></div>
            <?php } ?>
              <h3><?php _e('Main Gallery Options', $this->text_domain) ?></h3>
              
              <table id="lg_main_options_table" class="form-table">
                <tbody>
                <tr>
                  <th><label for="gallery_folder"><?php _e( 'Your Gallery Folder', $this->text_domain ); ?></label></th>
                  <td>
                    <?php
                      $lg_gallery_folder = $this->get_option( 'gallery_folder' );												
                    ?>
                    <input name="lazyest-gallery[gallery_folder]" id="gallery_folder" value="<?php echo $lg_gallery_folder ?>" size="60" class="code" type="text" /> <br />
                    <?php
                              if ( !( file_exists( ABSPATH . $this->get_option( 'gallery_folder' ) ) ) ) {
                    ?>
                              <div>
                                <b style='color:#ff0000;'>WARNING</b>: The specified gallery folder does not exists:
                                <code><?php _e( $this->get_option( 'gallery_folder' ), $this->text_domain ); ?></code><br />
                                <a href="options.php?page=lazyest-gallery&amp;create_folder=<?php echo $this->get_option( 'gallery_folder' ) ?>">
                                Let Lazyest Gallery create this folder for me</a>
                              </div>
                    <?php
                            }
                    ?>
                  </td>
                </tr>
                <tr>
                  <th><label for="gallery_id"><?php _e( 'Your Gallery Page', $this->text_domain ); ?></label></th>
                  
                  <td>                  
                    <?php
                    $pages = get_pages();
                    if ( 0 == count( $pages ) ) {                    
                      echo '<a href="' . get_option('siteurl'). '/wp-admin/page-new.php' . '">' . __( 'Your blog has no pages yet, please create a page for your gallery', $this->text_domain ) . '</a>';  
                    } else {
                      ?>
                      <select class="postform" name="lazyest-gallery[gallery_id]" id="gallery_id" onchange="lg_page_change()" >
                      <?php
                      $pages = get_pages();
                      if ( 0 < count( $pages ) )  {
                        foreach( $pages as $apage ) {
                          echo '<option value="' . $apage->ID . '"';
                          if ( $apage->ID == $this->get_option( 'gallery_id' ) ) {
                            echo 'selected="selected"';
                          }
                          echo '>' . $apage->post_title . '</option>';
                        }
                      } 
                      if ( ( 0 < count( $pages ) ) || ( $this->get_option( 'new_install' ) == 'TRUE' ) ) { 
                        echo '<option value="-1">' . __( 'Create a New Page', $this->text_domain ) . '</option>';
                      }
                      ?>                    
                      </select> <br />
                      <script type="text/javascript">
                      pageURLs = new Array();                  
                      pageCodes = new Array();
                      <?php
                      if ( 0 < count( $pages ) )  {
                        foreach( $pages as $apage ) {
                          echo "pageURLs['" . $apage->ID . "']='" . trailingslashit( get_page_link( $apage->ID ) ) . "';\n";
                          echo "pageCodes['" .$apage->ID . "']=";                       
                          $is_gallery = strpos( $apage->post_content, '[lg_gallery]' );
                          $str = ( false !== $is_gallery ) ? 'true' : 'false';
                          echo "$str;\n";
                        }
                      }
                      ?>
                      </script>
                      <?php                                         
                      $page_id = $this->get_option( 'gallery_id' );
                      if ( '' != $page_id ) {                      
                        $apage = get_page( $page_id );
                        if ( !$apage || ( 'publish' != $apage->post_status ) ) { // page should be published
                          $page_id = '';
                        }
                      }                     
                      if ( '' == $page_id ) { // page id is not set, just pick first in line
                        $apage = $pages[0];
                        $page_id = $apage->ID;
                        $this->change_option( 'gallery_prev', trailingslashit( get_page_link( $apage->ID ) ) );                        
                      } 
                      _e( 'The exact address where your main gallery is browsable:', $this->text_domain ); ?> 
                      <p id="gallery_prev_p"><?php echo $this->get_option( 'gallery_prev' ); ?></p>
                      <?php
                      $apage_id =  $this->get_option( 'gallery_id' );                                                           
                      $apage = get_page( $apage_id );                  
                      $is_gallery = strpos( $apage->post_content, '[lg_gallery]' ); 
                      $astyle = ( $is_gallery === false ) ? 'display:block' : 'display:none';                 
                      ?>
                      <div id="lg_insertcode" style="<?php echo $astyle; ?>">
                      <p><strong style='color:#ff0000;'><?php _e( 'WARNING', $lg_text_domain ); ?></strong>: <?php echo __( 'The Lazyest Gallery shortcode ', $lg_text_domain) . '<code>[lg_gallery]</code>' . __( 'cannot be found on this page.', $lg_text_domain) ;?></p>
                      <a id="a_insert_shortcode" href="admin.php?page=lazyest-gallery&amp;insert_shortcode=<?php echo $apage->ID ?>">Let Lazyest Gallery insert the shortcode for me</a>
                      </div>    
                      <input type="hidden" id="gallery_prev" value="<?php echo $this->get_option( 'gallery_prev' ); ?>" />
                      <?php
                    }
                    ?> 
                  </td>
                </tr>
                </tbody>
              </table>
            </div>
            <div id="lginstalled" <?php if( 'TRUE' == $this->get_option( 'new_install' ) || ( 0 == count( $pages ) ) ) { echo 'style="visibility:hidden; display:none"';} ?> >
              <!-- Thumbnail View Options -->
              <div id="lg_thumbnail_options">
                <h3><?php _e( 'Thumbnail View Options' , $this->text_domain ) ?></h3>
                <table id="lg_thumbnail_options_table" class="form-table">
                  <tbody>
                  <tr>
                    <th><label for="thumbwidth"><?php _e( 'Maximum Thumbnail Width' , $this->text_domain ) ?></label></th>
                    <td><input name="lazyest-gallery[thumbwidth]" id="thumbwidth" value="<?php echo $this->get_option( 'thumbwidth' ); ?>" size="10" class="code" type="text" /> pixels</td>
                  </tr>
                  <tr>
                    <th><label for="thumbheight"><?php _e( 'Maximum Thumbnail Height', $this->text_domain ) ?></label></th>
                    <td><input name="lazyest-gallery[thumbheight]" id="thumbheight" value="<?php echo $this->get_option( 'thumbheight' ); ?>" size="10" class="code" type="text" /> pixels</td>
                  </tr>								
                  <tr>
                    <th><label for="thumbspage"><?php _e( 'Thumbnails per Page', $this->text_domain ) ?></label></th>
                    <td><input name="lazyest-gallery[thumbs_page]" id="thumbs_page" value="<?php echo $this->get_option( 'thumbs_page' ); ?>" size="5" class="code" type="text" /><br />
                    <?php _e( 'Set to 0 to disable pagination.', $this->text_domain ) ?>
                    </td>
                  </tr>
                   <tr>
                    <th><label for="folderspage"><?php _e( 'Folders per Page', $this->text_domain ) ?></label></th>
                    <td><input name="lazyest-gallery[folders_page]" id="folders_page" value="<?php echo $this->get_option( 'folders_page' ); ?>" size="5" class="code" type="text" /><br />
                    <?php _e( 'Set to 0 to disable pagination.', $this->text_domain ) ?>
                    </td>
                  </tr>
                  <tr>
                    <th><label for="count_subfolders"><?php _e( 'Count Images', $this->text_domain); ?></label></th>
                    <td>
                      <select name="lazyest-gallery[count_subfolders]">
                        <option value="none" <?php selected( 'none', $this->get_option( 'count_subfolders' ) ) ?>><?php _e( 'Show number of images in folder only', $this->text_domain ) ?></option> 
                        <option value="include" <?php selected( 'include', $this->get_option( 'count_subfolders' ) ) ?>><?php _e( 'Show number of images in folder including subfolders', $this->text_domain ) ?></option>                           
                        <option value="separate" <?php selected( 'separate', $this->get_option( 'count_subfolders' ) ) ?>><?php _e( 'Show number of images in folder and subfolders separately', $this->text_domain ) ?></option>
                      </select>
                    </td>
                  </tr>
                  <tr>
                    <th><label for="sort_alphabetically"><?php _e( 'Sort Files and Folders by', $this->text_domain ) ?></label></th>
                      <td>
                        <select name="lazyest-gallery[sort_alphabetically]">
                          <option value="TRUE" <?php selected( 'TRUE' , $this->get_option( 'sort_alphabetically' ) ); ?>><?php _e('Name', $this->text_domain ) ?></option>                        
                          <option value="FALSE" <?php selected( 'FALSE' , $this->get_option( 'sort_alphabetically' ) ); ?>><?php _e('Date', $this->text_domain ) ?></option>                    
                          <option value="MANUAL" <?php selected( 'MANUAL' , $this->get_option( 'sort_alphabetically' ) ); ?>><?php _e('Manually', $this->text_domain ) ?></option>                        
                        </select>                     
                      </td>
                  </tr>
                  <tr>
                    <th><label for="folders_columns"><?php _e( 'Folder Columns', $this->text_domain ) ?></label></th>
                    <td><input name="lazyest-gallery[folders_columns]" id="folders_columns" value="<?php echo $this->get_option( 'folders_columns' ); ?>" size="5" class="code" type="text" /></td>
                  </tr>
                  <tr>
                    <th><label for="thumbs_columns"><?php _e( 'Thumbnail Columns', $this->text_domain ) ?></label></th>
                    <td><input name="lazyest-gallery[thumbs_columns]" id="thumbs_columns" value="<?php echo $this->get_option( 'thumbs_columns' ); ?>" size="5" class="code" type="text" /></td>
                  </tr>			
                  <tr>
                    <th><label for="folder_image"><?php _e( 'Folder Icons', $this->text_domain ) ?></label></th>
                    <td>
                      <select id="folder_image" name="lazyest-gallery[folder_image]" onchange="lg_random_change()">
                        <option value="icon" <?php selected( 'icon', $this->get_option( 'folder_image') ); ?>><?php _e('Folder icon', $this->text_domain) ?></option>
                        <option value="random_image" <?php selected( 'random_image', $this->get_option( 'folder_image') )?>><?php _e( 'Random image from folder', $this->text_domain ) ?></option>                      
                        <option value="none" <?php selected( 'none', $this->get_option( 'folder_image') ); ?>><?php _e( 'None', $this->text_domain ) ?></option>
                      </select> 
                      <div id="random_subfolder_div"<?php if ( 'random_image' != $this->get_option( 'folder_image' ) ) echo 'style="display:none;"' ?>>
                        <label><input name="lazyest-gallery[random_subfolder]" type="checkbox" value="TRUE" <?php checked( 'TRUE', $this->get_option( 'random_subfolder' ) ); ?> /> <?php _e( 'Include images from sub folders', $this->text_domain ); ?> </label>
                      </div>                  
                    </td>                    
                  </tr>                    
                  <tr>
                    <th><?php _e( 'Caching', $this->text_domain ) ?></th>
                    <td>
                      <label><input type="checkbox" name="lazyest-gallery[enable_cache]" value="TRUE" <?php checked( 'TRUE', $this->get_option( 'enable_cache' ) ); ?> /><?php _e( ' Enable thumbnail caching', $this->text_domain ); ?></label><br />
                      <label><input type="checkbox" name="lazyest-gallery[async_cache]" value="TRUE" <?php checked( 'TRUE', $this->get_option( 'async_cache' ) ); ?> /><?php ?><?php _e ( ' Create cached thumbnails after page has loaded in the browser', $this->text_domain ); ?></label>
                      <?php if( 'TRUE' == $this->get_option( 'use_cropping' ) ) {
                              _e( 'WARNING: Disabling this setting will also disable thumbnail cropping.', $this->text_domain );
                             }
                      ?>                           
                      <br /><label><?php _e( 'Store cached thumbnails in sub folders named: ', $this->text_domain ) ?><input name="lazyest-gallery[thumb_folder]" id="thumb_folder" value="<?php echo $this->get_option('thumb_folder'); ?>" size="25" class="code" type="text" /></label>
                      <br />
                    </td>
                  </tr>
                  <tr>
                    <th><?php _e( 'Cropping', $this->text_domain ) ?></th>
                    <td>
                      <label><input type="checkbox" name="lazyest-gallery[use_cropping]" value="TRUE" <?php checked( 'TRUE', $this->get_option( 'use_cropping' ) ); ?> /><?php _e(' Enable thumbnail cropping', $this->text_domain) ?></label><br />
                      <?php _e( 'Note: This setting will also enable thumbnail caching.', $this->text_domain ) ?>
                    </td>
                  </tr>
                  
                  <tr>
                    <th><?php _e('On Click', $this->text_domain) ?></th>
                    <td>
                      <?php _e('Perform the following action when thumbnails are clicked:', $this->text_domain) ?><br />
                      <select name="lazyest-gallery[on_thumb_click]">                    
                        <option value="nothing" <?php selected( 'nothing', $this->get_option( 'on_thumb_click' ) ); ?>><?php _e( 'Nothing', $this->text_domain ); ?></option>
                        <option value="slide" <?php selected( 'slide', $this->get_option( 'on_thumb_click' ) ); ?>><?php _e( 'Show slide in slide view', $this->text_domain ); ?></option>
                        <option value="lightslide" <?php selected( 'lightslide', $this->get_option( 'on_thumb_click' ) ); ?>><?php _e( 'Show slide in Lightbox', $this->text_domain ); ?></option>
                        <option value="thickslide" <?php selected( 'thickslide', $this->get_option( 'on_thumb_click' ) ); ?>><?php _e( 'Show slide in Thickbox', $this->text_domain ); ?></option>
                        <option value="fullimg" <?php selected( 'fullimg', $this->get_option( 'on_thumb_click' ) ); ?>><?php _e( 'Show full size image', $this->text_domain ); ?></option>                                           
                        <option value="lightbox" <?php selected( 'lightbox', $this->get_option( 'on_thumb_click' ) ); ?>><?php _e( 'Show full size image in Lightbox', $this->text_domain ); ?></option>                                           
                        <option value="thickbox" <?php selected( 'thickbox', $this->get_option( 'on_thumb_click' ) ); ?>><?php _e( 'Show full size image in Thickbox', $this->text_domain ); ?></option>
                      </select>
                      <br />                   
                <?php if ( !$this->some_lightbox_plugin() ) {
                        _e( ' (A supported Lightbox plugin was not detected.)', $this->text_domain ); 
                      } 
                ?>    <br />
                <?php if ( !$this->some_thickbox_plugin() ) { 
                        _e( ' (A supported Thickbox plugin was not detected.)', $this->text_domain ); 
                      } 
                ?>
                      <br />
                    </td>
                  </tr>
                  </tbody>
                </table>
              </div>
        
              <!-- Slide View Options -->
              <div id="lg_slide_options">
                <h3><?php _e( 'Slide View Options', $this->text_domain ) ?></h3>
                <table id="lg_slide_options_table" class="form-table">
                  <tbody>
                  <tr>
                    <th><?php _e( 'Comments', $this->text_domain ) ?></th>
                    <td>
                      <label><input name="lazyest-gallery[allow_comments]" type="checkbox" value="TRUE" <?php checked ( 'TRUE', $this->get_option( 'allow_comments' ) ); ?>  />
                        <?php _e( 'Enable user comments on slides', $this->text_domain );?>
                      </label>
                    </td>
                  </tr>
                  <tr>
                    <th><label for="pictwidth"><?php _e( 'Maximum Slides Width', $this->text_domain ) ?></label></th>
                    <td><input name="lazyest-gallery[pictwidth]" id="pictwidth" value="<?php echo $this->get_option( 'pictwidth' ); ?>" size="10" class="code" type="text" /> pixels</td>
                  </tr>
                  <tr>
                    <th><label for="pictheight"><?php _e( 'Maximum Slides Height', $this->text_domain ) ?></label></th>
                    <td><input name="lazyest-gallery[pictheight]" id="pictheight" value="<?php echo $this->get_option( 'pictheight' ); ?>" size="10" class="code" type="text" /> pixels</td>
                  </tr>
                  
                  <tr>
                    <th><?php _e( 'Caching', $this->text_domain ) ?></th>
                    <td>
                      <label><input type="checkbox" name="lazyest-gallery[enable_slides_cache]" value="TRUE" <?php checked( 'TRUE', $this->get_option( 'enable_slides_cache' ) ); ?> /><?php _e( ' Enable slide caching', $this->text_domain ) ?></label><br />
                      <label><?php _e( 'Store cached slides in sub folders named: ', $this->text_domain ) ?><input name="lazyest-gallery[slide_folder]" id="slide_folder" value="<?php echo $this->get_option( 'slide_folder' ); ?>" size="25" class="code" type="text" /></label> <br />
                    </td>
                  </tr>
                  <tr>
                    <th><?php _e( 'Slide Show', $this->text_domain ) ?></th>
                    <td>
                      <label><input type="checkbox" name="lazyest-gallery[enable_slide_show]" value="TRUE" <?php checked( 'TRUE', $this->get_option( 'enable_slide_show' ) ); ?> /><?php _e( ' Enable Slide Show', $this->text_domain ) ?></label><br />
                      <?php _e( 'Note: This setting will also enable slide caching.', $this->text_domain ) ?><br />
                    </td>
                  </tr>
        
        
                  <tr>
                    <th><?php _e( 'On Click', $this->text_domain ) ?></th>
                    <td>
                      <?php _e( 'Perform the following action when slides are clicked:', $this->text_domain ) ?><br />
                      <select name="lazyest-gallery[on_slide_click]">
                        <option value="nothing" <?php selected( 'nothing', $this->get_option( 'on_slide_click' ) ) ?>><?php _e( 'Nothing', $this->text_domain ) ?></option>
                        <option value="fullimg" <?php selected( 'fullimg', $this->get_option( 'on_slide_click' ) ) ?>><?php _e( 'Show full size image', $this->text_domain ) ?></option>
                        <option value="popup" <?php selected( 'popup', $this->get_option( 'on_slide_click' ) ) ?>><?php _e( ' Show image in pop-up window', $this->text_domain ) ?></option>
                        <option value="lightbox" <?php selected( 'lightbox', $this->get_option( 'on_slide_click' ) ) ?>><?php _e( 'Show image in Lightbox', $this->text_domain ) ?></option>
                        <option value="thickbox" <?php selected( 'thickbox', $this->get_option( 'on_slide_click' ) ) ?>><?php _e( 'Show image in Thickbox', $this->text_domain ) ?></option>
                      </select>
                      <br />
                <?php if ( !$this->some_lightbox_plugin() ) {
                        _e( '(A supported Lightbox plug-in was not detected.)', $this->text_domain ); 
                      } 
                ?>
                      <br />
                <?php if ( !$this->some_thickbox_plugin() ) { 
                        _e( ' (A supported Thickbox plug-in was not detected.)', $this->text_domain ); 
                      } 
                ?>
                      <br />
                    </td>
                  </tr>
                  </tbody>
                </table>
              </div>
              
              <!-- Captions Section -->
              <div id="lg_caption_options">
                <h3><?php _e( 'Caption Options', $this->text_domain ) ?></h3>
                <table id="lg_caption_options_table" class="form-table">
                  <tbody>
                  <tr>
                    <th scope="row" colspan="3" class="th-full">
                      <label>
                        <input type="checkbox" name="lazyest-gallery[enable_captions]" value="TRUE" <?php checked ( 'TRUE', $this->get_option( 'enable_captions' ) ); ?> />
                        <?php _e( 'Use image captions instead of file names', $this->text_domain ) ?>
                      </label>
                    </th>
                  </tr>
                  
                  <tr>
                    <th scope="row" colspan="3" class="th-full">
                      <label>
                        <input type="checkbox" name="lazyest-gallery[use_folder_captions]" value="TRUE" <?php checked( 'TRUE', $this->get_option( 'use_folder_captions' ) ); ?> />
                        <?php _e( 'Use folder captions instead of folder names', $this->text_domain ) ?>
                      </label>
                    </th>
                  </tr>
                  <tr>
                    <th scope="row">
                      <label for="captions_length">                
                        <?php _e( 'Length of Captions in Thumbnail View', $this->text_domain ) ?>                
                      </label>
                    </th>
                    <td>
                    	<input type="text" id="captions_length" name="lazyest-gallery[captions_length]" size="3" value="<?php echo $this->get_option( 'captions_length' ); ?>" /> 
                      <?php _e( 'characters', $this->text_domain ) ?> 
                    </td>
                    <td>
                    	<?php _e( 'Set to -1 to disable captions in thumbnail view.' ); ?><br />
                    	<?php _e( 'Set to  0 to disable cropping of captions text in thumbnail view.' ); ?>
                    </td>
                  </tr>
                  </tbody>
                </table>
                
                <h3><?php _e( 'Exif Data', $this->text_domain ) ?></h3>
                <table id="exif_data" class="form-table" >
                  <tbody>
                  <tr>
                    <th><?php _e( 'Exif Data', $this->text_domain ); ?></th>
                    <td>
                      <label>
                        <input type="checkbox" name="lazyest-gallery[enable_exif]" id="enable_exif" value="TRUE" <?php checked( 'TRUE', $this->get_option( 'enable_exif' ) ); ?> />
                          <?php _e( 'Display image Exif data', $this->text_domain ); ?>                 
                      </label>
                    </td>  
                  </tr>
                  </tbody>
                </table>
              </div>
              
              <!-- Upload Options Section -->
              <div id="lg_upload_options">
                <h3><?php _e( 'Upload Options', $this->text_domain ) ?></h3>
                <p><?php _e( 'These settings only affect the Lazyest Gallery image upload forms, not the standard WordPress uploader.', $this->text_domain ); ?></p>
                <table id="lg_upload_options_table" class="form-table">
                  <tbody>                    
                  <tr>
                    <th><label for="fileupload_allowedtypes"><?php _e( 'Allowed File Extensions', $this->text_domain ) ?></label></th>
                    <td><input name="lazyest-gallery[fileupload_allowedtypes]" type="text" id="fileupload_allowedtypes" value="<?php echo $this->get_option( 'fileupload_allowedtypes' ); ?>" size="40" />
                      <br />
                      <?php _e( 'Recommended: <code>jpg jpeg gif png</code>. Separate extensions by spaces (" ").', $this->text_domain ) ?>
                    </td>
                  </tr>
                  <tr>
                    <th><?php _e( 'Check roles allowed to manage images and folders', $this->text_domain ) ?></th>
                    <td>
                    	<?php $this->check_author_roles()	?>
                    </td>
                  </tr>								
                  <tr>
                    <th><label for="enable_mwp_support"><?php _e( 'Enable Web Publishing Wizard Support', $this->text_domain ) ?></label></th>
                    <td>
                      <input type="checkbox" id="enable_mwp_support" name="lazyest-gallery[enable_mwp_support]" value="TRUE" <?php checked( 'TRUE', $this->get_option('enable_mwp_support') ); ?> /><br />
                      <?php _e( 'Note: This feature is only supported for use with Microsoft Windows XP.', $this->text_domain ) ?>
                    </td>
                  </tr>
                  <?php if ( 'TRUE' == $this->get_option( 'enable_mwp_support' ) ) { ?>
                  <tr id="mwp_support">
                    <th>&nbsp;</th>
                    <td>
                      <div class="submit">
                        <a class="button" href="admin.php?page=lazyest-gallery&amp;xp_wiz" ><?php _e( 'Upload Wizard Settings', $this->text_domain ) ?></a>
                      </div>  
                    </td>
                  </tr> 
                  <?php } ?> 
                  </tbody>
                </table>
              </div>
              
              <!-- Advanced Options Section -->
              <div id="lg_advanced_options">
                <h3><?php _e( 'Advanced Options', $this->text_domain ) ?></h3>
                <table id="lg_advanced_options_table" class="form-table">
                  <tbody>
                  <tr>
                    <th><label for="use_permalinks"><?php _e( 'Use Permalinks for the Gallery', $this->text_domain ) ?></label></th>
                    <td>
                      <input type="checkbox" id="use_permalinks" name="lazyest-gallery[use_permalinks]" value="TRUE" <?php checked( 'TRUE', $this->get_option('use_permalinks') ); ?> /><br />
                      <?php _e( 'Enable this to show Gallery Folders as subpages of your Gallery Page.', $this->text_domain ) ?>
                    </td>
                  </tr>
                  <tr>
                    <th><label for="excluded_folders"><?php _e( 'Excluded Folders', $this->text_domain ) ?></label></th>
                    <td>
                      <input name="lazyest-gallery[excluded_folders_string]" id="excluded_folders_string" value="<?php echo implode( ',', $this->get_option( 'excluded_folders' ) ); ?>" size="60" class="code" type="text" /> <br />
                      <?php _e( 'List folders to exclude from the gallery.  Separate folders with commas (",") while omitting spaces.', $this->text_domain ) ?>
                    </td>
                  </tr>
                  <tr>
                    <th><label for="resample_quality"><?php _e( 'Image Resampling Quality', $this->text_domain ) ?></label></th>
                    <td>
                      <input name="lazyest-gallery[resample_quality]" id="resample_quality" value="<?php echo $this->get_option( 'resample_quality' ); ?>" size="10" class="code" type="text" /><br />
                      <?php _e( 'Valid settings range from 0 (low quality) to 100 (best quality).  This setting only applies to JPEG files.', $this->text_domain ) ?>
                    </td>
                  </tr>
                  <tr>
                    <th><label for="link_to_gallery"><?php _e( 'Shortcode links to Gallery', $this->text_domain ) ?></label></th>
                    <td>
                      <input type="checkbox" id="link_to_gallery" name="lazyest-gallery[link_to_gallery]" value="TRUE" <?php checked( 'TRUE', $this->get_option('link_to_gallery') ); ?> /><br />
                      <?php _e( 'Enable this to jump to the Gallery after a user clicks on an folder shortcode in a post.', $this->text_domain ) ?>
                    </td>
                  </tr>
                  <tr>
                    <th><label for="listed_as"><?php _e( 'The images in the Gallery should be listed as', $this->text_domain ); ?></label></th>
                    <td>
                      <input name="lazyest-gallery[listed_as]" id="listed_as" value="<?php echo $this->get_option( 'listed_as' ) ?>"size="12" type="text" />
                    </td>
                  </tr>
                  <tr>
                    <th><label for="show_credits"><?php _e( 'Credits', $this->text_domain ); ?></label></th>
                    <td>
                      <input type="checkbox" name="lazyest-gallery[show_credits]" id="show_credits" value="TRUE" <?php checked( 'TRUE', $this->get_option( 'show_credits' ) ); ?> /><br />
                      <?php _e( 'Enable this to support Lazyest Gallery by showing the "Powered by Lazyest Gallery" banner below your gallery', $this->text_domain ) ?>
                    </td>
                  </tr>
                  </tbody>
                </table>
              </div>
            </div>  
            <?php if ( 0 < count( $pages ) ) { ?>
      			<div class="submit">
      				<input class="button-primary" type="submit" name="lazyest-gallery[update_options]" value="<?php	_e( 'Save Changes', $this->text_domain )	?>" />
      			</div>
            <div id="utility">
              <h3><?php _e( 'Utility functions', $this->text_domain ) ?></h3>
              <div class="submit">
                <a class="button" href="admin.php?page=lazyest-gallery&amp;reset_options" title="<?php _e( 'Reset all options to their default values.', $this->text_domain ) ?>"><?php _e( 'Reset Options', $this->text_domain ) ?></a>
                <a class="button" href="admin.php?page=lazyest-gallery&amp;clear_cache" title="<?php _e( 'Clear thumbs and slides from your gallery', $this->text_domain ) ?>"><?php _e( 'Clear Cache', $this->text_domain ) ?></a>                 
                <p><br />
                <?php _e('Generate missing Thumbs and Slides', $this->text_domain); ?> <a class="button" href="admin.php?page=lazyest-gallery&amp;replete_cache" title="<?php _e('Create slides and thumbnails for recently added images' , $this->text_domain); ?>"><?php _e('Go', $this->text_domain); ?></a><br />
                <?php _e('If your gallery contains many images, this procedure could take a very long time to complete', $this->text_domain); ?>
              </p>
              </div>
            </div>
            <?php
            }
            unset( $pages );
            ?>
            <input type="hidden" name="lazyest-gallery[wizard_user]" value="<?php echo $this->get_option( 'wizard_user' ) ?>" />
            <input type="hidden" name="lazyest-gallery[wizard_password]" value="<?php echo $this->get_option( 'wizard_password' ) ?>" />
            <input type="hidden" name="lazyest-gallery[image_indexing]" value="<?php echo $this->get_option( 'image_indexing' ) ?>" />
            <input type="hidden" name="lazyest-gallery[gallery_secure]" value="<?php echo $this->get_option( 'gallery_secure') ?>" />
            <input type="hidden" name="lazyest-gallery[style_css]" value="lazyest-style.css" /> <!-- for future enhancement -->        
      	</form>
      </div>
      <?php            
    }   
  }
  
  /**
   * LazyestAdmin::sort_subfolders()
   * 
   * @return void
   */
  function sort_subfolders() {
    $folders = $this->folders( 'root', 'hidden' );
    for ($i = 0; $i != count($folders); $i++) {
      $folder = $folders[$i]; 
  		$folder_id =  $folder->form_name();      
      $folder->order = $_POST['index_' . $folder_id];
  		$folder->visibility = ( isset( $_POST['visible_' . $folder_id] ) ) ? 'hidden' : 'visible';
      $success = $folder->change();
      if ( !$success ) {
        break;
      }
  	}
    $message = ( $success ) ? __( 'Gallery sorted. Continue editing below', $this->text_domain ) : __( 'Lazyest Gallery could not save your folders.', $this->text_domain ); 
    $this->options_message( $message, $success ); 	      
  }
  
  /**
   * LazyestAdmin::delete_folder()
   * 
   * @return void
   */
  function delete_folder() {
    $path = $_GET['delete_folder'];
    $folder = new LazyestFolder( $path );
    $success = $folder->valid();
    if ( $success ) {
      $success = $this->remove_directory( $this->root . $path );
    } 
    $message = ( $success ) ? __( 'Folder deleted successfully', $this->text_domain ) : __( 'Lazyest Gallery could not delete the folder', $this->text_domain ); 
    $this->options_message( $message, $success ); 	      
  }
    
  /**
   * LazyestAdmin::remove_directory()
   * 
   * @param mixed $path
   * @return
   */
  function remove_directory( $path ) {
    if ( !file_exists( $path ) ) {
      return true; // don't attempt to remove a non-existant directory
    }
  	if( $this->clear_directory( $path ) ) {
  		if( rmdir( $path ) ){
  			return true;
  		// directory removed
  		} else {
  			return false;
  		// directory couldn't removed
  		}
  	} else {
  		return false;
  	// no empty directory
  	}
  }
  
  /**
   * LazyestAdmin::clear_directory()
   * 
   * @param mixed $path
   * @return
   */
  function clear_directory( $path ) {
    if ( !file_exists( $path ) ) {
      return true; // don't attempt to remove a non-existant directory
    }  
  	if( $dir_handle = @opendir( $path ) ) {
  		while( $file = readdir( $dir_handle ) ) {
  			if( is_dir( $path . $file ) && $file != "." && $file != ".." ) {				
  				$filevar = substr( $path, strlen( $this->root ) );
  				if ( $this->is_folder( $filevar ) && isset( $this->commentor ) ) { 
  					$this->commentor->remove_comments( $filevar );
  				}
  				$this->clear_directory( trailingslashit( $path .  $file ) );
  				$this->remove_directory( trailingslashit( $path .  $file ) );
  			} else {
  				if($file == "." || $file == "..") {
  					continue;
  				} else {
  					unlink( $path . $file );
  				}
  			}
  		}
  		closedir( $dir_handle );
  		return true;
  	// all files deleted
  	} else {
  		return false;
  	}
  }
  
  /**
   * LazyestAdmin::rename_file()
   * 
   * @param mixed $oldname
   * @param mixed $newname
   * @return
   */
  function rename_file( $oldname, $newname ) {
  	if ( @rename( $oldname, $newname ) ) {
  		return true;
  	} else {
  		return false;
  	}
  }
  
  /**
   * LazyestAdmin::make_directory()
   * 
   * @param mixed $path
   * @return
   */
  function make_directory( $path ) {
  	if ( @mkdir( $path, 0777 ) ) {
  	  $stat = stat( dirname( $path ) );
      $perms = $stat['mode'] & 0000777;
      @chmod( $path, $perms ); 
  		return true;
  	} else {
  		return false;
  	}
  }
  
   
  /**
   * LazyestAdmin::admin_clear_cache()
   * 
   * @return void
   */
  function admin_clear_cache() {
    $cache_cleared = $this->clear_cache( 'all' );
    $message = ( $cache_cleared ) ? __( 'Cache cleared succesfully', $this->text_domain) :  __( 'Lazyest Gallery cannot clear the cache: maybe it does not exist or has bad permissions', $this->text_domain );
    $this->options_message( $message, $cache_cleared );  
  }
  
  /**
   * LazyestAdmin::admin_replete_cache()
   * 
   * @return void
   */
  function admin_replete_cache() {
    $cache_repleted = $this->replete_cache();
    $message = ( $cache_repleted ) ? __('Slides and Thumbs generated succesfully', $this->text_domain) :  __('Lazyest Gallery cannot build the cache: maybe it has bad permissions', $this->text_domain );
    $this->options_message( $message, $cache_repleted );
  }
  
  /**
   * LazyestAdmin::clear_cache()
   * 
   * @param string $what
   * @return
   */
  function clear_cache( $what='all' ) {
  	$folders = $this->folders( 'subfolders', 'hidden');
    $thumbs = $this->get_option( 'thumb_folder' );
    $slides = $this->get_option( 'slide_folder' ); 
    $success = true; 
  	if ( 0 != count( $folders ) ) { 
  	 	for ( $i = 0; $i != count( $folders ); $i++ ) {
        $folder =  $folders[$i];
  	 	  $path = $this->root . $folder->curdir;
        if ( ( 'all' == $what ) || ( 'thumbs' == $what ) ) {
          if ( file_exists( $path . $thumbs ) ) {
            if ( $this->remove_directory( $path . $thumbs ) == false )
              $success =  false;
          }
        }      
        if ( (  'all' == $what ) || ( 'slides' == $what ) ) {
          if ( file_exists( $path . $slides) ) {
            if ( $this->remove_directory( $path . $slides ) == false ) 
              $success = false;
          }
        }  	 	 
   	  }
    }  
    return $success;
  }
  
  /**
   * LazyestAdmin::replete_cache()
   * 
   * @return void
   */
  function replete_cache() {
    $folders = $this->folders( 'subfolders', 'hidden' );
    $success = true;
    if ( 0 != count( $folders ) ) {
      for ( $i = 0; $i != count( $folders ); $i++ ) {
        $folder = $folders[$i];
        $success = $folder->load( 'thumbs' ) && $folder->load( 'slides' );
        unset( $folder );
      }
    }
    return $success;
  }
  
  
  
  /**
   * LazyestAdmin::check_author_roles()
   * 
   * @return void
   */
  function check_author_roles() {
  	global $wp_roles;
  	$p = '';
  	$lg_roles = $this->get_option( 'manager_roles' );
  	if ( !is_array( $lg_roles ) ) $lg_roles = array();
  	foreach( $wp_roles->role_names as $role => $name ) {
  		$name = translate_with_context( $name );
  		$arole = $wp_roles->get_role( $role );		
  		if ( in_array( $role, $lg_roles ) || $arole->has_cap( 'manage_lazyest_files' ) )
  			$p .= "\n\t<label><input type='checkbox' checked='checked' value='$role' name='lazyest-gallery[manager_roles_$role]' /> $name</label><br />";
  		else
  			$p .= "\n\t<label><input type='checkbox' value='$role' name='lazyest-gallery[manager_roles_$role]' /> $name</label><br />";
  	}
  	echo $p;
  }
  
  /**
   * LazyestAdmin::options_message()
   * 
   * @param mixed $message
   * @param bool $success
   * @return void
   */
  function options_message( $message, $success=true ) {
    if ( $success ) {
  	?>  
  	<div id="message" class="updated fade">
  		<p><?php echo $message; ?></p>
  	</div>
  
  	<?php
    } else {
    ?>
    <div id="message" class="error">
      <p><?php echo $message; ?></p>
    </div>
    <?php  
    }
  }
  
  /**
   * LazyestAdmin::some_lightbox_plugin()
   * 
   * @return
   */
  function some_lightbox_plugin() {
  	return (
      ( get_option( 'lightboxplus_options' ) != false ) ||
  		( class_exists( 'jQueryLightbox' ) ) ||
  		( get_option( 'lightbox_2_automate' ) != false ) ||
  		( get_option( 'lightbox_conditionals' ) != false ) ||
  		( get_option( 'shadowbox' ) != false )
  	);
  }
  
  /**
   * LazyestAdmin::some_thickbox_plugin()
   * 
   * @return
   */
  function some_thickbox_plugin() {
  	return (
  		function_exists('ThickBox_init') ||
  		function_exists('add_thickbox_js') ||
      ( get_option('thickbox_variant') != false ) ||
  		( get_option( 'shadowbox' ) != false )
  		);
  }
  
} // LazyestAdmin
?>