<?php
/**
 * LazyestCommentor
 * 
 * @package Lazyest Gallery  
 * @author Marcel Brinkkemper
 * @copyright 2010 Marcel Brinkkemper
 * @since 0.16.0
 * @access public
 */
class LazyestCommentor {
  
  var $tb_comments;
  
  var $comments_from;
  
  /**
   * LazyestCommentor::LazyestCommentor()
   * php 4 wrapper for constructor
   * @return void
   */
  function LazyestCommentor() {
    $this->__construct(); 
  }  
  
  /**
   * LazyestCommentor::__construct()
   * object constructor   * 
   * @return void
   */
  function __construct() { 
    global $wpdb, $lg_gallery;
    $this->tb_comments = $wpdb->prefix . 'lg_comments2image';
    if ( $wpdb->get_var("SHOW TABLES LIKE '$this->tb_comments'") != $this->tb_comments ) {
      $this->init_comments();
    }
    add_action( 'comment_post', array( &$this, 'comment_post' ), 10, 2);
    add_action( 'delete_comment', array( &$this, 'delete_comment' ) );
    add_action( 'init', array( &$this, 'redirect_comment' ) );
    add_action( 'wp_set_comment_status', array( &$this, 'set_comment_status' ), 10, 2 );
    add_filter( 'comments_array', array( &$this, 'comments_array' ) );
    add_filter( 'get_comments_number', array( &$this, 'get_comments_number' ) );
    add_filter( 'get_comment_link', array( &$this, 'get_comment_link' ) );
    if ( !is_admin() ) { 
      add_filter( 'comments_template', array( &$this, 'comments_template' ) );
      add_filter( 'get_comments_pagenum_link', array( &$this, 'comments_pagenum_link') );
    }
  }
  
  /**
   * LazyestCommentor::init_comments()
   * inserts image comments table in wp database
   * resets all image ids to unique values
   * @return void
   */
  function init_comments() {
    global $wpdb, $lg_gallery;
    // create a new comments table;
    if ( $wpdb->get_var("SHOW TABLES LIKE '$this->tb_comments'") != $this->tb_comments ) {
      $sql = "CREATE TABLE " . $this->tb_comments . " (
  			comment_ID bigint(20) NOT NULL default '0',
  			img_ID bigint(20) NOT NULL default '0',
  			comment_approved varchar(20) NOT NULL default 'approve',
  			UNIQUE  KEY  (comment_ID)
  		); ";
      require_once ( ABSPATH . 'wp-admin/includes/upgrade.php' );
      dbDelta( $sql );
    }
    // reset all image ids
  	$image_id = 1;
  	$folders = $lg_gallery->folders( 'subfolders', 'hidden' );
    if ( 0 < count( $folder->list ) ) { 
      foreach( $folders as $folder ) {
        $folder->open();
        $folder->id = $image_id++;
        $folder->load();      
    		foreach ( $folder->list as $image ) {
    			$image->id = $image_id++;
    		}
    		$folder->save();
        unset( $folder->list );
    	}
    }
    unset( $folders );
  	$lg_gallery->update_option( 'image_indexing', $image_id);
  }
  
  /**
   * LazyestCommentor::comment_post()
   * 
   * @param mixed $comment_ID
   * @param mixed $status
   * @return
   */
  function comment_post( $comment_ID, $status ) {
    global $wpdb, $lg_gallery;
  
    $status = (int) $status;
    if ( isset( $_POST['lg_comment_image_ID'] ) ) {
      $commentID = (int) $comment_ID;
      $select = "SELECT * FROM " . $this->tb_comments . " WHERE comment_ID = " . $commentID;
      $query = $wpdb->prepare( $select );
      $result = $wpdb->get_row( $query );
      if ( !$result ) { // comment is not in database yet
        if ( $status == 1 ) {
          $comment_approved = '"approve"';
        } else {
          $comment_approved = '"spam"';
        }
        $imgID = (int) $_POST['lg_comment_image_ID'];
        $insert = "INSERT INTO " . $this->tb_comments . " (comment_ID, img_ID, comment_approved) " . "VALUES (" . $commentID . "," . $imgID .
          "," . $comment_approved . ")";
        $results = $wpdb->query( $insert );
      }
    }
  }
      
  /**
   * LazyestCommentor::delete_comment()
   * 
   * @param mixed $comment_ID
   * @return
   */
  function delete_comment( $comment_ID ) {
    global $wpdb;

    $commentID = (int) $comment_ID;
    $select = "SELECT * FROM $lg_tb_comments WHERE comment_ID = $commentID;";
    $query = $wpdb->prepare( $select );
    $result = $wpdb->get_row( $query );
    if ( count($result) != 0 ) { // comment is in database
      $delete = "DELETE FROM $this->tb_comments WHERE comment_ID = $commentID  LIMIT 1;";
      $query = $wpdb->prepare( $delete );
      $result = $wpdb->get_row( $query );
    }
  }    
  
  /**
   * LazyestCommentor::redirect_comment()
   * 
   * @return
   */
  function redirect_comment() { 
    global $lg_gallery; 
    if ( '' !=  ( $lg_gallery->comment ) ) {
      $comment_ID = $lg_gallery->comment;
      $filevar = $this->get_file_by_comment_id( $comment_ID );
      $redirect = $lg_gallery->address;
      if ( $lg_gallery->is_folder( $filevar ) ) {
        $folder = new LazyestFrontendFolder( $filevar );
        if ( $folder->valid() ) {
          $redirect = $folder->uri();
        }
        unset( $folder );
      }
      if ( $lg_gallery->is_image( $filevar ) ) {
        $folder = new LazyestFrontendFolder( dirname( $filevar ) );
        if ( $folder->valid() ) {
          $image = $folder->single_image( basename( $filevar) );
          $slide = new LazyestSlide( $folder );
          $redirect = $slide->uri();
          unset( $slide );
        }
      }     
      wp_redirect( $redirect );
    }
  }
  
  
  /**
   * LazyestCommentor::set_comment_status()
   * 
   * @param mixed $comment_ID
   * @param mixed $status
   * @return
   */
  function set_comment_status( $comment_ID, $status ) {
    global $wpdb;    
    $commentID = ( int )$comment_ID;
    $update = "UPDATE $this->tb_comments SET comment_approved = \"$status\" WHERE comment_ID = $commentID";
    $query = $wpdb->prepare( $update );
    $wpdb->query( $query );
  }
  
  
  /**
   * LazyestCommentor::comments_array()
   * 
   * @param mixed $comments
   * @return
   */
  function comments_array( $comments ) {
    global $wpdb, $lg_gallery;  
    if ( !is_admin() && $lg_gallery->is_gallery() ) {
      if ( !isset( $lg_gallery->file ) ) $lg_gallery->valid();
      $filevar = $lg_gallery->file;
      if ( $lg_gallery->is_image( $filevar ) || $lg_gallery->is_folder( $filevar ) ) { // get the comments for the folder or the file    
        $img_comments = array();
        if ( $lg_gallery->is_image( $filevar ) ) {
          $folder = new LazyestFolder( dirname( $filevar ) );
          if ( $folder->valid() ) {
            $folder->load();
            $image = $folder->single_image( basename( $filevar ) ); 
            $imgID = (int) $image->id;
          }
          unset( $folder );
        } elseif ( $lg_gallery->is_folder($filevar) ) {
          $folder = new LazyestFolder( $filevar );
          if ( $folder->valid() ) {
            $folder->open();        
            $imgID = (int) $folder->id;
          }
          unset( $folder );
        }
        $select = "SELECT comment_ID FROM " . $this->tb_comments . " WHERE img_ID = " . $imgID;
        $query = $wpdb->prepare( $select );
        $results = $wpdb->get_results( $query, ARRAY_A );
        if ( 0 != count( $results ) ) {
          foreach ( $comments as $comment ) {
            if ( in_array( array( 'comment_ID' => $comment->comment_ID ), $results ) ) {
              $img_comments[] = $comment;
            }
          }
        }
        return $img_comments; // comments on this image
      } else { // het the comments for the gallery root
        $gal_comments = array();
        $select = "SELECT comment_ID FROM " . $this->tb_comments;
        $query = $wpdb->prepare( $select );
        $results = $wpdb->get_results( $query, ARRAY_A );
        if ( 0 != count( $results ) ) {
          foreach ( $comments as $comment ) {
            if ( !in_array( array( 'comment_ID' => $comment->comment_ID ), $results ) ) {
              $gal_comments[] = $comment;
            }
          }
          return $gal_comments; // comments on gallery
        } else {       
          return $comments;
        }
  
      }
    } else {
      return $comments; // comments outside of gallery
    }
  }
  
  /**
   * LazyestCommentor::get_comments_number()
   * 
   * @param mixed $count
   * @return
   */
  function get_comments_number( $count ) {
    global $wpdb, $lg_gallery;
  
    if ( !is_admin() && $lg_gallery->is_gallery() ) {
      $lg_gallery->valid();
      $filevar = $lg_gallery->file;
      if ( $lg_gallery->is_image( $filevar ) || $lg_gallery->is_folder( $filevar ) ) {if ( $lg_gallery->is_image( $filevar ) ) {
        $folder = new LazyestFolder( dirname( $filevar ) );
        if ( $folder->valid() ) {
          $folder->load();
          $image = $folder->single_image( basename( $filevar ) ); 
          $imgID = (int) $image->id;
        }
        unset( $folder );
        } elseif ( $lg_gallery->is_folder($filevar) ) {
          $folder = new LazyestFolder(  $filevar );
          if ( $folder->valid() ) {
            $folder->open();
            $imgID = (int) $folder->id;
          }
          unset( $folder );
        }
        $select = "SELECT * FROM $this->tb_comments WHERE img_ID = $imgID AND comment_approved = 'approve';";
        $query = $wpdb->prepare( $select );
        $results = $wpdb->get_results( $query, ARRAY_A );
        return count( $results );
  
      } else {
        $select = "SELECT comment_ID FROM $this->tb_comments WHERE comment_approved = 'approve';";
        $query = $wpdb->prepare( $select );
        $results = $wpdb->get_results( $query, ARRAY_A );
        if ( !$results ) {
          return $count;
        } else {
          return $count - count( $results );
        }
      }
    } else {
      return $count;
    }
  }
  
  /**
   * LazyestCommentor::get_comment_link()
   * 
   * @param string $link
   * @param string $linkref
   * @param mixed $comment
   * @param mixed $args
   * @return void
   */
  function get_comment_link( $link ) {
    global $lg_gallery, $wpdb;
    $comment_ID = substr( $link, strpos( $link, '#comment-' ) + 9 );
    if ( '' != $comment_ID ) {
      $file = $this->get_file_by_comment_id( $comment_ID );
      if ( false !== $file ) {
        $gallery_uri = $lg_gallery->get_option( 'gallery_prev' );
        $structure = get_option( 'permalink_structure' );    
        if ( (  0 < strlen( $structure ) ) && ( 0 == strpos( $structure, 'index.php' ) ) ) {
          if ( ( 'TRUE' == $lg_gallery->get_option( 'use_permalinks' ) ) ) {    
            $gallery_uri = trailingslashit( $gallery_uri );
            $get = '';
          } else {
            $gallery_uri = untrailingslashit( $gallery_uri );      
            $get = '?file=';
          }  
        } else {      
          $gallery_uri = untrailingslashit( $gallery_uri );
          $get = ( 0 < strpos( $gallery_uri, '?' ) ) ? '&amp;file=' : '?file=';
        }
        $link = $gallery_uri . $get . lg_nice_link( $file ) . '#comment-' . $comment_ID; 
      }      
    }    
    return $link;
  }
  
  /**
   * LazyestCommentor::comments_template()
   * 
   * @param mixed $include
   * @return
   */
  function comments_template( $include ) {
    global $lg_gallery;
    if ( $lg_gallery->is_gallery() ) {
      $folder = new LazyestFolder( $lg_gallery->currentdir );     
      $cansave = ( '' != $lg_gallery->currentdir ) ? ( $folder->valid() && $folder->can_save() ) : true;
      if ( $cansave ) {
        $include = $lg_gallery->plugin_dir . '/inc/comments-form.php';
      }
      unset($folder);
    }   
    return $include;
  }
  
  /**
   * LazyestCommentor::comments_pagenum_link()
   * 
   * @param mixed $result
   * @return
   */
  function comments_pagenum_link( $result ) {
    global $lg_gallery;
    if ( $lg_gallery->is_gallery() ) {
      $folder = new LazyestFolder( $lg_gallery->currentdir );
      $cansave = ( '' != $lg_gallery->currentdir ) ? ( $folder->valid() && $folder->can_save() ) : true;
      if ( $cansave ) {
        $lgresult = $lg_gallery->uri() . $lg_gallery->file;            
        $comment_pos = strpos( $result, 'comment-page-' );
        if ( $comment_pos !== false ) {
          $lgresult .= substr( $result, $comment_pos );
        } else {
          $lgresult .= '#comments';
        }
        return $lgresult;
      }
      unset($folder);      
    }
    return $result;
  }
    
    
  /**
   * LazyestCommentor::get_file_by_comment_id()
   * 
   * @param mixed $comment_ID
   * @return
   */
  function get_file_by_comment_id( $comment_ID ) {
   global $wpdb, $lg_gallery;
    $commentID = (int) $comment_ID;
    $select = "SELECT * FROM " . $this->tb_comments . " WHERE comment_ID = " . $commentID;
    $query = $wpdb->prepare( $select );
    $result = $wpdb->get_row( $query, ARRAY_A );
    $file = '';
    if ( 0 < count( $result ) ) {
      $imgID = (int) $result['img_ID'];
      if ( $imgID != 0 ) { // comment is on another level than root Gallery
        $folders = $lg_gallery->folders( 'subfolders', 'visible' );
        foreach ( $folders as $folder ) {
          if ( (int) $folder->id  == $imgID ) {
            $file = lg_nice_link( $folder->curdir ); 
            break;
          }
          $folder->load( 'slides' );
          for ( $i = 0; $i < count( $folder->list ); $i++ ) {
            $image = $folder->list[$i];
            if ( (int) $image->id  == $imgID ) {
              $file =  lg_nice_link( $folder->curdir . $image->image );
              unset( $folder->list );
            }
          }
          unset ( $folder->list );
        }
        unset ( $folders );
      }
      return $file;
    } else {
      return false;
    }
  }
  
  
  /**
   * LazyestCommentor::lg_count_comments()
   * 
   * @param mixed $img_ID
   * @return
   */
  function count_comments( $img_ID ) {
    global $wpdb, $lg_gallery;  
    $imgID = (int) $img_ID;
    if ( $imgID > 0 ) {
      $select = "SELECT * FROM $this->tb_comments WHERE img_ID = $imgID and comment_approved='approve';";
      $query = $wpdb->prepare( $select );
      $results = $wpdb->get_results( $query, ARRAY_A );
      return count( $results );
    } else { // count root comments
      $page_id = $lg_gallery->get_option( 'gallery_id' );
      $gallery_page = get_post( $page_id );
      $count = (int) $gallery_page->comment_count;
      $results = $wpdb->get_results( $wpdb->prepare( "SELECT comment_ID FROM $this->tb_comments WHERE comment_approved='approve';" ), ARRAY_A );
      if ( !$results ) {
        return $count;
      } else {
        return $count - count( $results );
      }
    }
  }
  
  
  /**
   * LazyestCommentor::get_comments()
   * 
   * @param mixed $img_ID
   * @return
   */
  function get_comments( $img_ID )
  {
    global $wpdb;
    $imgID = (int) $img_ID;
    $select = "SELECT * FROM $this->tb_comments WHERE img_ID =  $imgID AND comment_approved='approve';";
    $query = $wpdb->prepare( $select );
    $results = $wpdb->get_results( $query, ARRAY_A );
    $comments = array();
    if ( 0 != count( $results ) ) {
      foreach ( $results as $result ) {
        $comment_ID = (int) $result['comment_ID'];
        $comment = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM $wpdb->comments WHERE comment_ID = %d ORDER BY comment_date;", $comment_ID ) );
        if ( $comment )
          $comments[] = $comment;
      }
    }
    return $comments;
  }
  
  
  /**
   * LazyestCommentor::get_root_comments()
   * 
   * @return
   */
  function get_root_comments() {
    global $wpdb, $lg_gallery;
    $page_id = (int) $lg_gallery->get_option( 'gallery_id' );
    $comments = array();
    $allcomments = get_approved_comments( $page_id );
    $others = $wpdb->get_results( $wpdb->prepare( "SELECT comment_ID FROM $this->tb_comments WHERE comment_approved='approve';" ), ARRAY_A );
    if ( 0 != count( $others ) ) {
      foreach ( $allcomments as $comment ) {
        if ( !in_array( array( 'comment_ID' => $comment->comment_ID ), $others ) ) {
          $comments[] = $comment;
        }
      }
    } else {
      return ( $allcomments );
    }
    return $comments;  
  }
  
  /**
   * LazyestCommentor::remove_comments()
   * 
   * @param mixed $filevar
   * @return
   */
  function remove_comments( $filevar ) {
    global $lg_gallery;
    $result = true;
    if ( $lg_gallery->is_image( $filevar ) ) {
      $folder = new LazyestFolder( dirname( $filevar ) );
      if ( $folder->valid() ) {
        $folder->load();
        $image = $folder->single_image( basename( $filevar ) ); 
        $img_ID = (int) $image->id;
      }
      unset( $folder );
    } elseif ( $lg_gallery->is_folder( $filevar ) ) {
      $folder = new LazyestFolder( dirname( $filevar ) );
      if ( $folder->valid() ) {
        $folder->open();
        $folder->load();
        foreach( $folder->list as $image ) {
          $this->remove_comments( $filevar . $image->image );
        }
        $imgID = (int) $folder->id;
      }
      unset( $folder );
    }
    $comments = $this->get_comments( $img_ID );
    foreach ( $comments as $comment ) {
      $comment_ID = $comment->comment_ID;
      if ( !wp_delete_comment( $comment_ID ) )
        $result = false;
    }
    return $result;
  } 
  
  /**
   * LazyestCommentor::purge_spam()
   * 
   * @return void
   */
  function purge_spam() {
    global $wpdb;
    $select = "SELECT comment_ID FROM " . $this->tb_comments;
    $query = $wpdb->prepare( $select );
    $results = $wpdb->get_results( $query, ARRAY_A );
    if ( !empty($results) ) {
      foreach ( $results as $result ) {
        $comment_ID = ( int )$result['comment_ID'];
        $comment = get_comment( $comment_ID, ARRAY_A );
        if ( !$comment )
          $this->delete_comment( $comment_ID );
      }
    }
  }
  
  /**
   * LazyestCommentor::edit_comments_form()
   * 
   * @return
   */
  function edit_comments_form() {  
    global $lg_gallery;
  	if ( ! ( current_user_can( 'manage_lazyest_files' ) || current_user_can( 'moderate_comments' ) ) ) {	
  		_e( "It seems like you don't have permission to change Lazyest Gallery's Comments", $lg_gallery->text_domain );
  		return;
  	} else {
  		$this->purge_spam();
  		$this->comments_from = 'gallery';
  		wp_enqueue_script( 'admin-forms' );
  		wp_enqueue_script( 'admin-comments' );	
  		require_once('admin-header.php');
      $file= stripslashes( rawurldecode( $_GET['file'] ) );
      $title = __('Gallery', $lg_gallery->text_domain );
  		if ( $lg_gallery->is_folder( $file ) ) {
  			$this->comments_from = 'folder';               
        $folder = new LazyestFolder( $file );
        $folder->open();      
        $title = __( 'Folder ', $lg_gallery->text_domain ) . '&#8220;' . $folder->title() . '&#8221;';
        unset( $folder );
  		} elseif ( $lg_gallery->is_image( $file ) ) {
  			$this->comments_from = 'image';		        
        $folder = new LazyestFolder( dirname( $file ) );
        $image = $folder->single_image( basename( $file ) );
        $title = __( 'Image ', $lg_gallery->text_domain ) . '&#8220;' . $image->title() . '&#8221;';
        unset( $folder, $image );
  		} 
  	}	
  	
  		?>
  		<div class="wrap">
        <div id="icon-edit-comments" class="icon32"></div><h2><?php _e( 'Edit Comments on', $lg_text_domain ) ?> <?php echo $title ?></h2>
          <form id="posts-filter" action="" method="get">
  				<?php 	      				
  				switch ( $this->comments_from ) { 
  					case 'folder' :  
  						$this->_show_c_folder( $file ); 
  						break;
  					case 'image' : 			
  						$this->_show_c_image( $file );
  						break;
            case 'gallery' : 
  					default: 
  						$this->_show_c_gallery();
  					}
  					$this->edit_comments( $file );				
  				?>
  			</form>
  		</div>
  	<?php
  } 
  
  /**
   * LazyestCommentor::_show_c_folder()
   * 
   * @param mixed $filevar
   * @return
   */
  function _show_c_folder( $filevar ) {  
  	$folder = new LazyestFolder( $filevar );
    if ( $folder->valid() ) {
      $folder->open();
    } else {
      return;
    }
  	?>
  	<div class="tablenav"></div>
  	<br class="clear" />
  	<table class="widefat">
  		<thead>
  			<tr>
  				<th scope="col"><?php _e('Name', $lg_gallery->text_domain ) ?></th>
  				<th scope="col"><?php _e('Caption', $lg_gallery->text_domain ) ?></th>
  				<th scope="col"><?php _e('Date', $lg_gallery->text_domain ) ?></th>
  				<th scope="col" class="num"><div class="vers"><img alt="Comments" src="images/comment-grey-bubble.png"/></div></th>
  				<th scope="col" class="num"><?php _e( 'Images', $lg_gallery->text_domain ) ?></th>
  			</tr>
  		</thead>
  		<tbody id="folder_list" class="list:gal">
  			<tr class="alternate">
  				<td><a title="<?php _e( 'Edit ', $lg_gallery->text_domain ) ?>&quot;<?php echo $folder->title() ?>&quot;" class="row-title" href="admin.php?page=lazyest-filemanager&amp;folder=<?php echo $folder->curdir ?>"><?php echo untrailingslashit( $folder->curdir ) ?></a></td>
  				<td><?php echo $folder->caption ?></td>
  				<td><?php echo date( get_option( date_format ), $folder->datetime ); ?></td>
  				<?php $comment_count = $this->count_comments( $folder->id ); ?>
  				<td class="num" style="text-align:center"><div class="post-com-count-wrapper"><a class="post-com-count" href=""><span class="comment-count"><?php echo $comment_count ?></span></a></div></td>
  				<td class="num" style="text-align:center"><?php echo $folder->count()  ?></td>
  			</tr>
  		</tbody>
  	</table>	
  
  	<?php
    unset( $folder );
  }

  /**
   * LazyestCommentor::_show_c_image()
   * 
   * @param mixed $filevar
   * @return void
   */
  function _show_c_image( $filevar ) {
    global $lg_gallery;
    $folder = new LazyestFolder( dirname( $filevar ) );
  	$image = $folder->single_image( basename( $filevar ), 'thumbs' );
    $onclick = $image->onclick;
  	?>
  	<div class="tablenav"></div>
  	<br class="clear" />
  	<table class='widefat'>
  		<thead>
  			<tr>
  				<th scope="col"><?php _e( 'Image', $lg_gallery->text_domain ) ?></th>
  				<th scope="col"><?php _e( 'File Name', $lg_gallery->text_domain ) ?></th>
  				<th scope="col"><?php _e( 'Caption', $lg_gallery->text_domain ) ?></th>
  				<th scope="col"><?php _e( 'Date', $lg_gallery->text_domain ) ?></th>
  				<th scope="col"><div class='vers'><img alt="Comments" src="images/comment-grey-bubble.png"/></div></th>
  			</tr>
  		</thead>
  		<tbody>
  			<tr>
  				<td class="media-icon" width="80">  				 
  					<a target="_blank" href="<?php echo $onclick['href'] ?>"><img width="60" height="60" class="attachment-80x60" src="<?php echo $image->src() ?>" alt="<?php echo $image->alt() ?>"  title="<?php echo __('Preview ', $lg_gallery->text_domain) . $image->title(); ?>" /></a></td>
  					<td><strong><a title="<?php echo __('Edit ', $lg_gallery->text_domain) . $image->image ?>" href="admin.php?page=lazyest-filemanager&amp;folder=<?php echo lg_nice_link( $folder->curdir ); ?>#<?php echo $image->form_name(); ?>"><?php echo $image->image; ?></a></strong></td>
  					<td><?php echo $image->title() ?></td>
  					<td><?php echo date( get_option( date_format ), $image->datetime ); ?></td>
  					<td class="num  comments column-comments"><div class="post-com-count-wrapper"><a class="post-com-count" href=""><span class="comment-count"><?php echo $comment_count ?></span></a></div></td>
  				</tr>
  		</tbody>
  	</table>
  	<?php
    unset( $folder );
  }
  
  
  /**
   * LazyestCommentor::_show_c_gallery()
   * 
   * @return void
   */
  function _show_c_gallery() {
    global $lg_gallery; 
  	$page_id = $lg_gallery->get_option( 'gallery_id' );
  	$gallery_page = get_post( $page_id );
  	$parts = explode(' ', $gallery_page->post_date );
  	$parts = explode('-', $parts[0]);
  	$page_date = mktime( 0,0,0, (int) $parts[1], (int) $parts[2], (int) $parts[0] );
  	$comment_count = $this->count_comments( -1 );
  	$user_data = get_userdata( $gallery_page->post_author );
  	$nice_name = $user_data->user_nicename;
  	$post_stati  = array(	
  		'publish' => __('Published'),
  		'future' => __('Scheduled'), 
  		'pending' => __('Pending Review'), 
  		'draft' => __('Draft'), 
  		'private' => __('Private') );
  	$post_status_label = $post_stati[$gallery_page->post_status];
  	?>
  	<table class="widefat page">
  		<thead>
  			<tr>
  				<th scope="col">Date</th>	<th scope="col">Title</th>
  				<th scope="col">Author</th>
  				<th scope="col" class="num"><div class="vers"><img alt="" src="images/comment-grey-bubble.png" /></div></th>
  				<th scope="col">Status</th>
  			</tr>
  		</thead>
  		<tbody>
  			<tr id="page-<?php echo $page_id ?>" class="alternate">
  				<td><?php echo date( get_option( date_format ), $page_date ) ?></td>
  				<td><strong><a class="row-title" href="admin.php?page=lazyest-filemanager" title="Edit &quot;<?php echo $gallery_page->post_title; ?>&quot;"><?php echo $gallery_page->post_title ?></a></strong></td>
  				<td><a href="edit-pages.php?author=<?php echo $gallery_page->post_author; ?>"><?php ?><?php echo $nice_name; ?></a></td>
  				<td class="num  comments column-comments"><div class="post-com-count-wrapper"><a href="" class="post-com-count"><span class='comment-count'><?php echo $comment_count; ?></span></a></div></td>
  				<td><a href="<?php echo $lg_gallery->uri(); ?>" title="View &quot;<?php  echo $gallery_page->post_title;  ?>&quot;" rel="permalink"><?php echo $post_status_label; ?></a></td>
  			</tr>
  		</tbody>
  	</table>
  	<?php
  }
  
  function _show_rows() { 
  		?>
  		<tr>
  	    <th scope="col"><?php _e( 'Author' ); ?></th>
  	    <th scope="col"><?php _e( 'Comment' ) ?></th>
        <?php    
  	    	switch ( $this->comments_from ) {
  	    		case 'folder' :
  	    			$foldim = __( 'This Folder', $lg_gallery->text_domain );
  	    			break;
  	    		case 'image' : 
  	    			$foldim = __( 'This Image', $lg_gallery->text_domain );
  	    			break;
  	    		default :
  	    			$foldim = __( 'The Gallery', $lg_gallery->text_domain );
              break;
  	    	}         
        ?>  
  	    <th scope="col"><?php echo __( 'In Response To ' , $lg_gallery->text_domain ) . $foldim; ?></th>
  	  </tr>
  	<?php 
  }
  
    
  function _wp_comment_row( $comment_id, $mixed_list = false ) {
  	global $comment, $_comment_pending_count, $lg_gallery;
  	$comment = get_comment( $comment_id );
  	$the_comment_status = wp_get_comment_status($comment->comment_ID);  
  	$author_url = get_comment_author_url();
  	if ( 'http://' == $author_url )
  		$author_url = '';
  	$author_url_display = preg_replace('|http://(www\.)?|i', '', $author_url);
  	if ( strlen($author_url_display) > 50 )
  		$author_url_display = substr($author_url_display, 0, 49) . '...';
  
  	$ptime = date('G', strtotime( $comment->comment_date ) );
  	if ( ( abs(time() - $ptime) ) < 86400 )
  		$ptime = sprintf( __('%s ago'), human_time_diff( $ptime ) );
  	else
  		$ptime = mysql2date(__('Y/m/d \a\t g:i A'), $comment->comment_date );
  
  	if ( $user_can ) {
  		$del_nonce = esc_html( '_wpnonce=' . wp_create_nonce( "delete-comment_$comment->comment_ID" ) );
  		$approve_nonce = esc_html( '_wpnonce=' . wp_create_nonce( "approve-comment_$comment->comment_ID" ) );
  
  		$comment_url = esc_url(get_comment_link($comment->comment_ID));
  		$approve_url = esc_url( "comment.php?action=approvecomment&p=$post->ID&c=$comment->comment_ID&$approve_nonce" );
  		$unapprove_url = esc_url( "comment.php?action=unapprovecomment&p=$post->ID&c=$comment->comment_ID&$approve_nonce" );
  		$spam_url = esc_url( "comment.php?action=spamcomment&p=$post->ID&c=$comment->comment_ID&$del_nonce" );
  		$unspam_url = esc_url( "comment.php?action=unspamcomment&p=$post->ID&c=$comment->comment_ID&$del_nonce" );
  		$trash_url = esc_url( "comment.php?action=trashcomment&p=$post->ID&c=$comment->comment_ID&$del_nonce" );
  		$untrash_url = esc_url( "comment.php?action=untrashcomment&p=$post->ID&c=$comment->comment_ID&$del_nonce" );
  		$delete_url = esc_url( "comment.php?action=deletecomment&p=$post->ID&c=$comment->comment_ID&$del_nonce" );
  	}
  
  	echo "<tr id='comment-$comment->comment_ID' class='$the_comment_status'>";
  	$columns = get_column_headers('edit-comments');
  	$hidden = get_hidden_columns('edit-comments');
  	foreach ( $columns as $column_name => $column_display_name ) {
  		$class = "class=\"$column_name column-$column_name\"";
  
  		$style = '';
  		if ( in_array($column_name, $hidden) )
  			$style = ' style="display:none;"';
  
  		$attributes = "$class$style";
  
  		switch ($column_name) {
  		  
			  case 'cb':
				  break;
  			case 'comment':
  				echo "<td $attributes>";
  				echo '<div id="submitted-on">';
  				printf(__('Submitted on <a href="%1$s">%2$s at %3$s</a>'), $comment_url, get_comment_date(__('Y/m/d')), get_comment_date(__('g:ia')));
  				echo '</div>';
  				comment_text();
  				if ( $user_can ) { ?>
  				<div id="inline-<?php echo $comment->comment_ID; ?>" class="hidden">
  				<textarea class="comment" rows="1" cols="1"><?php echo htmlspecialchars( apply_filters('comment_edit_pre', $comment->comment_content), ENT_QUOTES ); ?></textarea>
  				<div class="author-email"><?php echo esc_attr( $comment->comment_author_email ); ?></div>
  				<div class="author"><?php echo esc_attr( $comment->comment_author ); ?></div>
  				<div class="author-url"><?php echo esc_attr( $comment->comment_author_url ); ?></div>
  				<div class="comment_status"><?php echo $comment->comment_approved; ?></div>
  				</div>
  				<?php
  				}
  
  				if ( $user_can ) {
  					// preorder it: Approve | Reply | Quick Edit | Edit | Spam | Trash
  					$actions = array(
  						'approve' => '', 'unapprove' => '',
  						'reply' => '',
  						'quickedit' => '',
  						'edit' => '',
  						'spam' => '', 'unspam' => '',
  						'trash' => '', 'untrash' => '', 'delete' => ''
  					);
  
  					if ( $comment_status && 'all' != $comment_status ) { // not looking at all comments
  						if ( 'approved' == $the_comment_status )
  							$actions['unapprove'] = "<a href='$unapprove_url' class='delete:the-comment-list:comment-$comment->comment_ID:e7e7d3:action=dim-comment&amp;new=unapproved vim-u vim-destructive' title='" . esc_attr__( 'Unapprove this comment' ) . "'>" . __( 'Unapprove' ) . '</a>';
  						else if ( 'unapproved' == $the_comment_status )
  							$actions['approve'] = "<a href='$approve_url' class='delete:the-comment-list:comment-$comment->comment_ID:e7e7d3:action=dim-comment&amp;new=approved vim-a vim-destructive' title='" . esc_attr__( 'Approve this comment' ) . "'>" . __( 'Approve' ) . '</a>';
  					} else {
  						$actions['approve'] = "<a href='$approve_url' class='dim:the-comment-list:comment-$comment->comment_ID:unapproved:e7e7d3:e7e7d3:new=approved vim-a' title='" . esc_attr__( 'Approve this comment' ) . "'>" . __( 'Approve' ) . '</a>';
  						$actions['unapprove'] = "<a href='$unapprove_url' class='dim:the-comment-list:comment-$comment->comment_ID:unapproved:e7e7d3:e7e7d3:new=unapproved vim-u' title='" . esc_attr__( 'Unapprove this comment' ) . "'>" . __( 'Unapprove' ) . '</a>';
  					}
  
  					if ( 'spam' != $the_comment_status && 'trash' != $the_comment_status ) {
  						$actions['spam'] = "<a href='$spam_url' class='delete:the-comment-list:comment-$comment->comment_ID::spam=1 vim-s vim-destructive' title='" . esc_attr__( 'Mark this comment as spam' ) . "'>" . /* translators: mark as spam link */ _x( 'Spam', 'verb' ) . '</a>';
  					} elseif ( 'spam' == $the_comment_status ) {
  						$actions['unspam'] = "<a href='$untrash_url' class='delete:the-comment-list:comment-$comment->comment_ID:66cc66:unspam=1 vim-z vim-destructive'>" . __( 'Not Spam' ) . '</a>';
  					} elseif ( 'trash' == $the_comment_status ) {
  						$actions['untrash'] = "<a href='$untrash_url' class='delete:the-comment-list:comment-$comment->comment_ID:66cc66:untrash=1 vim-z vim-destructive'>" . __( 'Restore' ) . '</a>';
  					}
  
  					if ( 'spam' == $the_comment_status || 'trash' == $the_comment_status || !EMPTY_TRASH_DAYS ) {
  						$actions['delete'] = "<a href='$delete_url' class='delete:the-comment-list:comment-$comment->comment_ID::delete=1 delete vim-d vim-destructive'>" . __('Delete Permanently') . '</a>';
  					} else {
  						$actions['trash'] = "<a href='$trash_url' class='delete:the-comment-list:comment-$comment->comment_ID::trash=1 delete vim-d vim-destructive' title='" . esc_attr__( 'Move this comment to the trash' ) . "'>" . _x('Trash', 'verb') . '</a>';
  					}
  
  					if ( 'trash' != $the_comment_status ) {
  						$actions['edit'] = "<a href='comment.php?action=editcomment&amp;c={$comment->comment_ID}' title='" . esc_attr__('Edit comment') . "'>". __('Edit') . '</a>';
  						$actions['quickedit'] = '<a onclick="commentReply.open(\''.$comment->comment_ID.'\',\''.$post->ID.'\',\'edit\');return false;" class="vim-q" title="'.esc_attr__('Quick Edit').'" href="#">' . __('Quick&nbsp;Edit') . '</a>';
  						if ( 'spam' != $the_comment_status )
  							$actions['reply'] = '<a onclick="commentReply.open(\''.$comment->comment_ID.'\',\''.$post->ID.'\');return false;" class="vim-r" title="'.esc_attr__('Reply to this comment').'" href="#">' . __('Reply') . '</a>';
  					}
  
  					$actions = apply_filters( 'comment_row_actions', array_filter($actions), $comment );
  
  					$i = 0;
  					echo '<div class="row-actions">';
  					foreach ( $actions as $action => $link ) {
  						++$i;
  						( ( ('approve' == $action || 'unapprove' == $action) && 2 === $i ) || 1 === $i ) ? $sep = '' : $sep = ' | ';
  
  						// Reply and quickedit need a hide-if-no-js span when not added with ajax
  						if ( ('reply' == $action || 'quickedit' == $action) && ! $from_ajax )
  							$action .= ' hide-if-no-js';
  						elseif ( ($action == 'untrash' && $the_comment_status == 'trash') || ($action == 'unspam' && $the_comment_status == 'spam') ) {
  							if ('1' == get_comment_meta($comment_id, '_wp_trash_meta_status', true))
  								$action .= ' approve';
  							else
  								$action .= ' unapprove';
  						}
  
  						echo "<span class='$action'>$sep$link</span>";
  					}
  					echo '</div>';
  				}
  
  				echo '</td>';
  				break;
  			case 'author':
  				echo "<td $attributes><strong>"; comment_author(); echo '</strong><br />';
  				if ( !empty($author_url) )
  					echo "<a title='$author_url' href='$author_url'>$author_url_display</a><br />";
  				if ( $user_can ) {
  					if ( !empty($comment->comment_author_email) ) {
  						comment_author_email_link();
  						echo '<br />';
  					}
  					echo '<a href="edit-comments.php?s=';
  					comment_author_IP();
  					echo '&amp;mode=detail';
  					if ( 'spam' == $comment_status )
  						echo '&amp;comment_status=spam';
  					echo '">';
  					comment_author_IP();
  					echo '</a>';
  				} //current_user_can
  				echo '</td>';
  				break;
  			case 'date':
  				echo "<td $attributes>" . get_comment_date(__('Y/m/d \a\t g:ia')) . '</td>';
  				break;
  			case 'response':  //TODO:start editing here
          $filevar = $this->get_file_by_comment_id( $comment_id );
          $is_image = $lg_gallery->is_image( $filevar );
          $is_folder = $lg_gallery->is_folder( $filevar );
          $edit_title = __( 'Gallery', $lg_gallery->text_domain );
          $edit_link = 'wp-admin/admin.php?page=lazyest-filemanager';
          if ( '' != $filevar ) {
            $editlink .= ( $is_folder ) ? dirname( $filevar ) : dirname( $filevar ) . '#' . basename( $filevar );
            if ( $lg_gallery->is_folder( $filevar ) ) {
              $folder = new LazyestFolder( $filevar );
              if ( $folder->valid() ) {
                $folder->open();         
                $edit_title = $folder->title();
              }
            }
            if ( $is_image ) {
              $folder = new LazyestFolder( dirname( $filevar ) );
              if ( $folder->valid() ) {
                $image = $folder->single_image( basename( $filevar), 'thumbs' );
                $edit_title = $image->title();
                $onclick = $image->on_click();                
                $image_src = $image->src();
              }
            }
          }
					$post_link = "<a href='" . $editlink . "'>";
					$post_link .= $edit_title . '</a>';				
					echo "<td $attributes>\n";
					echo '<div class="response-links"><span class="post-com-count-wrapper">';
					echo $post_link . '<br />';
					$pending_phrase = esc_attr(sprintf( __('%s pending'), number_format( $pending_comments ) ));
					if ( $pending_comments )
						echo '<strong>';
					comments_number("<a href='edit-comments.php?p=$post->ID' title='$pending_phrase' class='post-com-count'><span class='comment-count'>" . /* translators: comment count link */ _x('0', 'comment count') . '</span></a>', "<a href='edit-comments.php?p=$post->ID' title='$pending_phrase' class='post-com-count'><span class='comment-count'>" . /* translators: comment count link */ _x('1', 'comment count') . '</span></a>', "<a href='edit-comments.php?p=$post->ID' title='$pending_phrase' class='post-com-count'><span class='comment-count'>" . /* translators: comment count link: % will be substituted by comment count */ _x('%', 'comment count') . '</span></a>');
					if ( $pending_comments )
						echo '</strong>';
					echo '</span> ';
					echo '</div>'; 
          if ( $mixed_list ) {
            if ( $is_image ) { ?>
            <a target="_blank" href="<?php echo $onclick['href']; ?>" rel="<?php echo $onclick['rel'] ?>" class="alignright<?php echo $onclick['class'] ?>"> 
    			     <img width="60" height="60" class="attachment-80x60" src="<?php echo $image->src(); ?>" alt="<?php echo $image->alt(); ?>"  title="<?php echo $image->title() ?>" />
              </a>
            <?php
            } else {
              $the_uri =  ( '' == $filevar ) ? trailingslashit( $lg_gallery->address ) : $folder->uri();
              $the_image = ( '' == $filevar ) ? 'folders.png' : 'folder-icon.png';          
            ?>
            <a target="_blank" href="<?php echo $the_uri; ?>" class="alignright"> 
    			     <img width="60" height="60" class="attachment-80x60" src="<?php echo trailingslashit( $lg_gallery->plugin_url ) . 'images/' . $the_image; ?>" alt="<?php echo __( 'Icon', $lg_gallery->text_domain ); ?>"  title="<?php echo __( 'Cick to View', $lg_gallery->text_domain ); ?>" />
              </a>
            <?php
              
            }
          }
          unset( $image );
          unset( $folder );
  				break;
  			default:
  				echo "<td $attributes>\n";
  				do_action( 'manage_comments_custom_column', $column_name, $comment->comment_ID );
  				echo "</td>\n";
  				break;
  		}
  	}
  	echo "</tr>\n";
  }


  /**
   * LazyestCommentor::edit_comments()
   * 
   * @param mixed $filevar
   * @return void
   */
  function edit_comments( $filevar ) {
  	global $lg_gallery;
    
  	?>
  	<div class="tablenav"></div>
  	<?php
  	  
  	switch ( $this->comments_from ) {
  	case 'folder' :
  		$folder = new LazyestFolder( $filevar );
      $folder->open();
  		$comments = $this->get_comments( $folder->id );
  		$caption = $folder->caption;
  		break;
  	case 'image' :
      $folder = new LazyestFolder( dirname( $filevar ) );
      $folder->load( 'images' );
  		$image = $folder->single_image( basename( $filevar ) );
  		$comments = $this->get_comments( $image->id );
  		$caption = $image->caption;
  		break;
    case 'gallery' :
  	default : 
  		$comments = $this->get_root_comments();
  		$page_id = $lg_gallery->get_option( 'gallery_id' );
  		$gallery_page = get_post( $page_id );
  		$caption = $gallery_page->post_title;
  	}    
  	if ( $comments ) {		
  		update_comment_cache( $comments );
  		?>
  		<br class="clear" />
  		<table class="widefat" style="margin-top: .5em">
  		<thead>
  		  <?php $this->_show_rows(); ?>
  		</thead>
  		<?php if( $new_comments ) { ?>
  			<tfoot>
  			  <?php $this->_show_rows(); ?>
  			</tfoot>
  		<?php } ?>
  		<tbody id="the-comment-list" class="list:comment">
  		<?php
  			foreach ( $comments as $comment )
  				$this->_wp_comment_row( $comment->comment_ID ); //wordpress internal function ! check on wp update
  		?>
  		</tbody>
  		</table>
  		<?php
  		
			$pageID = $lg_gallery->get_option( 'gallery_id' );
			$search = get_option( 'siteurl' ) . '/wp-admin/page.php?action=edit&post=' . $pageID;			
						
			switch ( $comments_from  ) {
				case 'image' : 
					$replace = 'admin.php?page=lazyest-filemanager&amp;folder=' . lg_nice_link( $folder->curdir ) . '#' . $image->image;
					break;
				case 'folder':
					$replace = 'admin.php?page=lazyest-filemanager&amp;folder=' . lg_nice_link( $folder->curdir );
					break;
				default:
					$replace = 'admin.php?page=lazyest-filemanager';
			}
  		
  		echo "<script type='text/javascript'>\n";
  		echo "lg_editCommentsSearch = '" . $search . "';\n";
  		echo "lg_editCommentsReplace = '". $replace . "';\n";
  		echo "lg_editCommentsString = '". htmlspecialchars( $caption, ENT_QUOTES ) . "';\n";
  		echo "lg_numComments = '(" . count( $comments ) . ")';\n";
  		echo "</script>\n";
  	} 
    if ( isset( $folder ) ) {
      unset ( $folder ) ;      
    }
  }   
    
} // LazyestCommentor


function lg_comments_caption() {
  global $lg_gallery;
  if ( !isset( $lg_gallery ) ) return false;
  if ( !isset( $lg_gallery->file ) ) $lg_gallery->valid();	  
	if ( $lg_gallery->is_image( $lg_gallery->file ) ) {
		$the_folder = new LazyestFolder( dirname( $lg_gallery->file ) );
		$the_image = $the_folder->single_image( basename( $lg_gallery->file ) );
    echo ' &#8220;' . $the_image->caption() . '&#8221;';
	} elseif ( $lg_gallery->is_folder( $lg_gallery->file ) ) {
		$the_folder = new LazyestFolder( $lg_gallery->file ) ;
    $the_folder->open();
    $title= $the_folder->caption();
    unset( $the_folder );
    echo ' &#8220;' . $title . '&#8221;';
  } else {
    the_title();
  }
}

function lg_comments_filename() {
  global $lg_gallery;
  if ( !isset( $lg_gallery ) ) return false;
  if ( !isset( $lg_gallery->file ) ) $lg_gallery->valid();	  
	if ( $lg_gallery->is_image( $lg_gallery->file ) ) {
		$the_folder = new LazyestFolder( dirname( $lg_gallery->file ) );    
		$the_image = $the_folder->single_image( basename( $lg_gallery->file ) );
    echo esc_html( $the_image->image );
	} elseif ( $lg_gallery->is_folder( $lg_gallery->file ) ) {
		$the_folder = new LazyestFolder( $lg_gallery->file ) ;
    $the_folder->open();
    $filename= untrailingslashit( $the_folder->curdir );
    unset( $the_folder );
    echo esc_html( $filename );
  } 
}

function lg_comments_can_access() {
  global $lg_gallery;
  if ( !isset( $lg_gallery ) ) return false;
  if ( !isset( $lg_gallery->file ) ) $lg_gallery->valid();
  if ( $lg_gallery->is_folder( $lg_gallery->file ) ) {
		$the_folder = new LazyestFolder( $lg_gallery->file ) ;
    $the_folder->open();
    $can_access = $the_folder->user_can_access();
    unset( $the_folder );
    return $can_access;
  } else {
    return true;
  }
}

function lg_comments_not_root() {
  global $lg_gallery;
  if ( !isset( $lg_gallery ) ) return false;
  if ( !isset( $lg_gallery->file ) ) $lg_gallery->valid();
  return $lg_gallery->is_image( $lg_gallery->file ) || $lg_gallery->is_folder( $lg_gallery->file );
}

function lg_comments_on_image() {
  global $lg_gallery;
  if ( !isset( $lg_gallery ) ) return false;
  if ( !isset( $lg_gallery->file ) ) $lg_gallery->valid();
  return $lg_gallery->is_image( $lg_gallery->file );  
}

function lg_comment_id_fields() {
  global $lg_gallery;
  if ( !isset( $lg_gallery ) ) return false;
  if ( !isset( $lg_gallery->file ) ) $lg_gallery->valid();	  
	if ( $lg_gallery->is_image( $lg_gallery->file ) ) {
		$the_folder = new LazyestFolder( dirname( $lg_gallery->file ) );    
		$the_image = $the_folder->single_image( basename( $lg_gallery->file ) );
    $the_id =  $the_image->id;
    $the_uri = $the_image->uri();
    unset( $the_image );
	} elseif ( $lg_gallery->is_folder( $lg_gallery->file ) ) {
		$the_folder = new LazyestFolder( $lg_gallery->file ) ;
    $the_folder->open();
    $the_id= $the_folder->id;
    $the_uri = $the_folder->uri();
    unset( $the_folder );
  } else {
    return;
  } 
  ?>
  <input type="hidden" name="lg_comment_image_ID" value="<?php echo $the_id; ?>" />
  <input type="hidden" name="redirect_to" value="<?php echo $the_uri; ?>" />
  <?php
}
?>