<?php
class LazyestFolder {
  
  var $curdir;
  
  var $caption;
    
	var $description;
  
	var $order;
  
	var $visibility;
  
  var $roles;
  	
	var $id;
  
  var $datetime;
  
  var $list;
  
  function LazyestFolder( $path ) {
    $this->__construct( $path );
  }
  
  
  /**
   * LazyestFolder::__construct()
   * 
   * @param mixed $path
   * @return
   */
  function __construct( $path ) {    
    $this->curdir = trailingslashit( $path );   
    if ( !$this->valid() ) {
      return false;
    }
    $roles = array();     
  }
  
  
  /**
   * LazyestFolder::valid()
   * 
   * @return
   */
  function valid() {
    global $lg_gallery;
    if ( ( '' == $this->curdir ) || !is_dir( $lg_gallery->root . $this->curdir ) ) {
      return false;
    }
    if ( !is_readable( $lg_gallery->root . $this->curdir ) ) {
      return false;
    }
    $dirs = explode( '/', $this->curdir );
    $dir = $dirs[ count( $dirs ) - 2 ];
    return !in_array( $dir, $lg_gallery->get_option( 'excluded_folders' ) ) && ( $dir != '.' ) && ( $dir != '..' ) && ( '.' != $dir[0] );
  }
  
  /**
   * LazyestFolder::can_save()
   * 
   * @return
   */
  function can_save() {  
    global $lg_gallery; 
    return is_writeable( $lg_gallery->root . $this->curdir );
  }
  
  
  /**
   * LazyestFolder::uri()
   * 
   * @return
   */
  function uri( $widget = 'none' ) {
    global $lg_gallery; 
    if ( !$this->valid() || !isset( $lg_gallery ) || !$this->user_can_access() ) {
      return false;
    }
    $gallery_uri = $lg_gallery->uri( $widget );
      $structure = get_option( 'permalink_structure' );    
      if ( (  0 < strlen( $structure ) ) && ( 0 == strpos( $structure,'index.php' ) ) ) {
      if ( ( 'TRUE' == $lg_gallery->get_option( 'use_permalinks' ) )  && ( $lg_gallery->is_gallery() || ( 'widget' == $widget ) ) )  {
        $gallery_uri = trailingslashit( $gallery_uri );
        $get = '';
      } else {
        $gallery_uri = untrailingslashit( $gallery_uri );
        $get = '?file=';
      }  
    } else {      
      $gallery_uri = untrailingslashit( $gallery_uri );
      $get = ( 0 < strpos( $gallery_uri, '?' ) ) ? '&amp;file=' : '?file=';
    }     
    return $gallery_uri . $get . lg_nice_link( $this->curdir );    
  }
  
  /**
   * LazyestFolder::dirname()
   * 
   * @return
   */
  function dirname() {
    $dirs = explode( '/', $this->curdir );
    return $dirs[count( $dirs )-2];
  }
  
  function caption() {
    global $lg_gallery;   
    $caption = ( '' != $this->caption ) ? $this->caption : str_replace( '_', ' ', $this->dirname() );
    $caption =  ( 'TRUE' == $lg_gallery->get_option( 'use_folder_captions' ) ) ? $caption : $this->dirname();
    return apply_filters( 'lazyest_folder_caption', lg_html( $caption ) );
  }
  

  /**
   * LazyestFolder::title()
   * 
   * @return
   */
  function title() {
    global $lg_gallery;   
    $caption = ( '' != $this->caption ) ? $this->caption : str_replace( '_', ' ', $this->dirname() );
    $caption =  ( 'TRUE' == $lg_gallery->get_option( 'use_folder_captions' ) ) ? $caption : $this->dirname();
    $title =  htmlspecialchars( strip_tags( $caption ), ENT_QUOTES );
    return apply_filters( 'lazyest_folder_title', $title );
  }
  
  function form_name() {    
    return preg_replace( '/\"|\'|\.| |\s/', '_', $this->curdir );
  }
  
  function html_id() {
    return $this->form_name();
  }
    
  function is_folder_icon( $filevar ) {
  	global $lg_gallery;
  	if ( 'icon' != $lg_gallery->get_option( 'folder_image' ) ) {
  		return false;
  	}
  	$path_parts = pathinfo( $filevar );
  	$filename = $path_parts['filename'];  
    $dirs = explode( '/', untrailingslashit( $this->curdir ) );
    $dir = $dirs[ count( $dirs )-1 ];   
  	return ( $filename == $dir );  	
  }
  
  
  function count( $sub = 'root' ) {
    global $lg_gallery;
    if  ( !$this->valid() ) {
      return false;
    }
    $location = $lg_gallery->root . $this->curdir;
	 	$numfiles = 0;
    $subfiles = 0;
		if ( $dir_content = opendir( $location ) ) {  
			while ( $dir_file = readdir( $dir_content ) ) {
        if ( ( 'subfolders' == $sub ) && is_dir( $location . $dir_file ) ) {
          $subfolder = new LazyestFolder( $this->curdir . $dir_file );
          if ( $subfolder->valid() ) {
            $subfiles += $subfolder->count( $sub );            
          }
          unset( $subfolder );
        }  			 
				if  ( is_readable( $location . $dir_file ) &&	( 0 < preg_match( "/^.*\.(jpg|gif|png|jpeg)$/i", $dir_file ) ) ) {
					if ( !$this->is_folder_icon( $dir_file ) ) {
						$numfiles++;
					}
				}
			}
		} else {
	    return false;
		}
  	return ( 'subfolders' == $sub ) ? $numfiles + $subfiles : $numfiles;
  }
  
  function _compare_i( $i1, $i2 ) {    
    global $lg_gallery;
    switch ( $lg_gallery->get_option( 'sort_alphabetically' ) ) {
      case 'TRUE' : $id = 'image';
        break;
      case 'FALSE' : $id = 'datetime';
        break;
      case 'MANUAL' : $id = 'index';
        break;  
    }     
    if ( $i1->$id == $i2->$id ) {
      return 0;
    }    
    return ( $i1->$id < $i2->$id) ? -1 : 1; 
  }
  
  function sort() {
    if ( isset( $this->list ) ) {
      return ( usort( $this->list, array( &$this, '_compare_i' ) ) );
    } else {
      return false;
    }
  }
  
  
  /**
   * LazyestFolder::open()
   * Setting class members by reading captions.xml file if found
   * 
   * @return bool success or failure
   */
  function open() {
    global $lg_gallery;
    
    if ( !$this->valid() ) {
      return false;
    } 
  	$this->caption = '';  
  	$this->description = '';
  	$this->level = '1';
  	$this->order = '';
  	$this->visibility = 'visible';	
  	$this->id = '0';    
    $this->datetime =  @filemtime( $lg_gallery->root . $this->curdir );
  	if ( false === $this->datetime ) {
  		$this->datetime = time();
  	}  	
  	if ( file_exists( $lg_gallery->root . $this->curdir . 'captions.xml' ) ) {
  		$objXML = new LazyestXMLParser();
  		$arrXML = $objXML->parse( $lg_gallery->root . $this->curdir . 'captions.xml' );
  
  		if ( isset( $arrXML ) && ( $arrXML != NIL ) ) {
  			foreach ( $arrXML[0]['children'] as $child ) {
  				switch ( $child['name'] ) {
  					case 'FOLDER' :
  						if ( NULL != $child['tagdata'] ) $this->caption = stripslashes( html_entity_decode( utf8_decode( $child['tagdata'] ) ) );
  						break;      
  					case 'FDESCRIPTION' :
  						if ( NULL != $child['tagdata'] ) $this->description = stripslashes( html_entity_decode( utf8_decode( $child['tagdata'] ) ) );
  						break;
  					case 'LEVEL' : // for compatibility. will not be writen back
  						if ( ( NULL != $child['tagdata'] ) && ( '' != $child['tagdata'] ) )  {
  							$level = $child['tagdata'];
  							if ( $level <= 1 ) { 
  								$this->roles[] = 'everyone'; 
  							} else {
  								if ( $level > 1 ) $this->roles[] = 'author';
  								if ( $level > 2 ) $this->roles[] = 'editor';
  								if ( $level > 7 ) $this->roles[] = 'administrator';
  							}
  						} else {
  							$this->roles[] = 'everyone';
  						}
  					break;
  					case 'ORDER' :
  						if ( ( NULL != $child['tagdata'] ) && ( '' != $child['tagdata'] ) ) $this->order = $child['tagdata'];
  						break;
  					case 'VISIBILITY' :
  						if ( ( NULL != $child['tagdata'] ) && ( '' != $child['tagdata'] ) ) $this->visibility = $child['tagdata'];
  						break;		
  				  case 'ID' :
  				  	if ( ( NULL != $child['tagdata'] ) && ( '' != $child['tagdata'] ) ) $this->id = $child['tagdata'];
  						break;
  					case 'ROLE' :
  				  	if ( ( NULL != $child['tagdata'] ) && ( '' != $child['tagdata'] ) ) $this->roles[] = $child['tagdata'];
  						break; 		
  				}
  			}     			
    		if ( '0' == $this->id ) {
    			$k = $lg_gallery->get_option( 'image_indexing' );
    			$this->id = $k++;
    			$lg_gallery->update_option( 'image_indexing' , $k );
          $this->change();
    		}
    	}
    	unset($arrXML);
    	unset($objXML);
      return true;
  	} else {
			$k = $lg_gallery->get_option( 'image_indexing' );
    	$this->id = $k++;
    	$lg_gallery->update_option( 'image_indexing' , $k );
      $this->change();    
  	}
  }
  
  
  function write_xml( $handle ) {
    if ( !$this->valid() || !isset( $handle ) ) {
      return false;
    }    
  	fwrite( $handle, "\t<folder><![CDATA[" . utf8_encode( htmlentities( $this->caption ) ) . "]]></folder>\n" );  
  	fwrite( $handle, "\t<fdescription><![CDATA[" . utf8_encode( htmlentities( $this->description ) ) . "]]></fdescription>\n" );		
  	fwrite( $handle, "\t<order>" . $this->order . "</order>\n" );
  	fwrite( $handle, "\t<visibility>" . $this->visibility . "</visibility>\n" );
  	fwrite( $handle, "\t<id>" . $this->id . "</id>\n" );
  	foreach ( (array) $this->roles as $role ) fwrite( $handle, "\t<role>" . $role . "</role>\n" );
  }
  
  
  function _read_files() {  
    global $lg_gallery;
    $location = $lg_gallery->root . $this->curdir;
	 	$ilist = array();
		if ( $dir_content = opendir( $location ) ) {  
			while ( false !== ( $dir_file = readdir( $dir_content ) ) ) {
        if ( $lg_gallery->is_image( $this->curdir . $dir_file ) ) {
          $ilist[] = basename( $dir_file );            
        }  			 
			}
		} else {  
	    return false;
		}
    return $ilist;
  }
  
  function _new_item( $what = 'images' ) {
    switch ( $what ) {
	    case 'images' : 
        $image = new LazyestImage( $this );        
        break;
      case 'thumbs' :
        $image = new LazyestThumb( $this );
        break;
      case 'slides' :
        $image = new LazyestSlide( $this );
        break; 
	  }
    return $image;       
  }
  
  function _empty_list() {
    for ( $i = 0; $i < count( $this->list ); $i++ ) {
      $image = $this->list[$i];
      unset( $image );
    }
    unset( $this->list );
  }
  
  
  /**
   * LazyestFolder::load()
   * 
   * @param string $what What to load, can be either 'images', 'thumbs' or 'slides'
   * Reads all images in the folder and reads image data from captions.xml file.
   * Writes captions.xml with new images info, and deletes not found images info. 
   * @return bool success or failure
   */
  function load( $what = 'images' ) {
    global $lg_gallery;
    if ( !$this->valid() ) {
      return false;
    }
    if ( isset( $this->list ) ) {
      $this->_empty_list();
    }
    $readfiles = $this->_read_files();
    if ( $readfiles === false ) {
      return false;
    }
  	if ( file_exists( $lg_gallery->root . $this->curdir . 'captions.xml' ) ) {	
  		$objXML = new LazyestXMLParser();
  		$arrXML = $objXML->parse( $lg_gallery->root . $this->curdir . 'captions.xml' );
  		$i = 0;
      $changed = false;
  		if ( isset( $arrXML ) && ( $arrXML != NIL ) ) {
  			foreach ( $arrXML[0]['children'] as $child ) {
  				if ( 'PHOTO' == $child['name'] ) {
  				  $image = $this->_new_item( $what );    				  
  					$image->image = $child['attrs']['ID']; // for compatibility pre 0.12 - tricky: in the xml file, ID is used for the image name
  					foreach( $child['children'] as $grandchild ) {
  						switch ( $grandchild['name'] ) {
  							case 'FILENAME' :
  								$image->image = $grandchild['tagdata'];
  								break;
  							case 'CAPTION' :
  								$image->caption = stripslashes( html_entity_decode( utf8_decode( $grandchild['tagdata'] ) ) );
  								break;                
  							case 'DESCRIPTION' :
  								$image->description = stripslashes( html_entity_decode( utf8_decode( $grandchild['tagdata'] ) ) );
  								break;
  							case 'IMAGE' :
  								$image->id = $grandchild['tagdata']; // tricky: in the xml file, IMAGE is used for the id
                  if ( '' == $image->id ) {                    
                    $k = intval( $lg_gallery->get_option( 'image_indexing' ) );
                    $image->id = $k++;
    	              $lg_gallery->update_option( 'image_indexing' , strval( $k ) );
                    $changed = true;                     
                  }
  								break;
  							case 'INDEX' :
  								if ( '' == $grandchild['tagdata'] ) {
  									$image->index = strval( $i );
  								} else {
  									$image->index = $grandchild['tagdata'];
  								}
                  break;
  						}
  					}
            if ( !in_array( $image->image, $readfiles ) ) { // file has been deleted after last write
              unset( $image );
              $changed = true;
            } else {
              unset( $readfiles[array_search( $image->image, $readfiles )] );
    					$i++;         
              $this->list[] = $image;
            }				
				  }
  			}	
   		}
      if (  0 < count( $readfiles ) ) { // files have been added after last write
        $changed = true;
        foreach( $readfiles as $filename ) {
          $image = $this->_new_item( $what );
          $image->image = $filename;
          $image->index = strval( $i++ );
          $this->list[] = $image;
        }
      }
      unset( $readfiles );
  		unset( $arrXML );
  		unset( $objXML );
  	} else {
      if (  0 < count( $readfiles ) ) { // files have been found nut no captions.xml
        $changed = true;
        foreach( $readfiles as $filename ) {
          $image = $this->_new_item( $what );
          $image->image = $filename;
          $image->index = strval( $i++ );
          $this->list[] = $image;
        }
      }
  	} 
    if ( 0 < count( $this->list ) ) { // list has been read and validated: set dates
      foreach( $this->list as $image ) {
        $image->datetime  =  @filemtime( $lg_gallery->root . $this->curdir . $image->image );
      }
    }
    $this->sort();
    if ( $changed ) {  
      $this->save();
    }
    return true;	     
  }
  
  
  function save() { 
    global $lg_gallery;
  	$xml_file = $lg_gallery->root . $this->curdir . 'captions.xml';
  	$handle = @fopen( $xml_file, 'wb' );
  	if ( false !== $handle ) { 	 
  		fwrite( $handle, "<?xml version='1.0' encoding='UTF-8' ?>\n" );
  		fwrite( $handle, "<data>\n" );
  		$this->write_xml( $handle );      
      if ( isset( $this->list ) ) {
        for ( $i = 0; $i < count( $this->list ); $i++ ) {
          $image = $this->list[$i];
          $image->write_xml( $handle );
        }      
      }
  		fwrite( $handle, "</data>" );
  		fclose( $handle );
  		$stat = stat(  $lg_gallery->root . $this->curdir );
  		$perms = $stat['mode'] & 0000666;
  		@chmod( $xml_file, $perms );
  	} else {
  	  return false; 
  	}
    return true;
  }
  
  
  function change() { 
    global $lg_gallery;
  	$xml_file = $lg_gallery->root . $this->curdir . 'captions.xml';
  	$old_file = file_exists( $xml_file );
  	if ( $old_file ) {
  	 $this->load();
  	}
    $result = $this->save();
    return $result;
  }
  
  function _compare_f( $f1, $f2 ) {
    global $lg_gallery;
    switch ( $lg_gallery->get_option( 'sort_alphabetically' ) ) {
      case 'TRUE' : $id = 'curdir';
        break;
      case 'FALSE' : $id = 'datetime';
        break;
      case 'MANUAL' : $id = 'order';
        break;  
    }       
    if ( $f1->$id == $f2->$id ) {
      return 0;
    }    
    return ( $f1->$id < $f2->$id) ? -1 : 1; 
  }  
  
  /**
   * LazyestFolder::subfolders()
   * 
   * @param string $show
   * @return
   */
  function subfolders( $show='hidden' ) {
    global $lg_gallery;
    if  ( !$this->valid() ) {
      return false;
    }
    $location = $lg_gallery->root . $this->curdir;
    
	 	$flist = array();
		if ( $dir_content = opendir( $location ) ) {  
			while ( false !== ( $dir_file = readdir( $dir_content ) ) ) {
        if ( is_dir( $location . $dir_file ) ) {
          $subfolder = new LazyestFolder( $this->curdir . $dir_file );
          if ( $subfolder->valid() ) {
            $subfolder->open();      
            if ( ( ( $show == 'hidden') && ( $subfolder->visibility == 'hidden' ) ) || ( $subfolder->visibility == 'visible' ) ) {
              $flist[] = $subfolder;
            }            
          }
        }  			 
			}
		} else {
	    return false;
		}
    return ( usort( $flist, array( &$this, '_compare_f' ) ) ) ? $flist : false;
  }
  
  /**
   * LazyestFolder::list_folders()
   * 
   * @param string $show
   * @param string $text
   * @param string $link
   * @return void
   */
  function list_folders( $show='visible', $text='title', $link='frontend' ){
    global $lg_gallery;
    if ( $folders = $this->subfolders( $show ) ) {
      if ( 0 < count( $folders ) ) {
        foreach( $folders as $folder ) {          
          $folder->open();
          echo "\n<ul>\n";       
          $title = ( 'title' == $text ) ? $folder->title() : $folder->dirname();
          $href = ( 'frontend' == $link ) || ( 'widget' == $link ) ? $folder->uri( $link ) : 'admin.php?page=lazyest-filemanager&amp;folder=' . lg_nice_link( $folder->curdir );             
          echo "<li><a href=\"$href\">$title</a>";
          if ( 'admin' == $link ) {
            echo " (" . $folder->count() . __(' Images)',  $lg_gallery->text_domain );
          }
          $folder->list_folders( $show, $text, $link );
          echo "</li>\n";
          echo "</ul>\n";   
        }
      }
    } 
  } 
  
  
  /**
   * LazyestFolder::user_can_access()
   * 
   * @return
   */
  function user_can_access() {
    global $lg_gallery;
    if ( !$this->valid() ) {
      return false;
    }
  	$upper_level = explode( '/', $this->curdir );
  	for ( $i = 0; $i < ( count( $upper_level ) -2 ); $i++ ) {
  		$top .= trailingslashit( $upper_level[$i] );
  	}
  	if ( 0 == count( $this->roles ) ) $this->roles[] = 'everyone';
  	
  	$access_folder = in_array( 'everyone', (array) $this->roles );
  	
  	if ( !$access_folder ) {
  		foreach ( $this->roles as $role ) {
  			if ( current_user_can( $role ) ) $access_folder = true;
  		}
  	}
  	
    $access_top = true;
    if ( '' != $top ) {
      $top_folder = new LazyestFolder( $top );
      $access_top = $top_folder->user_can_access();
      unset( $top_folder );
    }
  	return ( $access_folder && $access_top ); 
  }
  
  /**
   * LazyestFolder::_subimages()
   * 
   * @param mixed $folders
   * @param mixed $folder
   * @return
   */
  function _subimages( $folders, $folder ) {
    $subfolders = $folder->subfolders();  
    if ( 0 < count( $subfolders ) ) {
      foreach ( $subfolders as $subfolder ) {          
        if ( 'visible' == $subfolder->visibility ) {
          $folders[] = $subfolder;
          $folders = $this->_subimages( $folders, $subfolder );
        }
      }
    }
    return $folders;
  }
  
  /**
   * LazyestFolder::random_image()
   * 
   * @param string $sub
   * @param integer $count
   * @return
   */
  function random_image( $sub = 'root', $count = 1 ) {
    $this->load( 'thumbs' );
    $random_list = isset ( $this->list ) ? $this->list : array(); 
    $folders = $this->subfolders('visible');    
    if ( 'subfolders' == $sub ) {
      $folders = $this->_subimages( $folders, $this );
      if ( 0 < count( $folders ) ) {     
        foreach ( $folders as $folder ) {
          $folder->load( 'thumbs' );
          if ( 0 < count( $folder->list ) ) {
            foreach ( $folder->list as $image ) {
              $random_list[] = $image;
            }
          }
          unset( $folder->list );
        }
      }
    }  
    $images_list = array();
    if ( 0 < count( $random_list ) ) {
      $count = ( $count > count( $random_list ) ) ? count( $random_list ) : $count;
      $counted = 0;
      if ( 1 == $count ) {
        $images_list[] = $random_list[array_rand( $random_list )]; 
      } else {         
 	      while ( ( $counted < $count ) && ( 0 < count( $random_list ) ) ) { 
 	        $key = array_rand( $random_list ); 
          $images_list[] = $random_list[$key]; 
 	        $counted++;          
 	        unset( $random_list[$key] ); 
        }
      } 
		}     
    return $images_list;
  }
  
  /**
   * LazyestFolder::single_image()
   * 
   * @param mixed $filename
   * @return
   */
  function single_image( $filename, $what = 'images' ) {
    $single_image = false;
    $this->load( $what );
    if ( 0 < count( $this->list ) ) {
      foreach ( $this->list as $image ) {
        if ( $image->valid() && ( $image->image == $filename ) ) {
          $single_image = $image;
          break;
        }
      }
    }  
    return $single_image;
  }
  
  function icon() {
  	global $lg_gallery;
  	
  	$folder_icon = array();    
    
    if ( !$this->user_can_access() ) {
      $folder_icon['icon'] = $lg_gallery->plugin_url . '/images/folder-na.png';
      return $folder_icon;
    }
    
  	$dir_parts = explode( '/', untrailingslashit( $this->curdir ) );
  	$fil = $dir_parts[ count( $dir_parts ) -1 ];
  		
  	$default_icon = $lg_gallery->plugin_url . '/images/folder-icon.png';
  	
  	$the_icon = $default_icon;
  	$folder_icon['class'] = 'icon';
    $exts = array( '.gif', '.jpg', '.jpeg', '.png' );
    $the_ext = '';
  	switch( $lg_gallery->get_option( 'folder_image' ) ) {
  		case 'icon':		
  			$folder_icon['icon'] = $the_icon;	
        $stub = $lg_gallery->root . $this->curdir . $fil;
        $stuba = $lg_gallery->address . $this->curdir . $fil;
        foreach( $exts as $ext ) {  
          if ( file_exists( $stub . $ext ) ) {
            $the_ext = $ext;
          }
          if ( file_exists( $stub . strtoupper( $ext ) ) )
            $the_ext = strtoupper( $ext );
        }
  			if ( '' != $the_ext ) {
  			  $thumb = new LazyestThumb( $this );
          $thumb->image = $fil . $the_ext; 
          $folder_icon['icon'] = $thumb->src();
  				$folder_icon['class'] = 'category_icon';
          unset( $thumb );
  			}	
  		break;
  	
  		case 'random_image':
  			$folder_icon['icon'] = $default_icon;
  			$folder_icon['class'] = 'random_image';
        $sub = ( 'TRUE' == $lg_gallery->get_option( 'random_subfolder' ) ) ? 'subfolders' : 'root';
        $images = $this->random_image( $sub ); 
        if ( 0 < count( $images ) ) {          
          $thumb = $images[0];
          $folder_icon['icon'] = $thumb->src();
          unset( $thumb );
        }
  			break;  
  	}	
  	return $folder_icon;
  }
    
} // LazyestFolder

/**
 * LazyestXMLParser xml parser class
 * 
 * @access public
 */
class LazyestXMLParser {

	var $arrOutput = array();
	var $resParser;
	var $strXmlData;

	/**
	 * LazyestXMLParser::parse()
	 * 
	 * @param mixed $strInputXML
	 * @return
	 */
	function parse($strInputXML) {
		$this->resParser = xml_parser_create ();
		xml_parser_set_option($this->resParser, XML_OPTION_TARGET_ENCODING, 'UTF-8');
		xml_set_object($this->resParser,$this);
		xml_set_element_handler($this->resParser, "tagOpen", "tagClosed");

		xml_set_character_data_handler($this->resParser, "tagData");

		$f = fopen( $strInputXML, 'r' );
		$readok = true;
		
		while( ( $data = fread( $f, 4096 ) ) && $readok ) {
			$this->strXmlData = xml_parse($this->resParser,$data );
			if(!$this->strXmlData) {
				printf("XML error: %s at line %d in file %s <br />" ,
					xml_error_string(xml_get_error_code($this->resParser)),
					xml_get_current_line_number($this->resParser),
					$strInputXML );
				$readok = false;
			}
		}
		xml_parser_free($this->resParser);
		
		if ( $readok ) {
			return $this->arrOutput;
		} else {
			return NIL;
		}
	}
	/**
	 * LazyestXMLParser::tagOpen()
	 * 
	 * @param mixed $parser
	 * @param mixed $name
	 * @param mixed $attrs
	 * @return
	 */
	function tagOpen($parser, $name, $attrs) {
	
		$tag=array("name"=>$name,"attrs"=>$attrs);
		array_push($this->arrOutput,$tag);
	}

	/**
	 * LazyestXMLParser::tagData()
	 * 
	 * @param mixed $parser
	 * @param mixed $tagData
	 * @return
	 */
	function tagData($parser, $tagData) {
		if(trim($tagData)) {
			if(isset($this->arrOutput[count($this->arrOutput)-1]['tagdata'])) {
				$this->arrOutput[count($this->arrOutput)-1]['tagdata'] .= $tagData;
			}
			else {
				$this->arrOutput[count($this->arrOutput)-1]['tagdata'] = $tagData;
			}
		}
	}

	/**
	 * LazyestXMLParser::tagClosed()
	 * 
	 * @param mixed $parser
	 * @param mixed $name
	 * @return
	 */
	function tagClosed($parser, $name) {
		$this->arrOutput[count($this->arrOutput)-2]['children'][] = $this->arrOutput[count($this->arrOutput)-1];
		array_pop($this->arrOutput);
	}
} // LazyestXMLParser
?>