<?php
/**
 * LazyestFrontend class
 * This class contains all functions and actions required for Lazyest Gallery to work on the frontend of WordPress
 * 
 * @package Lazyest-Gallery  
 * @author Marcel Brinkkemper
 * @copyright 2008-2010 Marcel Brinkkemper
 * @since 0.16.0
 * 
 */
 
class LazyestFrontend extends LazyestGallery {
  
  var $slideshows;
  
  var $comment;
  
  function LazyestFrontend() {
    $this->__construct();
  }  
  
  function __construct() {    
    LazyestGallery::__construct();
    
    $this->nr_shows = 0;    
    $this->slideshow = $this->comment = '';
    
    add_action('wp_head', array( &$this, 'styles' ), 7 );
    add_action('wp_head', array( &$this, 'scripts' ), 1);  
        
    add_filter('query_vars', array( &$this, 'query_vars' ) );
    
    add_shortcode('lg_folder', array( &$this, 'folder_code' ) );
    add_shortcode('lg_gallery', array( &$this, 'gallery_code' ) );
    add_shortcode('lg_image', array( &$this, 'image_code' ) );
    add_shortcode('lg_slideshow', array( &$this, 'slideshow_code' ) ); 
    $structure = get_option( 'permalink_structure' );    
    if ( ( 0 < strlen( $structure ) ) && ( 0 == strpos( $structure, 'index.php' ) ) && ( 'TRUE' == $this->get_option( 'use_permalinks' ) ) ) {
      add_action('generate_rewrite_rules', array( &$this, 'rewrite_rules' ) );
      add_action('init', array( &$this, 'flush_rules' ) );
    }
    add_filter('wp_title', array( &$this, 'wp_title' ) );    
  }
  
  /**
   * LazyestFrontend::rewrite_rules()
   * 
   * @param mixed $rules
   * @return void
   */
  function rewrite_rules( $rules ) {
    global $wp_rewrite;
    if ( 0 == strlen( $this->get_option( 'gallery_prev'  ) ) ) return; 
    $sitelen = strlen( get_option( 'siteurl' ) ) + 1;
    $page_path = untrailingslashit( substr( $this->get_option( 'gallery_prev' ), $sitelen ) );
    $new_rules = array( "$page_path/(.+)" => "index.php?pagename=$page_path&file=" . $wp_rewrite->preg_index( 1 ) );   
    $wp_rewrite->rules = $new_rules + $wp_rewrite->rules;
  }
  
  /**
   * LazyestFrontend::query_vars()
   * 
   * @param mixed $vars
   * @return
   */
  function query_vars( $vars ) { 
    $vars[] = 'file';
    $vars[] = 'lg_comment';
    $vars[] = 'lg_show';
    $vars[] = 'lg_diroffset';
    $vars[] = 'lg_offset';
    return $vars;
  }
  
  /**
   * LazyestFrontend::flush_rules()
   * 
   * @return void
   */
  function flush_rules() {	
    global $wp_rewrite;
   	$wp_rewrite->flush_rules();    
  }
  
  
  /**
   * LazyestFrontend::styles()
   * 
   * @return void
   */
  function styles() {
    $stylesheet =  $this->get_option( 'style_css' );
    if ( '' != $stylesheet ) {
      $styles[] = '/css/' . $stylesheet;
    } else {
      $styles[] = '/css/lazyest-style.css';
    }
    $styles[] = '/css/_slideshow.css';
    
    $i = 0;
    foreach( $styles as $style_css ) {
      if ( '' != $style_css ) {
        $style_url = $this->plugin_url . $style_css;
        $style_file = $this->plugin_dir . $style_css;
        $style_name = 'lazyest-style_' . $i;
        if ( file_exists( $style_file ) ) {
          wp_register_style( $style_name, $style_url );
          wp_enqueue_style( $style_name ); 
          $i++;    
        }
      }
    }
  }
  
  /**
   * LazyestFrontend::scripts()
   * 
   * @return void
   */
  function scripts() {
    if ( 'TRUE' == $this->get_option('allow_comments') ) {
      wp_enqueue_script( 'lg_gallery', $this->plugin_url . '/js/lazyest-gallery.js', array( 'jquery' ), LG_VERSION, true );
    }
    if ( 'TRUE' == $this->get_option( 'enable_exif' ) ) {
      wp_enqueue_script( 'jquery' );
    }
    if ( 'TRUE' == $this->get_option( 'enable_slide_show' ) ) {    
      wp_enqueue_script( 'slideshow', $this->plugin_url . '/js/lazyest-slideshow.js', array( 'jquery' ), LG_VERSION, true );
    }
  }
    
  /**
   * LazyestFrontend::valid()
   * Sets the path to folder or image from query var 'file''
   * Sets query var 'cpage' if comment-page is found in 'file;'
   * Handles other Lazyest Gallery query vars for commenting and slideshow
   * 
   * @param string $filevar : path to check if it is a valid gallery folder or image
   * @return bool true or false
   */
  function valid() { 
    global $file, $lg_comment, $lg_show, $wp_query; // will be set by wordpress query_vars
    if ( isset( $file ) ) {
      $file = stripslashes( $file );
      $this->file = stripslashes( $file ); // $file is urldecoded
    } else {
      if ( isset( $_GET['file'] ) ) {   
        $this->file = stripslashes( rawurldecode( $_GET['file'] ) ); // $_GET is not urldecoded
      } 
    }         
    $comment_pos = strpos( $this->file, 'comment-page-' );
    if ( $comment_pos !== false ) {
      $comment_page = substr( $this->file, $comment_pos + 13 );
      set_query_var( 'cpage', $comment_page );
      $this->file = substr( $this->file, 0, $comment_pos );
    }             
    if ( isset( $lg_comment ) ) {      
       $this->comment = $lg_comment;
    } else {  
     if ( isset( $_GET['lg_comment'] ) ) {
       $this->comment = $_GET['lg_comment'];
     }
    }
    if ( isset( $lg_show ) ) {
      $this->slideshow = $lg_show;
    } else {     
      if ( isset( $_GET['lg_show'] ) ) {
        $this->slideshow = $_GET['lg_show'];
      } 
    }
    // validate dir
    if ( strstr( $this->file, '..' ) || strstr( $this->file, '%2e%2e' ) ) {      
      return false; 
    }
    // check wether the file exists and can be read
    if ( !is_readable( $this->root . $this->file ) ) {
      return false;
    }   
    if ( '' != $this->file ) {    
      if ( is_dir( $this->root . $this->file ) ) {     
        $folder = new LazyestFolder( $this->file );
        $valid = $folder->valid(); 
        unset( $folder );
        if ( false === $valid ) {
          return false;          
        }
      } else if ( 0 == preg_match( "/.*\.(jpg|gif|png|jpeg)/i", $this->file ) ) {                 
        return false;
      }
    }
    
    $path = pathinfo( $this->file );
    $this->currentdir = ( is_dir( $this->root . $this->file ) ) ? ltrim( $this->file, '/' ) :  trailingslashit( ltrim( $path['dirname'], '/' ) );
    return true;
  }
   
  /**
   * LazyestFrontend::is_gallery()
   * 
   * @return
   */
  function is_gallery() {
  	$protocol = 'http' . ( ( isset( $_SERVER['HTTPS'] ) && ( 'on' == strtolower( $_SERVER['HTTPS'] ) ) ) ? 's' : '') . '://';
  	$server = isset( $_SERVER['HTTP_HOST'] ) ? $_SERVER['HTTP_HOST'] : $_SERVER['SERVER_NAME'];
  	$current_uri = $protocol . $server . $_SERVER['REQUEST_URI'];
    if ( ( $this->get_option( 'use_permalinks' ) == 'TRUE' ) && ( strlen( get_option( 'permalink_structure' ) ) > 0 ) ) {
      $gal = strpos( $current_uri, $this->get_option( 'gallery_prev' ) );
      return ( false === $gal ) ? false : true;
    } else {
      if ( function_exists( 'is_page' ) ) {
        return is_page( $this->get_option( 'gallery_id' ) );
      } else {  
        return false;
      }
    }	
  }
  
  /**
   * LazyestFrontend::folder_code()
   * 
   * @param mixed $atts
   * @return
   */
  function folder_code( $atts ) {
    global $file;
    extract( shortcode_atts( array( 'folder' => '', 'count' => $this->get_option( 'thumbs_page' ), 'cols' => $this->get_option( 'thumbs_columns' ), 'paging' => 'false' ), $atts ) );
    $folder = ltrim( $folder, '/' );
    $folder = trailingslashit( $folder );
    $folder_code = __( 'Lazyest Gallery cannot access ', $this->text_domain ) . $folder;    
    $paging = strtolower( $paging );
    $the_folder = new LazyestFrontendFolder( $folder );
    $this->valid(); // set $this->file     
    if ( $the_folder->valid() ) {
      ob_start();
    ?>
		<div class="lg_gallery">
      <?php      
      if ( isset( $file ) && $this->is_image( $this->file ) ) {
        $the_folder->show_slide( basename( $this->file ) );
      } else {
        $the_folder->show_thumbs( $count, $cols, $paging );
      } 
      ?>
    </div>        
    <?php
      $folder_code = ob_get_contents();
      ob_end_clean();
    }
    unset( $the_folder );
    return $folder_code;
  }
  
  /**
   * LazyestFrontend::gallery_code()
   * 
   * @param mixed $atts
   * @return
   */
  function gallery_code( $atts ) {
    ob_start();
    $show = ( !isset( $this->file ) ) ? true : $this->valid();       
    if ( $show === false ) {
      ?>
      <div class="error">
        <p><strong><?php echo  __( 'Something went wrong initializing Lazyest Gallery.', $this->text_domain ); ?></strong></p>
        <p><?php echo __( 'Maybe the folder or the image you are looking for does not exist',$this->text_domain ); ?></p>
        <p>
      <?php 
        _e( 'Please check your settings, ', $this->text_domain ); 
        if ( current_user_can( 'manage_options' ) ) {
          ?>
          <a href="<?php echo get_option( 'siteurl' ); ?>/wp-admin/admin.php?page=lazyest-gallery"><?php _e(' here,', $this->text_domain); ?></a>
          <?php
        }
        _e( ' or contact the author of this page ', $this->text_domain );
      ?>      
        </p>
      </div>
      <?php 
    } else {    
      $this->show();                  
    } 
    $new_content = ob_get_contents();
    ob_end_clean();
    return $new_content;
  }
  
  /**
   * LazyestFrontend::image_code()
   * 
   * @param mixed $atts
   * @return
   */
  function image_code( $atts ) {
    
    extract( shortcode_atts ( array( 'folder' => '', 'image' => '', 'align' => '', 'width' => '', 'height' => '', 'caption' => '', 'display' => 'thumb'), $atts));
    
    $folder = trailingslashit( $folder );    
    $image_code = __( 'Lazyest Gallery cannot access ', $this->text_domain );
    $image_code .= $folder;
    if ( is_readable( $this->root . $folder ) ) {
      $ifolder = new LazyestFolder( $folder );
      $the_image = $ifolder->single_image( $image );
      if ( false === $the_image ) {
        $image_code = __( 'Lazyest Gallery cannot find ', $this->text_domain );
        $image_code .= $image;
      } else {  
        $slide = new LazyestSlide( $ifolder );
        $slide->image = $the_image->image;      
        $img_link = $slide->on_click();
        switch( $display ) {
          case 'slide' :
            $img_src = $slide->src();
            break; 
          case 'thumb' :
            $thumb = new LazyestThumb( $ifolder );
            $thumb->image = $the_image->image;   
            $img_src = $thumb->src();
            $img_link = $thumb->on_click( 'widget' );
            unset( $thumb );
            break;
         case 'image' :  
            $img_src = $the_image->src();
            break;  
        }
        $image_link = '';        
        unset( $slide );
        unset( $ifolder );
        
        $image_code = '<div class="lg_image" style="';
        if ( 'left' == $align ) {
            $image_code .= 'float:left;';
        } elseif ( 'right' == $align ) {
            $image_code .= 'float:right;';
        } elseif ( 'center' == $align ) {
            $image_code .= 'margin-left:auto;margin-right:auto;';
        }
        if ( '' != $width ) {
            $div_width = (int) $width;
        } else {
            $div_width = (int) $this->get_option( 'thumbwidth' );
        }
        $div_width += 16;
        $image_code .= 'width:' . strval( $div_width ) . 'px;';
        $image_code .= '"><div style="text-align:center">';        
        if ( '' != $width )
        $wcode = ( '' != $width ) ? ' width="' . $width . '" ' : '';
        $hcode = ( '' != $height ) ? ' height="' . $height . '" '  : '';
        $image_link = '<a href="' . $img_link['href'] . '" class="' . $img_link['class'] . '" rel="' . $img_link['rel'] . '" title="' . $the_image->title() . '" >';
        $image_link .= '<img src="' . $img_src . '" alt="' . $the_image->title . '" ' . $wcode . $hcode . ' /></a>';        
        $image_code .= $image_link;
        $image_code .= '</div><div class="thumb_caption">';
        if ( ( '' == $caption ) && ( 'TRUE' == $this->get_option( 'enable_captions' ) ) ) {
          $caption = $the_image->caption;
        }
        if ($caption != '') {
          $image_code .= $caption;
        }
        $image_code .= '</div></div>';
      }
      unset( $the_image );
    }
    return $image_code;
  }
 
  /**
   * LazyestFrontend::slideshow_code()
   * 
   * @param mixed $atts
   * @return
   */
  function slideshow_code($atts) {
    extract( shortcode_atts( array( 'folder' => '', 'display' => 'slide' ), $atts ) );
    $folder = ltrim( $folder, '/' );
    $folder = trailingslashit( $folder );  
    $slideshow_code = __( 'Lazyest Gallery cannot find images in ', $this->text_domain );
    $slideshow_code .= $folder;
    $sfolder = new LazyestFrontendFolder( $folder );
    if ( $sfolder->valid() ) {
        ob_start();
        echo "<div class='lg_gallery'>\n";
        $sfolder->slideshow( $display );
        echo "</div>\n";
        $slideshow_code = ob_get_contents();
        ob_end_clean();
    }
    return $slideshow_code;
  }

  
  /**
   * LazyestFrontend::show()
   * 
   * @param integer $count
   * @param integer $cols
   * @param bool $dirs
   * @return
   */
  function show( $count = 0, $cols = 0, $dirs = true ) { // builds main gallery page
    if ( 'TRUE' == $this->get_option( 'allow_comments' ) && ( '' == $this->comment ) && ( '' == $this->file ) ) { 
      echo "<script type=\"text/javascript\">lazyestGallery=true;</script>\n";
    }
    if ( '' != $this->file ) {      
      $folder = new LazyestFrontEndFolder( $this->currentdir );
      if ( !$folder->valid() ) {
        unset( $folder );
        return false;
      } else {
        $folder->open();
        $folder->load( 'thumbs' );
      }
    }
    ?>  
      <div class="lg_gallery">
    <?php  
    $this->create_navigation();                     
    $dcount = ( 0 == $count ) ? $this->get_option( 'folders_page' ) : $count;
    $dcols = ( 0 == $cols ) ?  $this->get_option( 'folders_columns' ) : $cols;
    if ( isset( $folder ) && ( 'true' == $this->slideshow ) ) {
      $folder->slideshow('slide');
    } else { 
      if ( !$this->is_image( $this->file ) ) { 
        $this->show_dirs( $folder, $dcount, $dcols ); // show (sub)folders
      }
      if ( isset( $folder ) ) {                      // not on the gallery root
        if ( is_dir( $this->root . $this->file ) ) { // it is a folder; show thumbnails  
          $count = ( 0 == $count ) ? $this->get_option( 'thumbs_page' ) : $count;
          $cols = ( 0 == $cols ) ?  $this->get_option( 'thumbs_columns' ) : $cols;
          $folder->show_thumbs( $count, $cols ); // show thumbs
        } else {                  
          $folder->show_slide( basename( $this->file ) ); // show slide page
        }
      }
    }
    unset( $folder );
    if ( current_user_can( 'manage_options' ) ) {
  ?>          
    <div class="lg_admin"> 
      <a href="<?php echo get_option( 'siteurl' ) . '/wp-admin/admin.php?page=lazyest-gallery'; ?>"><?php _e('&raquo; Lazyest Gallery Settings', $this->text_domain); ?></a>
    </div>
  <?php  
    }
    if ( 'TRUE' == $this->get_option( 'show_credits' ) ) {
  ?>  
    <div class="lg_powered">
      <div class="lgpow">
        <?php _e( 'Powered by ', $this->text_domain ); ?><a href="http://wordpress.org/extend/plugins/lazyest-gallery/">Lazyest Gallery <?php echo LG_VERSION; ?></a> - Copyright &copy; 2008-<?php echo date( 'Y' );  ?><a href="http://brimosoft.nl"> Brimosoft</a>
      </div>
    </div>
  <?php  
    }
  ?>  
  </div>
  <?php
  }
  
  /**
   * LazyestFrontend::create_navigation()
   * 
   * @return void
   */
  function create_navigation() {  
    $nav = split( '/', untrailingslashit( $this->currentdir ) );
    $path = pathinfo( $this->file );
    ?>  <div class="top_navigator">
    <?php echo __( ' Now viewing: ', $this->text_domain ); ?><a href="<?php echo get_option( 'siteurl' ); ?>"><?php echo bloginfo( 'name' ); ?></a> <span class="raquo">&raquo;</span> <a href="<?php echo $this->get_option( 'gallery_prev' ); ?>"><?php echo the_title(); ?></a><?php
    foreach ( $nav as $n ) {
      $current .= trailingslashit( $n );     
      $folder = new LazyestFrontendFolder( $current );
      echo ' <span class="raquo">&raquo;</span> <a href="' . $folder->uri() . '">' . $folder->title() . '</a> ';
      unset( $folder );
    }
    if ( !is_dir( $this->root . $this->file ) ) {
      $folder = new LazyestFolder( $this->currentdir );
      if ( $folder->valid() ) {
        $image =$folder->single_image( $path['basename'] );        
        echo ' <span class="raquo">&raquo;</span> <a href="#">' . $image->title() . '</a>';    
      }
      unset( $folder );
    }
    ?> 
      </div> 
    <?php
  }

  /**
   * LazyestFrontend::show_dirs()
   * 
   * @param integer $thumbs_page
   * @param integer $columns
   * @param string $paging
   * @return
   */
  function show_dirs( $folder, $thumbs_page = 0, $columns = 1, $paging = "true" ) {
    global $lg_diroffset;
  
    if ( isset( $folder ) && !$folder->user_can_access() ) {
      return;
    } else { 
      // gathering pagination infos
      if ( $thumbs_page != 0 && isset( $lg_diroffset ) ) {
        $lg_offset = floor( abs( intval( $lg_diroffset ) ) / $thumbs_page ) * $thumbs_page;
      } else {
        $lg_offset = 0;
      }
  
      $runonce = false;
      $col_count = 0;
      
      $structure = get_option( 'permalink_structure' );    
      if ( (  0 < strlen( $structure ) ) && ( 0 == strpos( $structure, 'index.php' ) ) && ( 'TRUE' == $this->get_option( 'use_permalinks' ) ) ) {
        $q = '?';
      } else {
        $q = ( '' != $this->file ) ? '&amp;' : '?';
      }     
      $folders = ( isset( $folder ) ) ? $folder->subfolders( 'visible' ) : $this->folders( 'root', 'visible' );
      $link_uri = ( isset( $folder ) ) ? $folder->uri() : $this->uri(); 
  
      if ( count( $folders ) > 0 ) {
        
        $div_height = (int) $this->get_option( 'thumbheight' ) + 2;
        $div_width = (int) $this->get_option( 'thumbwidth' ) + 2;  
        
        if ( 0 == $thumbs_page ) { // no pagination, display all
          $end = count( $folders );
          $lg_offset = 0;
        } else {
          $end = $thumbs_page + $lg_offset;
          if ( count( $folders ) < $end ) {
            $end = count( $folders );
          }
        }
        ?>  
        <!-- Lazyest Gallery <?php echo LG_VERSION; // please do not remove this line ?> -->
        <div class="folders">
    			<table summary="folders" class="dir_view">
            <tbody>
              <tr>
                <td colspan="<?php echo $columns; ?>" class="folder"><img class="lg_folders_img icon" src="<?php echo $this->plugin_url; ?>/images/folders.png" alt="folders" /> <span class="raquo">&raquo; </span><?php _e( "Folders", $this->text_domain ); ?></td>
              </tr>
              <tr>
        <?php
        $i = $lg_offset;
        while ( $i < $end ) {
          
          $folderi = $folders[$i];   
          if ( 'hidden' != $folderi->visibility ) {
            if ( 'none' != $this->get_option( 'folder_image' ) ) {
              $folderi_icon = $folderi->icon();                
            }
            if ( 'empty_folder' == $folderi_icon['class'] ) $div_height = '1';
          ?>    
                <td>
                  <div class="lg_thumb" style="width:<?php echo $div_width; ?>px">         
                    <div class="lg_folder_thumb_image" style="min-height:<?php echo $div_height; ?>px;">
                      <a class="fldrimg" href="<?php echo $folderi->uri(); ?>"><img src="<?php echo $folderi_icon['icon']; ?>" alt="folder icon" class="<?php echo $folderi_icon['class']; ?>" /></a>
                      <br />
                    </div>
            <?php
            ?>         
                  <div class="lg_thumb_caption">
                    <span class="fldrcaption"><?php echo lg_html( $folderi->caption() ) ?></span><br />
            <?php             
            $folderinum = $folderi->count();  
            $subfoldernum = 0;         
            switch ( $this->get_option( 'count_subfolders' ) ) {
              case 'separate' :
                $subfoldernum = $folderi->count( 'subfolders' ) - $folderinum;                
                break;
              case 'include' :
                $folderinum = $folderi->count( 'subfolders' );
                break;                
            }  
            ?>
                    <span class="lg_foldernum"><?php echo $folderinum . '&nbsp;' . $this->get_option( 'listed_as' ); ?></span><br />
            <?php
            if ( 0 < $subfoldernum ) {
            ?>        
                    <span class="lg_subfoldernum"><?php echo $subfoldernum . __( ' in folders' )  ?></span>
            <?php        
            }
            ?>
                  </div>
                </div>
              </td>
            <?php
            $col_count++;
            if ( ( $col_count / $columns ) == intval( $col_count / $columns ) ) {
            ?>  
            </tr> 
            <?php if ( $i+1 < $end ) {
            ?>
            <tr>
            <?php
              }
            }            
            $i++;
          } // not hidden
        } // foreach
        
        if ( ( $col_count / $columns ) != intval( $col_count / $columns ) ) {
          while ( ( $col_count / $columns ) != intval( $col_count / $columns )  ) {
        ?>
                <td></td>
        <?php
            $col_count++;
          }
        ?>  
              </tr>
        <?php } ?>       
            </tbody>
          </table>
          <br />
        <?php
          if ( $paging == "true" ) {
            // pagination navigatior code
            if ( $thumbs_page != 0 ) {
              $pages = ceil( sizeof( $folders ) / $thumbs_page );
        ?>      
          <div class="folder_pagination">
        <?php
              if ( $lg_offset > 0 ) {
        ?>
        <span class="prev"><a href="<?php echo $link_uri . $q . 'lg_diroffset=' . ( $lg_offset - $thumbs_page ); ?>"  title="<?php _e( 'previous folders', $this->text_domain ); ?>">&laquo; <?php _e( 'Prev', $this->text_domain ); ?></a></span>
        <?php
              }
              echo '<span class="pages">';
              if ( $pages > 1 ) {
                for ( $i = 1; $i <= $pages; $i++ ) {
                  if ( $lg_offset != ($i - 1) * $thumbs_page )
                    echo ' <a href="' . $link_uri . $q . 'lg_diroffset=' . ( $i - 1 ) * $thumbs_page . '" >' . $i . '</a> ';
                  else
                    echo " $i ";
                }
              }
              echo '</span>';
              if ( count($images) > ( $thumbs_page + $lg_offset ) ) {
                echo ' <span class="next"><a href="' . $link_uri . $q . 'lg_diroffset=' . $end . '"  title="next folders">' . __( 'Next', $this->text_domain ) . ' &raquo;</a></span> ';
              }
              ?>
          </div>
            <?php    
            }
            
            // end of pagination navigatior code
          }
        ?>  
        </div> <!-- folders -->
        <?php
      } // count folders
    } //end access
  }

  function wp_title( $title ) { 
    global $file;
  	if ( $this->is_gallery() && $this->valid() && ( '' != $this->currentdir ) ) {
  	
  		$tdirs = untrailingslashit( $this->currentdir );
  		$dirs = explode( '/', $tdirs );  		
  		$tfile = '';
  		$gallery_title = '';
  		
  		foreach( $dirs as $dir ) {
  			$tfile .= $dir . '/';
  			if ( is_dir( $this->root . $tfile ) ) {  				
  				$ctitle = '';
  				if ( ( $dir != '' ) && ( 'TRUE' == $this->get_option( 'use_folder_captions' ) ) ) {
  				  $folder = new LazyestFrontendFolder( $tfile );
            if ( is_object( $folder ) ) {
              $folder->open();
    					$ctitle = $folder->title();
            }
  				}
  				if ( '' == $ctitle ) $ctitle = $dir;
  				$gallery_title .= ' &raquo; ' . $ctitle;
  			} 
  		}
  		
  		$ctitle ='';
  		if ( $this->is_image( $file ) && ( 'TRUE' == $this->get_option( 'enable_captions' ) ) ) {
  		  if ( is_object( $folder )) {  		   
    		  $folder->load( 'images' );
          $pathinfo = pathinfo( $file );
    			$image = $folder->single_image( $pathinfo['basename'] ); 
  		  }
  			if ( is_object( $image) ) $ctitle = $image->title();
  		}
  		
  		$gallery_title .= ' &raquo; ' . $ctitle . ' &raquo; ';	
  		$title .= substr( $gallery_title, 8, strlen( $gallery_title ) );
  	}
  	return $title;
  }
 
} // LazyestFrontend;


class LazyestFrontendFolder extends LazyestFolder {
  
  function load( $what = 'images' ) {
    global $lg_gallery;
    LazyestFolder::load( $what );    
    if (  ( 'icon' == $lg_gallery->get_option( 'folder_image' ) ) && ( 0 < count( $this->list ) ) ) {
      foreach( $this->list as $image ) {
        if ( $this->is_folder_icon( $image->image ) ) {
          unset( $this->list[ array_search( $image, $this->list )] );
          $this->list = array_values( $this->list ); 
        }
      }
    } 
  }
   
  /**
   * LazyestFrontendFolder::slideshow()
   * 
   * @param string $display. What to display in the slide show. Can be either 'slide', 'thumb', or 'image'
   * @return void
   */
  function slideshow( $display='slide' ) {		
  	global $lg_gallery;
  
  	if ( ( 'image' == $display ) && ( $lg_gallery->get_option( 'disable_full_size' ) == "TRUE" ) ) {
      $display = 'slide';
  	}
  	if ( !$this->user_can_access() ) {
  		?>
  		<p><?php _e( 'Sorry, you are not allowed to view this folder', $lg_text_domain ); ?> </p>
  		<?php
  	} else {
  		$gallery_uri = $lg_gallery->uri() ;
      switch ( $display ) {
        case 'slide' : $this->load('slides'); break;
        case 'thumb' : $this->load('thumbs'); break;
        case 'image' : $this->load('images'); break;
      }
  		$show_class = ( display == 'thumb' )? 'lg_sideshow' : 'lg_slideshow'; 
  		?>
  		<div class="<?php echo $show_class; ?>" id="lg_slideshow_<?php $lg_gallery->nr_shows++; echo $lg_gallery->nr_shows; ?>" >	
      <div class="lg_loading">Loading...</div>			
  		<?php
      $i= 0;     
      while ( $i < count( $this->list ) ) {        
        $slide = $this->list[$i];     
        $img_link = $slide->on_click();
        $img_src = $slide->src();        
        $acaption = '';
        if ( '' != $slide->caption ) {
          $acaption = '<h3>' . $slide->caption . '</h3>'; 
        }
        if ( '' != $slide->description ) {
          $adescription = '<p>' . $slide->description . '</p>';
        }   
        ?>
          <a id="<?php echo $img_link['id'] ?>" href="<?php echo $img_link['href'];  ?>" class="<?php echo $img_link['class']; ?>" rel="<?php echo $img_link['rel'] ?>">
          <img src="<?php echo $img_src; ?>" title="<?php echo $slide->title(); ?>" alt="<?php echo $slide->alt() ?>" rel="<?php echo $acaption . $adescription; ?> "/>
          </a>
          <?php
          $i++;
        } ?>  		
          <div class="sscaption" style="<?php if ( 'thumb' == $display ) echo "height:0px" ?>"></div>
        </div>
        <script type="text/javascript">lgSlideDuration = 5000;</script>
        <?php      
  	}
  }
  
  function _ssq() {
    global $lg_gallery;
    $structure = get_option( 'permalink_structure' ); 
    $wp_permalinks = (  0 < strlen( $structure ) ) && ( 0 == strpos( $structure, 'index.php' ) );
    $lg_permalinks = 'TRUE' == $lg_gallery->get_option( 'use_permalinks' );
    $q = $wp_permalinks ? ( $lg_permalinks ? '?' : '&' ) : '&';
    return $q;
  }
  
  function show_thumbs( $count = 0, $columns = 1, $paging = 'true' ) {		
    global $lg_gallery, $lg_offset;
  	if ( !$this->user_can_access() ) {
      ?>  	 
  		<p><?php _e('Sorry, you cannot browse this folder.', $this->text_domain); ?></p>
      <?php
      return false;
  	}
    $lg_offset = ( isset( $lg_offset ) ) ? $lg_offset : 0;
    // $lg_offset = ( ( $count != 0 && isset( $_GET['lg_offset'] ) && is_numeric( $_GET['lg_offset'] ) ) )  ? floor( abs( intval( $_GET['lg_offset'] ) ) / $count ) * $count : 0;
    $folder_caption = ( 'TRUE' == $lg_gallery->get_option('use_folder_captions') ) ? $this->caption : $this->dirname();

		$tcol_count = 0;
    if ( !isset( $this->list )  ) {
      $this->load( 'thumbs' );
    }
		
		if( 0 < count( $this->list ) ) {		
			$i = 0;
			while ( $i < $lg_offset ) { // pre cycle of anchor links for slideshow plugins
        $image = $this->list[$i];   
        $onclick = $image->on_click();
        ?>
        <a id="<?php echo $onclick['id']; ?>" href="<?php echo $onclick['href']; ?>" class="<?php echo $onclick['class']; ?>" rel="<?php $onclick['rel']; ?>" title="<?php echo $image->title(); ?>" ></a>
        <?php
				$i++;
			}
			
			$do_caption = ( 'TRUE' == $lg_gallery->get_option( 'enable_captions' ) ) && ( '-1' != $lg_gallery->get_option( 'captions_length' ) );
			if ( $do_caption ) {
			  $div_height = (int) $lg_gallery->get_option( 'thumbheight' ) + 20;
			} else {
				$div_height = 0;
			}
		?>
    <div class="lg_thumb_view">
			<table class="lazyest_thumb_view" summary="thumbs">
        <tbody>
          <tr>
            <td colspan="<?php echo $columns; ?>">
              <div class="folder_caption">		
                <h3><?php echo $this->title(); ?></h3>
              </div>
              <?php
              if ( '' != $this->description ) {
              ?>  
              <div class="folder_description"><p><?php echo lg_html(  $this->description ); ?></p></div>
              <?php  
              }   
		          ?>
            </td>
          </tr> 			
          <tr>
    <?php  		
			if( 0 == $count ) { // no pagination, display all
				$end = count( $this->list );
				$lg_offset = 0;
			}	else {
				$end = $count + $lg_offset ;
				if( count( $this->list ) < $end ){
					$end = count( $this->list );
				}
			}	  
      if ( 0 < count( $this->list ) ) {	
  			for ( $i = $lg_offset; $i < $end; $i++ ) { // main cycle
          
          $image = $this->list[$i];      
          if ( $image )$onclick = $image->on_click();                 
        ?>
  				        <td>
                    <div class="lg_thumb">
  				            <div class="lg_thumb_image" style="min-height: <?php echo $div_height . 'px;'?>">
                        <a id="<?php echo $onclick['id']; ?>" href="<?php echo $onclick['href']; ?>" class="<?php echo $onclick['class']; ?>" rel="<?php echo $onclick['rel']; ?>" title="<?php echo $image->title(); ?>" ><img class="thumb" src="<?php echo $image->src(); ?>" alt="<?php echo $image->alt(); ?>" /></a>                    
                      </div>
        <?php
  				if ( $do_caption ) {
  		  ?>
  				            <div class="lg_thumb_caption">
        <?php	
            $caption = $image->caption(); 
  					$max_length = (int) $lg_gallery->get_option( 'captions_length' );
  					if ( '0' != $lg_gallery->get_option( 'captions_length' ) )  {
  						if ( strlen( $caption ) > $max_length ) {
  							$caption = substr( $caption, 0, $max_length - 3 ) . '...';
  						}	
  					}
  					if ( $caption == '' ) $caption = '&nbsp;';
        ?>
                        <span title="<?php echo $image->title(); ?>" ><?php echo $caption; ?></span>       
                      </div>
        <?php
  				}
        ?>  
                    </div>
                  </td>
        <?php
  				$col_count++;
              if ( ( $col_count / $columns ) == intval( $col_count / $columns ) ) {
  		  ?>
                </tr>
                
        <?php if ( $i+1 < $end ) {
        ?>
                <tr>                 
        <?php         
            }
  				}
  				
  			} // for
      }	
			 if ( ( $col_count / $columns ) != intval( $col_count / $columns )  ) {   
          while ( ( $col_count / $columns ) != intval( $col_count / $columns )  ) {
        ?>
                <td></td>
        <?php
            $col_count++;
          }
    ?>  
              </tr>
    <?php 
        }
    ?>
            </tbody>
          </table>
		<?php	
			$i = $end++;
      while ($i < count( $this->list ) ) { // post cycle of anchor links for slideshow plugins
        $image = $this->list[$i];        
        $onclick = $image->on_click();
        ?>
        <a id="<?php echo $onclick['id']; ?>" href="<?php echo $onclick['href']; ?>" class="<?php echo $onclick['class']; ?>" rel="<?php $onclick['rel']; ?>" title="<?php echo $image->title(); ?>" ></a>
        <?php
				$i++;
			}
			
			if ( 'true' == $paging ) { // pagination's navigatior code
				if( 0 != $count ) { 
					$pages = ceil( sizeof( $this->list ) / $count );
    ?>      
          <div class="image_pagination">
    <?php      
					if( $lg_offset > 0 ){
		?>			 
						<span class="prev"><a href="<?php echo $this->uri() . $this->_ssq() . 'lg_offset=' . ( $lg_offset - $count ); ?>"  title="<?php _e( 'previous', $lg_gallery->text_domain ); ?>">&laquo; <?php _e('Prev', $this->text_domain); ?></a></span>
    <?php              
					}
         
	   	echo '<span class="pages">';
          
					if( $pages > 1){
						for($i = 1; $i <= $pages; $i++){
							if( $lg_offset != ($i-1) * $count ) {
               
					      echo '<a href="' . $this->uri() . $this->_ssq() . 'lg_offset=' . ( $i-1 ) * $count . '" > ' . $i . ' </a>';               
							} else {
								echo '&nbsp;' . $i . '&nbsp;';
              }  
						}
					}
          
					echo "</span>\n";
    
					if( count( $this->list ) > ( $count + $lg_offset ) ) {
		?>			 
					<span class="next"><a href="<?php echo $this->uri() . $this->_ssq() . 'lg_offset=' . $end; ?>"  title="<?php _e('next', $lg_gallery->text_domain ); ?>"><?php _e( 'Next', $this->text_domain ); ?> &raquo;</a></span>
    <?php            
					}
					if ( ( 'TRUE' == $lg_gallery->get_option( 'enable_slide_show' ) )  && $lg_gallery->is_gallery() ) {
		?>			 
					<a href="<?php echo $this->uri() . $this->_ssq() . 'lg_show=true'; ?>" class="lg_slideshow_button"><?php echo __( 'Slide Show', $this->text_domain ); ?></a>
    <?php      
					}
    ?>      
					</div>
    <?php      
				}
				// end of pagination's navigatior code
			}
    ?>	
    </div>
    <?php
		} // count images
    ?>
    <?php
		
		if ( current_user_can( 'manage_lazyest_files' ) ) { // admin links
    ?>  
				  <div class="lg_admin">
				    <a href="<?php echo get_option ( 'siteurl' ) . '/wp-admin/?page=lazyest-filemanager&amp;folder=' . $this->curdir; ?>"><?php echo '&raquo; ' . __( "Manage images and folder: ", $this->text_domain ) . '&quot;' .  untrailingslashit( $this->curdir ) . '&quot;'; ?></a>
				  </div>
    <?php      
		}
  }
  
  function show_slide( $filename ) {
    global $lg_gallery;
  	if ( !$this->user_can_access() ) {
    ?>	 
  		<p><?php _e("Sorry, you are not allowed to view this folder", $this->text_domain); ?></p>
    <?php  
  	} else {
      $this->load('slides');           
  		for ( $i = 0; $i < count( $this->list ); $i++ ) {
  		  $image = $this->list[$i];      
  			if( $image->image == $filename ) {          
  				if( 0 == $i ) {  				  
  					$previous = end( $this->list );
  				} else {
  					$previous = $this->list[$i-1];
  				}  			 
  				if( ( $i + 1 ) == count( $this->list ) ) {
  					$next = $this->list[0];
  				} else {
  					$next = $this->list[$i+1];
  				}
  				break;
  			}
  		};                    
      ?>  
  		<div class="lazyest_navigator">
		    <table style="width:100%;">
          <tbody>
            <tr>
              <td <?php if ( $lg_gallery->is_gallery ) echo 'id=lg_previous_id"'; ?>>
                <a href="<?php echo $previous->uri(); ?>" class="alignleft"><?php _e('&laquo; Previous', $this->text_domain); ?></a>
              </td>
              <td>
      <?php            
  					if ( ( $lg_gallery->get_option('enable_slide_show') == 'TRUE' ) && $lg_gallery->is_gallery() ) {
  		?>			 
  						  <a href="<?php echo $this->uri() . $this->_ssq() . 'lg_show=true'; ?>" class="lg_slideshow_button"><?php _e('Slideshow', $this->text_domain); ?></a>
      <?php } ?>        
  					
              </td>
              <td <?php  if ( $lg_gallery->is_gallery ) echo 'id="lg_next_id"';  ?>>
                <a href="<?php echo $next->uri(); ?>" class="alignright"><?php _e('Next &raquo;',$this->text_domain); ?></a>
              </td>
  					</tr>
          </tbody>
        </table>
  		</div>
      <div class="lazyest_image">
      <?php
  		if ( in_array( $lg_gallery->get_option( 'on_slide_click' ), array( 'lightbox', 'thickbox' ) ) ) { // add links for lightbox
  			$j = 0;
  			while ( $j < $i ) {
          $dummy = $this->list[$j];
          $onclick = $dummy->on_click();
        ?>
          <a id="<?php echo $onclick['id']; ?>" class="lg_dummy <?php echo $onclick['class'] ?>" title="<?php echo $onclick['title']; ?>"  href="<?php echo $onclick['href']; ?>" rel="<?php echo $onclick['rel']; ?>"></a>
        <?php          
  				$j++;
  			}
  		}
      $onclick = $image->on_click();
      ?>
        <a id="<?php echo $onclick['id'] ?>" class="slide <?php echo $onclick['class']; ?>" href="<?php echo $onclick['href'] ?>" title="<?php echo $onclick['title']; ?>" rel="<?php echo $onclick['rel']; ?>" id="<?php echo $onclick['id'] ?>">
          <img class="slide" id="<?php echo $image->html_id(); ?>" src="<?php echo $image->src(); ?>" alt="<?php echo $image->alt(); ?>" />
        </a>         
      <?php
  		
  		if ( in_array( $lg_gallery->get_option( 'on_slide_click' ), array( 'lightbox', 'thickbox' ) ) ) { // add links for lightbox
  			$j = $i + 1;
  			while ( $j < count( $this->list ) ) {
          $dummy = $this->list[$j];
          $onclick = $dummy->on_click();
        ?>
          <a id="<?php echo $onclick['id']; ?>" class="lg_dummy <?php echo $onclick['class'] ?>" title="<?php echo $onclick['title']; ?>"  href="<?php echo $onclick['href']; ?>" rel="<?php echo $onclick['rel']; ?>"></a>
        <?php          
  				$j++;
  			}
  		}  	      	
  		if ( '' != $image->caption ) {
  		?>  
  		  <div class="caption"><?php echo lg_html( $image->caption ); ?>&nbsp;</div>
      <?php  
  		}
      if ( '' != $image->description ) {
      ?>  
        <div class="description"><?php echo lg_html(  $image->description ); ?>&nbsp;</div>
      <?php  
      }   
  		?>
  		</div> <!-- lazyest image -->
      <?php
  
  		if( 'TRUE' == $lg_gallery->get_option( 'enable_exif' ) ) {
  		  $this->show_exif( $filename );
  		}
  		if ( current_user_can( 'manage_lazyest_files' ) ) {
      ?>    
  		<div class='lg_admin'> 
        <a href="<?php echo get_option ( 'siteurl' ) . '/wp-admin/?page=lazyest-filemanager&amp;folder=' . $this->curdir . '#' . $image->form_name(); ?>"><?php echo '&raquo; ' . __( "Edit Image: ", $this->text_domain ) . '&quot;' . $image->image . '&quot;'; ?></a>
  		</div>
      <?php  
  		}
  	}
  }
  
    
  function _photo_getval( $image_info, $val_array ) {
    $info_val = 'Unknown';
    foreach( $val_array as $name=>$val ) {
      if ( $name == $imageinfo ) {
        $info_val = &$val;
        break;
      }
    }
    return $info_val;
  }
    
  /**
   * LazyestFrontendFolder::show_exif()
   * 
   * @param string $filename
   * @return void
   */
  function show_exif( $filename ) {
    global $lg_gallery;
    $image = $this->single_image( $filename );    
    $pathinfo = pathinfo( $filename );
        
    $imgtype = array( '', 'GIF', 'JPG', 'PNG', 'SWF', 'PSD', 'BMP', 'TIFF(intel byte order)', 'TIFF(motorola byte order)', 'JPC', 'JP2', 'JPX', 'JB2', 'SWC', 'IFF', 'WBMP', 'XBM');

    $orientation = array('', 'top left side', 'top right side', 'bottom right side', 'bottom left side', 'left side top', 'right side top', 'right side bottom', 'left side bottom');

    $resolution_unit = array('', '', 'inches', 'centimeters');

    $ycbcr_positioning = array('', 'the center of pixel array', 'the datum point');
    
    $exposure_program = array(
      __('Not defined', $lg_gallery->text_domain ),
      __( 'Manual', $lg_gallery->text_domain ), 
      __( 'Normal program', $lg_gallery->text_domain ), 
      __( 'Aperture priority', $lg_gallery->text_domain ), 
      __( 'Shutter priority', $lg_gallery->text_domain ), 
      __( 'Creative program (biased toward depth of field)', $lg_gallery->text_domain ), 
      __( 'Action program (biased toward fast shutter speed)', $lg_gallery->text_domain ), 
      __( 'Portrait mode (for closeup photos with the background out of focus)', $lg_gallery->text_domain ), 
      __( 'Landscape mode (for landscape photos with the background in focus)', $lg_gallery->text_domain )
    );

    
    $metering_mode = array(
      '0' => __( 'Unknown', $lg_gallery->text_domain ),
      '1' => __( 'Average', $lg_gallery->text_domain ),
      '2' => __( 'Center Weighted Average', $lg_gallery->text_domain ),
      '3' => __( 'Spot', $lg_gallery->text_domain ),
      '4' => __( 'MultiSpot', $lg_gallery->text_domain ),
      '5' => __( 'Pattern', $lg_gallery->text_domain ),
      '6' => __( 'Partial', $lg_gallery->text_domain ),
      '255' =>__( 'Other Metering Mode', $lg_gallery->text_domain )
    );
    
    $light_source = array(
      '0' => __( 'unknown', $lg_gallery->text_domain ),
      '1' => __( 'Daylight', $lg_gallery->text_domain ),
      '2' => __( 'Fluorescent', $lg_gallery->text_domain ),
      '3' => __( 'Tungsten (incandescent light)', $lg_gallery->text_domain ),
      '4' => __( 'Flash', $lg_gallery->text_domain ),
      '9' => __( 'Fine weather', $lg_gallery->text_domain ),
      '10' => __( 'Cloudy weather', $lg_gallery->text_domain ),
      '12' => __( 'Daylight fluorescent (D 5700  7100K)', $lg_gallery->text_domain ),
      '13' => __( 'Day white fluorescent (N 4600  5400K)', $lg_gallery->text_domain ),
      '14' => __( 'Cool white fluorescent (W 3900  4500K)', $lg_gallery->text_domain ),
      '15' => __( 'White fluorescent (WW 3200  3700K)', $lg_gallery->text_domain ),
      '17' => __( 'Standard light A', $lg_gallery->text_domain ),
      '18' => __( 'Standard light B', $lg_gallery->text_domain ),
      '19' => __( 'Standard light C', $lg_gallery->text_domain ),
      '20' => __( 'D55', $lg_gallery->text_domain ),
      '21' => __( 'D65', $lg_gallery->text_domain ),
      '22' => __( 'D75', $lg_gallery->text_domain ),
      '23' => __( 'D50', $lg_gallery->text_domain ),
      '24' => __( 'ISO studio tungsten', $lg_gallery->text_domain ),
      '255' => __( 'other light source', $lg_gallery->text_domain )
    );
    
    $flash = array(
      '0' => __( 'Flash did not fire.', $lg_gallery->text_domain ),
      '1' => __( 'Flash fired.', $lg_gallery->text_domain ),
      '5' => __( 'Strobe return light not detected.', $lg_gallery->text_domain ),
      '7' => __( 'Strobe return light detected.', $lg_gallery->text_domain ),
      '9' => __( 'Flash fired, compulsory flash mode', $lg_gallery->text_domain ),
      '13' => __( 'Flash fired, compulsory flash mode, return light not detected', $lg_gallery->text_domain ),
      '15' => __( 'Flash fired, compulsory flash mode, return light detected', $lg_gallery->text_domain ),
      '16' => __( 'Flash did not fire, compulsory flash mode', $lg_gallery->text_domain ),
      '24' => __( 'Flash did not fire, auto mode', $lg_gallery->text_domain ),
      '25' => __( 'Flash fired, auto mode', $lg_gallery->text_domain ),
      '29' => __( 'Flash fired, auto mode, return light not detected', $lg_gallery->text_domain ),
      '31' => __( 'Flash fired, auto mode, return light detected', $lg_gallery->text_domain ),
      '32' => __( 'No flash function', $lg_gallery->text_domain ),
      '65' => __( 'Flash fired, red-eye reduction mode', $lg_gallery->text_domain ),
      '69' => __( 'Flash fired, red-eye reduction mode, return light not detected', $lg_gallery->text_domain ),
      '71' => __( 'Flash fired, red-eye reduction mode, return light detected', $lg_gallery->text_domain ),
      '73' => __( 'Flash fired, compulsory flash mode, red-eye reduction mode', $lg_gallery->text_domain ),
      '77' => __( 'Flash fired, compulsory flash mode, red-eye reduction mode, return light not detected', $lg_gallery->text_domain ),
      '79' => __( 'Flash fired, compulsory flash mode, red-eye reduction mode, return light detected', $lg_gallery->text_domain ),
      '89' => __( 'Flash fired, auto mode, red-eye reduction mode', $lg_gallery->text_domain ),
      '93' => __( 'Flash fired, auto mode, return light not detected, red-eye reduction mode', $lg_gallery->text_domain ),
      '95' => __( 'Flash fired, auto mode, return light detected, red-eye reduction mode', $lg_gallery->text_domain )
    );
    
    $exif = @exif_read_data( $lg_gallery->root . $this->curdir . $image->image, 0, true );  
    $img_info = array ( 
      __( 'Artist', $lg_gallery->text_domain ) => $exif['IFD0']['Artist'], 
      __( 'FileType', $lg_gallery->text_domain ) => $imgtype[$exif['FILE']['FileType']], 
      __( 'MimeType', $lg_gallery->text_domain ) => $exif['FILE']['MimeType'], 
      __( 'FileSize', $lg_gallery->text_domain ) => ( floor( $exif['FILE']['FileSize'] / 1024 * 10 ) /10 ) . 'KB', 
      __( 'FileDateTime', $lg_gallery->text_domain ) => date( 'Y-m-d  H:i:s', $exif['FILE']['FileDateTime'] ), 
      __( 'Make', $lg_gallery->text_domain ) => $exif['IFD0']['Make'], 
      __( 'Model', $lg_gallery->text_domain ) => $exif['IFD0']['Model'], 
      __( 'DateTime', $lg_gallery->text_domain ) => $exif['IFD0']['DateTime'], 
      __( 'ExifVersion', $lg_gallery->text_domain ) => $exif['EXIF']['ExifVersion'], 
      __( 'DateTimeOriginal', $lg_gallery->text_domain ) => $exif['EXIF']['DateTimeOriginal'], 
      __( 'DateTimeDigitized', $lg_gallery->text_domain ) => $exif['EXIF']['DateTimeDigitized'], 
      __( 'Height', $lg_gallery->text_domain ) => $exif['COMPUTED']['Height'] . 'px', 
      __( 'Width', $lg_gallery->text_domain ) => $exif['COMPUTED']['Width'] . 'px', 
      __( 'CompressedBitsPerPixel', $lg_gallery->text_domain ) => $exif['EXIF']['CompressedBitsPerPixel'] . 'Bits/Pixel', 
      __( 'FocusDistance', $lg_gallery->text_domain ) => !empty( $exif['COMPUTED']['FocusDistance'] ) ? $exif['COMPUTED']['FocusDistance'] . 'm' : NULL, 
      __( 'FocalLength', $lg_gallery->text_domain ) => !empty( $exif['EXIF']['FocalLength'] ) ? $exif['EXIF']['FocalLength'] . 'mm' : NULL, 
      __( 'FocalLengthIn35mmFilm', $lg_gallery->text_domain ) => !empty( $exif['EXIF']['FocalLengthIn35mmFilm'] ) ? $exif['EXIF']['FocalLengthIn35mmFilm'] . 'mm' : NULL, 
      __( 'ColorSpace', $lg_gallery->text_domain ) => ( $exif['EXIF']['ColorSpace'] == 1 ? 'sRGB' : 'Uncalibrated' ), 
      __( 'FileName', $lg_gallery->text_domain ) => $exif['FILE']['FileName'], 
      __( 'FileType', $lg_gallery->text_domain ) => $imgtype[$exif['FILE']['FileType']], 
      __( 'MimeType', $lg_gallery->text_domain ) => $exif['FILE']['MimeType'], 
      __( 'FileSize', $lg_gallery->text_domain ) => ( floor( $exif['FILE']['FileSize'] / 1024 * 10 )/10 ) . 'KB', 
      __( 'FileDateTime', $lg_gallery->text_domain ) => date( 'Y-m-d  H:i:s', $exif['FILE']['FileDateTime'] ), 
      __( 'ImageDescription', $lg_gallery->text_domain ) => $exif['IFD0']['ImageDescription'], 
      __( 'Orientation', $lg_gallery->text_domain ) => $orientation[$exif['IFD0']['Orientation']], 
      __( 'XResolution', $lg_gallery->text_domain ) => $exif['IFD0']['XResolution'] . $resolution_unit[$exif['IFD0']['ResolutionUnit']], 
      __( 'YResolution', $lg_gallery->text_domain ) => $exif['IFD0']['YResolution'] . $resolution_unit[$exif['IFD0']['ResolutionUnit']], 
      __( 'Software', $lg_gallery->text_domain ) => utf8_encode( $exif['IFD0']['Software'] ), 
      __( 'DateTime', $lg_gallery->text_domain ) => $exif['IFD0']['DateTime'], 
      __( 'Artist', $lg_gallery->text_domain ) => $exif['IFD0']['Artist'], 
      __( 'YCbCrPositioning', $lg_gallery->text_domain ) => $ycbcr_positioning[$exif['IFD0']['YCbCrPositioning']], 
      __( 'Copyright', $lg_gallery->text_domain ) => $exif['IFD0']['Copyright'], 
      __( 'Photographer', $lg_gallery->text_domain ) => $exif['COMPUTED']['Copyright . Photographer'], 
      __( 'Editor', $lg_gallery->text_domain ) => $exif['COMPUTED']['Copyright . Editor'], 
      __( 'ExifVersion', $lg_gallery->text_domain ) => $exif['EXIF']['ExifVersion'], 
      __( 'FlashPixVersion', $lg_gallery->text_domain ) => 'Ver' . number_format( $exif['EXIF']['FlashPixVersion']/100, 2 ), 
      __( 'DateTimeOriginal', $lg_gallery->text_domain ) => $exif['EXIF']['DateTimeOriginal'], 
      __( 'DateTimeDigitized', $lg_gallery->text_domain ) => $exif['EXIF']['DateTimeDigitized'], 
      __( 'Height', $lg_gallery->text_domain ) => $exif['COMPUTED']['Height'] . 'px', 
      __( 'Width', $lg_gallery->text_domain ) => $exif['COMPUTED']['Width'] . 'px', 
      __( 'ApertureValue', $lg_gallery->text_domain ) => $exif['EXIF']['ApertureValue'], 
      __( 'ShutterSpeedValue', $lg_gallery->text_domain ) => $exif['EXIF']['ShutterSpeedValue'], 
      __( 'ApertureFNumber', $lg_gallery->text_domain ) => $exif['COMPUTED']['ApertureFNumber'], 
      __( 'MaxApertureValue', $lg_gallery->text_domain ) => 'F' . $exif['EXIF']['MaxApertureValue'], 
      __( 'ExposureTime', $lg_gallery->text_domain ) => $exif['EXIF']['ExposureTime'], 
      __( 'F-Number', $lg_gallery->text_domain ) => $exif['EXIF']['FNumber'], 
      __( 'MeteringMode', $lg_gallery->text_domain ) => $this->_photo_getval( $exif['EXIF']['MeteringMode'], $metering_mode ), 
      __( 'LightSource', $lg_gallery->text_domain ) => $this->_photo_getval( $exif['EXIF']['LightSource'], $light_source ), 
      __( 'Flash', $lg_gallery->text_domain ) => $this->_photo_getval( $exif['EXIF']['Flash'], $flash ), 
      __( 'ExposureMode', $lg_gallery->text_domain ) => ( $exif['EXIF']['ExposureMode'] == 1 ? __( 'Manual exposure', $lg_gallery->text_domain ) : __( 'Auto exposure', $lg_gallery->text_domain ) ), 
      __( 'WhiteBalance', $lg_gallery->text_domain ) => ( $exif['EXIF']['WhiteBalance'] == 1 ? __( 'Manual white balance', $lg_gallery->text_domain ) : __( 'Auto white balance', $lg_gallery->text_domain ) ), 
      __( 'ExposureProgram', $lg_gallery->text_domain ) => $exposure_program[$exif['EXIF']['ExposureProgram']], 
      __( 'ExposureBiasValue', $lg_gallery->text_domain ) => $exif['EXIF']['ExposureBiasValue'] . 'EV', 
      __( 'ISOSpeedRatings', $lg_gallery->text_domain ) => $exif['EXIF']['ISOSpeedRatings'], 
      __( 'ComponentsConfiguration', $lg_gallery->text_domain ) => ( bin2hex( $exif['EXIF']['ComponentsConfiguration'] ) == '01020300' ? 'YCbCr' : 'RGB' ), 
      __( 'CompressedBitsPerPixel', $lg_gallery->text_domain ) => $exif['EXIF']['CompressedBitsPerPixel'] . 'Bits/Pixel', 
      __( 'FocusDistance', $lg_gallery->text_domain ) => $exif['COMPUTED']['FocusDistance'] . 'm', 
      __( 'FocalLength', $lg_gallery->text_domain ) => $exif['EXIF']['FocalLength'] . 'mm', 
      __( 'FocalLengthIn35mmFilm', $lg_gallery->text_domain ) => $exif['EXIF']['FocalLengthIn35mmFilm'] . 'mm', 
      __( 'UserCommentEncoding', $lg_gallery->text_domain ) => $exif['COMPUTED']['UserCommentEncoding'], 
      __( 'UserComment', $lg_gallery->text_domain ) => $exif['COMPUTED']['UserComment'], 
      __( 'ColorSpace', $lg_gallery->text_domain ) => ( $exif['EXIF']['ColorSpace'] == 1 ? 'sRGB' : __( 'Uncalibrated', $lg_gallery->text_domain ) ), 
      __( 'ExifImageLength', $lg_gallery->text_domain ) => $exif['EXIF']['ExifImageLength'], 
      __( 'ExifImageWidth', $lg_gallery->text_domain ) => $exif['EXIF']['ExifImageWidth'], 
      __( 'FileSource', $lg_gallery->text_domain ) => ( bin2hex( $exif['EXIF']['FileSource'] ) == 0x03 ? 'DSC' : __( 'unknown', $lg_gallery->text_domain ) ), 
      __( 'SceneType', $lg_gallery->text_domain ) => ( bin2hex( $exif['EXIF']['SceneType'] ) == 0x01 ? __( 'A directly photographed image', $lg_gallery->text_domain ) : __( 'unknown', $lg_gallery->text_domain ) ), 
      __( 'Thumbnail.FileType', $lg_gallery->text_domain ) => $exif['COMPUTED']['Thumbnail.FileType'], 
      __( 'Thumbnail.MimeType', $lg_gallery->text_domain ) => $exif['COMPUTED']['Thumbnail.MimeType']
    );
   
    ?>    
    <div class="imagedata">
      <p class="exifheader"><?php _e( 'Image data', $lg_gallery->text_domain ); ?></p>
      <?php
      if ( $exif ) {        
      ?>
      <table class="imagedatatable">
        <tbody>
          <tr>
            <th scope="row"><?php _e( 'Date', $lg_gallery->text_domain ); ?></th>
            <td><?php echo $img_info['FileDateTime']; ?></td>
          </tr>
          <tr>
            <th scope="row"><?php _e( 'Height' ); ?></th>
            <td><?php echo $img_info['Height']; ?></td>
          </tr>
          <tr>
            <th scope="row"><?php _e( 'Width' ); ?></th>            
            <td><?php echo $img_info['Width']; ?></td>
          </tr>
          <tr>
            <th scope="row"><?php _e( 'Camera' ); ?></th>            
            <td><?php echo $img_info['Make'] . ' - ' . $img_info['Model']; ?></td>
          </tr>
        </tbody>
      </table>
      <script type="text/javascript">function showExif(){jQuery('#all_exif').show();}</script>
      <a href="javascript:showExif();"><?php _e( 'Show all Exif data', $lg_gallery->text_domain ); ?></a>
      <table id="all_exif">
        <tbody>
        <?php 
        foreach( $img_info as $name => $val ) {
          if ( $val ) {
          ?>
          <tr>
            <th scope="row"><?php echo $name; ?></th>
            <td><?php echo $val; ?></td>
          </tr>
          <?php
          }
        }
        ?>
        </tbody>
      </table>   
    <?php
    } else {
      list($width, $height, $type, $attr) = getimagesize( $lg_gallery->root . $this->curdir . $image->image );
    ?> 
      <table class="imagedatatable">
        <tbody>
          <tr>
            <th scope="row"><?php _e( 'Date', $lg_gallery->text_domain ); ?></th>
            <td><?php echo date( get_option('date_format' ), filemtime( $lg_gallery->root . $this->curdir . $image->image ) ); ?></td>
            <th scope="row"><?php _e( 'Height' ); ?></th>
            <td><?php echo $height . 'px'; ?></td>
            <th scope="row"><?php _e( 'Width' ); ?></th>            
            <td><?php echo $width . 'px'; ?></td>
          </tr>
        </tbody>
      </table>   
    <?php
    }
    ?>
  </div>
  <?php  
  }
  
} // LazyestFrontendFolder
 
 ?>