<?php
/**
 * Template tags and functions for Lazyest Gallery
 * 
 * @package Lazyest-Gallery  
 * @author Marcel Brinkkemper
 * @copyright 2008-2010 Marcel Brinkkemper
 */
 
 
/**
 * lg_list_folders()
 * 
 * @param string $title
 * @return
 */
function lg_list_folders( $title ) {
  global $lg_gallery;
  if ( !isset( $lg_gallery ) ) {
    return false;
  }
  $disp =  ( 'TRUE' == $lg_gallery->get_option( 'use_folder_captions' ) ) ? 'title' : 'dirname';
  if ( $title != '' ) {
    ?>
    <h2><?php echo $title; ?></h2>
    <?php
  }
  $folders = $lg_gallery->folders( 'root', 'visible' );
  if ( 0 < count( $folders ) ) {
    ?><ul><?php
    foreach( $folders as $folder ) {
      $folder->open();
      ?>
      <li><a href="<?php echo $folder->uri( 'widget' ); ?>" title="<?php echo $folder->title(); ?>"><?php echo $folder->dirname(); ?></a>
      <?php $folder->list_folders( 'visible', $disp, 'widget' ); ?>
      </li>
      <?php 
    }
    ?></ul><?php
  }
}
 
 /**
 * lg_random_image() template tag to display random image
 * 
 * @param string $title
 * @param string $count
 * @param string $folder
 * @param bool $sub
 * @return
 */ 
function lg_random_image( $title, $count='1', $folder='', $sub=true ) {
  global $lg_gallery;
  if ( !isset( $lg_gallery ) ) {
    return false;
  }
  if ( '' == $folder ) $sub = true;
  $substr = $sub ? 'subfolders' : 'root';
  $count = intval( $count ); 
  $image_list = $lg_gallery->random_image( $folder, $substr, $count );
  if ( $title != '' ) {
    ?>
    <h2><?php echo $title; ?></h2>
    <?php
  }
  ?>
    <div class="lazyest_sidebox">
  <?php 
  foreach ( $image_list as $thumb ) {
    $onclick = $thumb->on_click( 'widget' );
    ?>
    <p class="lg_thumb_image">
      <a href="<?php echo $onclick['href']; ?>" title="<?php echo $thumb->title() ?>" rel="<?php echo $onclick['rel']; ?>" class="<?php echo $onclick['class'] ?>"><img class="thumb" src="<?php echo $thumb->src(); ?>" alt="<?php echo $thumb->alt(); ?>" /></a>
    </p>
    <?php
  }
  ?>
    </div>
  <?php
}


/**
 * lg_random_slideshow() slide show of random images (as a widget) in sidebar
 * 
 * @param string $title
 * @param string $count
 * @param string $display
 * @param string $folder
 * @param bool $sub
 * @return
 */
function lg_random_slideshow($title, $count='2', $display='5', $folder='', $sub=true ) {
   global $lg_gallery;
  if ( !isset( $lg_gallery ) ) {
    return false;
  }	
  if ( '' == $folders ) $sub = true;
  $substr = $sub ? 'subfolders' : 'root'; 
  $image_list = $lg_gallery->random_image( $folder, $substr, $count );
  
  if ( $title != '' ) {
    ?>
    <h2><?php echo $title; ?></h2>
    <?php
  }
  ?>
    <div class="lg_slideshow" id="lg_sideshow_<?php $lg_gallery->slideshows++; echo $lg_gallery->slideshows; ?>" > 
      <div class="lg_loading"><?php _e( 'Loading...', $lg_gallery->text_domain ); ?></div> 
  <?php
  foreach ( $image_list as $thumb ) {
    $onclick = $thumb->on_click( 'widget' );
    ?>
    <a id="<?php echo $onclick['id'] ?>" href="<?php echo $onclick['href']; ?>" title="<?php echo $thumb->title() ?>" rel="<?php echo $onclick['rel']; ?>" class="<?php echo $onclick['class'] ?>"><img class="thumb" src="<?php echo $thumb->src(); ?>" alt="<?php echo $thumb->alt(); ?>" /></a>
    <?php
  }
  ?>
    </div>    
    <script type="text/javascript">lgSlideDuration = 5000;</script>
  <?php  
}

/**
 * lg_nice_link()
 * encodes the URL but leaves slashes for nicer link in the gallery
 * 
 * @param string $alink 
 * @return string
 */
function lg_nice_link( $alink ) {
  return str_replace( '%2F', '/', rawurlencode( $alink ) );
}

/**
 * lg_html()
 * This function makes sure captions and desvriptions will be displayed with only the allowed html elements
 * 
 * @param mixed $astring
 * @return void
 */
function lg_html( $astring ) {
  $allowed_html = array( 'a' => array( 'href' => array(),'title' => array() ) );
  return wp_kses( stripslashes( $astring ), $allowed_html, array() );
}
?>