<?php
class LazyestImage {
  
  var $image; 
  
  var $caption;
  
  var $description;
  
  var $id;
  
  var $index;
  
  var $datetime;
  
  var $folder;
  
  var $_resized;
  
  function LazyestImage( $parent ) {
    $this->__construct( $parent );
  }
  
  function __construct( $parent ) {
    $this->image = $this->caption = $this->description = $this->id = $this->index = '';
    $this->folder = $parent;
  }
  
  function valid() {
    global $lg_gallery;
    return file_exists( $lg_gallery->root . $this->folder->curdir . $this->image );
  }
  
  /**
   * LazyestImage::src()
   * 
   * @return
   */
  function src() {
    global $lg_gallery;
    if ( ( '' == $this->image ) || !isset( $lg_gallery ) ) {
      return false;
    }  
    return  $lg_gallery->address . lg_nice_link( $this->folder->curdir . $this->image );
  }
  
  function alt() {
    return __( 'image ' ) . $this->image; 
  }
  
  function html_id() {
    return $this->form_name;
  }
  
  function uri( $widget = 'none' ) {
    global $lg_gallery;
    if ( ( '' == $this->image ) || !isset( $lg_gallery ) ) {
      return false;
    }
    return  $this->folder->uri( $widget ) . lg_nice_link( $this->image );     
  }
  
  /**
   * LazyestImage::loc()
   * 
   * @return string location of the image in the file system
   */
  function loc() {
    global $lg_gallery;
    if ( ( '' == $this->image ) || !isset( $lg_gallery ) ) {
      return false;
    }
    $loc =$lg_gallery->root . $this->folder->curdir . $this->image;
    return ( file_exists( $loc ) ) ? $loc : $loc;
  }
  
  function caption() {
    global $lg_gallery;
    $caption = ( '' != $this->caption ) ? $this->caption : str_replace( '_', ' ', $this->image );
    $caption =  ( 'TRUE' == $lg_gallery->get_option( 'enable_captions' ) ) ? $caption : $this->image; 
    return apply_filters( 'lazyest_image_caption', lg_html( $caption ) );
  }
  
  function title() {
    global $lg_gallery;
    $caption = ( '' != $this->caption ) ? $this->caption : str_replace( '_', ' ', $this->image );
    $caption =  ( 'TRUE' == $lg_gallery->get_option( 'enable_captions' ) ) ? $caption : $this->image; 
    $title =  htmlspecialchars( strip_tags( $caption ), ENT_QUOTES );    
    return apply_filters( 'lazyest_image_title', $title );
  }
  
  function form_name() {
    if ( '' == $this->image ) {
      return false;
    }
    return preg_replace( '/\"|\'|\.| |\s/', '_', $this->image );
  }
  
  function on_click( $widget='none' ) {
    global $lg_gallery;
    return array( 'href' => $lg_gallery->address . lg_nice_link( $this->folder->curdir . $this->image ) , 'class' => 'lg', 'rel' => 'lazyest', 'title' => $this->title(), 'id' => str_replace( ' ', '_', $this->image ) );  
  }
  
  function write_xml( $handle ) {
    if ( !isset( $handle ) ) {    
      return false;      
    }    
		fwrite( $handle, "\t<photo>\n" );
		fwrite( $handle, "\t\t<filename><![CDATA[" . $this->image . "]]></filename>\n" );
		fwrite( $handle, "\t\t<caption><![CDATA[" . utf8_encode( htmlentities( $this->caption ) ) . "]]></caption>\n" );    
		fwrite( $handle, "\t\t<description><![CDATA[" . utf8_encode( htmlentities( $this->description ) ) . "]]></description>\n" );
		fwrite( $handle, "\t\t<image>" . $this->id . "</image>\n" );
		fwrite( $handle, "\t\t<index>". $this->index . "</index>\n" );
		fwrite( $handle, "\t</photo>\n" );
  }
  
  /**
   * LazyestImage::resize()
   * 
   * @param int $width  Maximum Width to resize the image
   * @param int $height Maximum height to resize the image
   * @return
   */
  function resize( $width, $height ) {
    global $lg_gallery;
    if ( false === $this->loc() ) {
      return false;
    }
    $img_location = $this->loc();
    $path = pathinfo( $img_location );
    switch ( strtolower( $path['extension'] ) ) {
      case 'jpeg':
      case 'jpg':
        $img = imagecreatefromjpeg( $img_location );
        break;
      case 'gif':
        $img = imagecreatefromgif( $img_location );
        break;
      case 'png':
        $img = imagecreatefrompng( $img_location );
        break;
      default:
        break;
    }
    list( $o_width,  $o_height ) = getimagesize( $img_location );
    $xratio = $width / $o_width;
    $yratio = $height / $o_height;
  	if ( ( $xratio >= 1 )  && ( $yratio >= 1 ) ) { 
  	  $nwidth = $o_width;
  	  $nheight = $o_height;
  	} elseif ( ( $xratio * $o_height ) < $height ) {
  		$nheight = floor( $xratio * $o_height );
  		$nwidth = $width;
  	} else {
  		$nwidth = floor( $yratio * $o_width );
  		$nheight = $height;
  	}
  	$resized = imagecreatetruecolor( $nwidth, $nheight );  
    imagecopyresampled( $resized, $img, 0, 0, 0, 0, $nwidth, $nheight, $o_width, $o_height );
    unset( $img );
    $this->_resized = $resized;               
    return true; 
  }
  
  /**
   * LazyestImage::crop()
   * 
   * @param mixed $size Width and Height of the square cropped image
   * @return bool success or failure
   */
  function crop( $size ) {
    if ( false === $this->loc() ) {
      return false;
    }
    $img_location = $this->loc();
    $path = pathinfo( $img_location );
    switch ( strtolower( $path['extension'] ) ) {
      case 'jpeg':
      case 'jpg':
        $img = imagecreatefromjpeg( $img_location );
        break;
      case 'gif':
        $img = imagecreatefromgif( $img_location );
       break;
      case 'png':
        $img = imagecreatefrompng( $img_location );
        break;
    }
    
    list( $o_width,  $o_height ) = getimagesize( $img_location );
    $cropped = imagecreatetruecolor( $size, $size );
    if ( $o_width > $o_height )  { // landscape image
      $out_width = $out_height = $o_height;
      $out_left = round( ( $o_width - $o_height ) / 2 );
      $out_top = 0;
    } else {
      $out_top = round( ( $o_height - $o_width ) / 2 );
      $out_width = $out_height = $o_width;
      $out_left = 0;
    }  
    imagecopyresampled( $cropped, $img, 0, 0, $out_left, $out_top, $size, $size, $out_width, $out_height );
    unset( $img );
    $this->_resized = $cropped;  
    return true;  
  }
  
} // LazyestImage

class LazyestSlide extends LazyestImage {
  
  function LazyestSlide( $parent ) {
    $this->__construct( $parent );
  }
  
  function __construct( $parent ) {
    LazyestImage::__construct( $parent );    
  }  
  
  /**
   * LazyestSlide::src()
   * 
   * @return
   */
  function src() {
    global $lg_gallery;
    if ( ( false === $this->loc() ) || !isset( $lg_gallery )  ) {
      return false;
    } 
    $slidefile = $lg_gallery->root . $this->folder->curdir . $lg_gallery->get_option( 'slide_folder' ) . $this->image;
    if ( 'TRUE' == $lg_gallery->get_option( 'enable_slides_cache' ) ) {
      if ( file_exists( $slidefile ) ) {
        return  $lg_gallery->address . lg_nice_link( $this->folder->curdir . $lg_gallery->get_option( 'slide_folder' ) . $this->image );
      }
    }		   
  	return $lg_gallery->plugin_url . '/lazyest-img.php?file='. lg_nice_link( $this->folder->curdir . $this->image ) ;						
  }
      
  function html_id() {
    return 'lg_slide_' . LazyestImage::html_id();
  }
  
  function uri( $widget = 'none' ) {
    global $lg_gallery;
    if ( ( false === $this->loc() ) || !isset( $lg_gallery )  ) {
      return false;
    }
    return $this->folder->uri( $widget ) . lg_nice_link( $this->image );
  }
  
  /**
   * LazyestSlide::cache()
   * Creates a slide in the slides cache.
   * 
   * @return bool success or failure
   */
  function cache() {
    global $lg_gallery;
    if ( isset( $lg_gallery ) && ( $this->image != '' ) ) {
      if ( 'TRUE' == $lg_gallery->get_option( 'enable_slides_cache' ) ) {
        $slide_dir = $lg_gallery->root . $this->folder->curdir . $lg_gallery->get_option( 'slide_folder' );
		    if ( !file_exists( $slide_dir . $this->image ) ) {
		      if ( false === $this->resize( $lg_gallery->get_option( 'pictwidth' ), $lg_gallery->get_option( 'pictheight' ) ) ) {
		        return false;  
		      }
          if ( !file_exists( $slide_dir ) ) {
            $res = @mkdir( $slide_dir, 0777 );
            if ( !$res ) {
              return false;
            }
          }
          if ( is_writable( $slide_dir ) ) {
            $path = pathinfo( $this->image ); 
        		switch ( strtolower( $path['extension'] ) ) {
        	  	case 'jpeg':
        	  	case 'jpg':
        	    	imagejpeg( $this->_resized, $slide_dir . $this->image, $lg_gallery->get_option( 'resample_quality' ) );
        	    	break;
        	  	case 'gif':
        	    	imagegif( $this->_resized, $slide_dir . $this->image );
        	    	break;
        	  	case 'png':
        	    	imagepng( $this->_resized, $slide_dir . $this->image );
        	   	 break;
        		}
          }
          if ( file_exists( $slide_dir . $this->image ) ) {
            $stat = stat( dirname( $slide_dir ) );            
            $perms = $stat['mode'] & 0000777;
            @chmod( untrailingslashit( $slide_dir ) , $perms );
            $perms = $stat['mode'] & 0000666;
            @chmod( $slide_dir . $this->image, $perms );
            return true;
          } else {            
            return false;
          }  
        } else {
          return true;
        }
      }
    }
  }
  
  /**
   * LazyestSlide::on_click()
   * 
   * @return
   */
  function on_click( $widget = 'none' ) {
    global $lg_gallery;  
    $onclick = LazyestImage::on_click();
    $onclick['id'] = 'lg_thumb_onclick_' .  $onclick['id'];   
    $slide = new LazyestSlide( $this->folder );
    $slide->image = $this->image; 
    switch ( $lg_gallery->get_option( 'on_slide_click' ) ) {
      case 'nothing' : 
        $onclick['href'] = '#';
        break;
      case 'fullimg' :
        break;
      case 'lightbox' :
        $onclick['rel'] = 'lightbox[' . $this->folder->curdir . ']';        
        break;
      case 'thickbox' :
        $onclick['class'] = 'thickbox';
        $onclick['rel'] = $this->folder->curdir;
        break;
      case 'popup' :
        $onclick['href'] = "javascript:void(window.open('" . $lg_gallery->plugin_url . "/lazyest-popup.php?image=" . $this->image . "&amp;folder=" . lg_nice_link( $this->folder->curdir ) . "','','resizable=no,location=no,menubar=no,scrollbars=no,status=no,toolbar=no,fullscreen=no,dependent=yes,width=" . $lg_gallery->get_option( 'pictwidth' ) . ",height=" . $lg_gallery->get_option( 'pictheight' ) . ",left=100,top=100'))";
        break;
    }    
    unset( $slide );
    $onclick = apply_filters( 'lazyest_slide_onclick', $onclick );
    return $onclick;
  }
  
} // LazyestSlide

class LazyestThumb extends LazyestImage {
  
  function LazyestThumb( $parent ) {
    $this->__construct( $parent );
  }
  
  function __construct( $parent ) {
    LazyestImage::__construct( $parent );    
  }  
  
  /**
   * LazyestThumb::src()
   * 
   * @return
   */
  function src() {
    global $lg_gallery;
    if ( ( false === $this->loc() ) || !isset( $lg_gallery )  ) {
      return false;
    }  
    $thumbfile = $lg_gallery->root . $this->folder->curdir . $lg_gallery->get_option( 'thumb_folder' ) . $this->image;
    if ( 'TRUE' == $lg_gallery->get_option( 'enable_cache' ) ) {   
      if ( !file_exists( $thumbfile ) && ( 'TRUE' != $lg_gallery->get_option( 'async_cache' ) ) ) {
        $this->cache();
      }
      if ( file_exists( $thumbfile ) ) { 
        return  $lg_gallery->address . lg_nice_link( $this->folder->curdir . $lg_gallery->get_option( 'thumb_folder' ) . $this->image );
      } 
    }				
  	return $lg_gallery->plugin_url . '/lazyest-img.php?file='. lg_nice_link( $this->folder->curdir . $this->image ) . '&amp;thumb=1';						
  }
        
  function html_id() {
    return 'lg_thumb_' . LazyestImage::html_id();
  }
  
  function cache() {
    global $lg_gallery;
    if ( isset( $lg_gallery ) && ( $this->image != '' ) ) {
      if ( 'TRUE' == $lg_gallery->get_option( 'enable_cache' ) ) {
        $thumb_dir = $lg_gallery->root . $this->folder->curdir . $lg_gallery->get_option( 'thumb_folder' );
		    if ( !file_exists( $thumb_dir . $this->image ) ) {
		      if ( 'TRUE' == $lg_gallery->get_option( 'use_cropping' ) ) {
		        $size = ( $lg_gallery->get_option( 'thumbwidth' ) < $lg_gallery->get_option( 'thumbheight' )  ) ? $lg_gallery->get_option( 'thumbwidth' ) :  $lg_gallery->get_option( 'thumbheight' ); 
		        if ( false === $this->crop( $size ) ) {
		          return false;
		        }             
		      } else {
		        if  ( false === $this->resize( $lg_gallery->get_option( 'thumbwidth' ), $lg_gallery->get_option( 'thumbheight' ) ) ) {
		          return false;
		        }
          }
          if ( !file_exists( $thumb_dir ) ) {
            $res = @mkdir( $thumb_dir, 0777 );
            if ( !res ) {		                        
              return false;  
            }
          }
          if ( is_writable( $thumb_dir ) ) {
            $path = pathinfo( $this->image );
        		switch ( strtolower( $path['extension'] ) ) {
        	  	case 'jpeg':
        	  	case 'jpg':
        	    	imagejpeg( $this->_resized, $thumb_dir . $this->image, $lg_gallery->get_option( 'resample_quality' ) );
        	    	break;
        	  	case 'gif':
        	    	imagegif( $this->_resized, $thumb_dir . $this->image );
        	    	break;
        	  	case 'png':
        	    	imagepng( $this->_resized, $thumb_dir . $this->image );
        	   	 break;
        		}
          }
          if ( file_exists( $thumb_dir . $this->image ) ) {
            $stat = stat( dirname( $thumb_dir ) );
            $perms = $stat['mode'] & 0000777;
            @chmod( untrailingslashit( $thumb_dir ) , $perms );
            $perms = $stat['mode'] & 0000666;
            @chmod( $thumb_dir . $this->image, $perms );
            return true;
          } else {		          
            return false;
          }  
        } else {
          return true;
        }
      }
    }
  }
  
  /**
   * LazyestThumb::on_click()
   * 
   * @return
   */
  function on_click( $widget = 'none' ) {
    global $lg_gallery;  
    $onclick = LazyestImage::on_click( $widget );     
    $onclick['id'] = 'lg_thumb_onclick_' .  $onclick['id'];   
    $slide = new LazyestSlide( $this->folder );
    $slide->image = $this->image;  
    switch ( $lg_gallery->get_option( 'on_thumb_click' ) ) {
      case 'nothing' : 
        $onclick['href'] = '#';
        break;
      case 'fullimg' :
        break;
      case 'slide' : 
        $onclick['href'] = $slide->uri( $widget );
        break;
      case 'lightslide' :
        $onclick['href'] = $slide->src();
        $onclick['rel'] = 'lightbox[' . $this->folder->curdir . ']'; 
        break;
      case 'thickslide' : 
        $onclick['href'] = $slide->src(); 
        $onclick['class'] = 'thickbox';
        $onclick['rel'] = $this->folder->curdir;
      case 'lightbox' :
        $onclick['rel'] = 'lightbox[' . $this->folder->curdir . ']';        
        break;
      case 'thickbox' :
        $onclick['class'] = 'thickbox';
        $onclick['rel'] = $this->folder->curdir;
        break;
    }    
    unset( $slide );
    $onclick = apply_filters( 'lazyest_thumb_onclick', $onclick );
    return $onclick;
  }
  
} // LazyestThumb
?>