<?php
/*
Plugin Name: Lazyest Gallery
Plugin URI: http://brimosoft.nl/lazyest/
Description: Easy Gallery management plugin for Wordpress with automatic creation of thumbnails and slides, an integrated slideshow and commenting per image. 
Date: 2010, August
Author: Brimosoft
Author URI: http://brimosoft.nl 
Version: 0.16.7
License: GNU GPL
*/

/*
Copyright (C) 2004 Nicholas Bruun Jespersen
Copyright (C) 2005-2006 Valerio Chiodino
Copyright (C) 2008-2010 Marcel Brinkkemper
(For questions join discussion on http://brimosoft.nl/lazyest/ )
*/

/**
 * Main Lazyest Gallery Script
 * 
 * @package Lazyest-Gallery
 * @version 0.16
 * @author Marcel Brinkkemper (lazyest@brimosoft.nl)
 * @copyright 2004 Nicholas Bruun Jespersen
 * @copyright 2005-2006 Valerio Chiodino
 * @copyright 2008-2010 Marcel Brinkkemper 
 * @license GNU GPL
 * @link http://brimosoft.nl/lazyest/
 * 
 */

/**
 * LazyestGallery
 * Lazyest Gallery core class
 * 
 * @package Lazyest Gallery
 * @author Marcel Brinkkemper
 * @copyright 2010
 * @access public
 * @since 0.16.0
 */
 
class LazyestGallery {
  
  var $plugin_url;
  
  var $plugin_dir;
  
  var $plugin_file;
  
  var $plugin_basename;  
  
  var $text_domain;
  
  var $options;
  
  var $address;
  
  var $root;
  
  var $commentor;
  
  var $currentdir;
  
  var $file;
  
  function LazyestGallery() {    
    $this->__construct();
  }
  
  function __construct() { 
    global $wpdb;
    
    $this->file = $this->currentdir = '';
    
		$this->options = get_option ( 'lazyest-gallery' );
    
    $this->plugin_url = WP_PLUGIN_URL . '/' . plugin_basename( dirname( __file__ ) );
    $this->plugin_dir = WP_PLUGIN_DIR . '/' . plugin_basename( dirname( __file__ ) );    
		$this->plugin_file = dirname( dirname ( __FILE__ ) ) . '/lazyest-gallery.php';
		$this->plugin_basename = plugin_basename( $this->plugin_file );      
    $this->text_domain = "lazyest-gallery";  
    load_plugin_textdomain( $this->text_domain, $plugin_dir );

    $this->root = str_replace( "\\", "/", ABSPATH . $this->get_option( 'gallery_folder' ) );
    $this->address = trailingslashit( get_option( 'siteurl' ) ) . $this->get_option( 'gallery_folder' ); 
           
    register_activation_hook( $this->plugin_file , array ( &$this , 'init' ) );     
    add_action( 'init', array( &$this, 'add_capabilities'), 1 );
    add_action( 'init', array( &$this, 'set_gallery_prev') );
    
    $this->init();
    
    if ( 'TRUE' == $this->get_option( 'allow_comments' ) ) { 
      require_once ( $this->plugin_dir . '/inc/comments.php');
      $this->commentor = new LazyestCommentor();
    }    
  }
  
  /**
   * LazyestGallery::get_option()
   * 
   * @param string $option
   * @return mixed option value or false on fail
   */
  function get_option( $option ) {
		if ( isset ( $this->options[$option] ) )
			return $this->options[$option];
		else
			return false;
	}
  
  /**
   * LazyestGallery::change_option()
   * 
   * @param mixed $option
   * @param mixed $value
   * @return void
   */
  function change_option( $option, $value ) {
    $this->options[$option] = $value;
  }
  
  /**
   * LazyestGallery::update_option()
   * 
   * @param mixed $option
   * @param mixed $value
   * @return void
   */
  function update_option( $option, $value ) {
    $this->change_option( $option, $value );
    update_option( 'lazyest-gallery', $this->options );
  }
  
  /**
   * LazyestGallery::store_options()
   * 
   * @return void
   */
  function store_options() {    
    update_option( 'lazyest-gallery', $this->options );
  }
      
	/**
	 * LazyestGallery::defaults()
	 * 
	 * @return
	 */
	function defaults () {
	  global $wpdb;
    $results = get_pages();
    $page_ID = 0;
    if ( !empty( $results ) ) {
      foreach ($results as $page) {
        if ( ( $page->post_status == 'publish' ) && ($page->post_type == 'page' ) ) {
          $contect = $page->post_content;
          $pos = strpos($contect, '[lg_gallery]'); 
          if ( $pos === false ) {
            $page_ID = $page->ID;
          }
        }
      }
      $permalink = get_option( 'permalink_structure' );
      $gallery_temp_uri = ( strlen( $permalink ) != 0 ) ? get_option( 'siteurl' ) . '/' . get_page_uri( $page_ID ) . '/' : get_option( 'siteurl' ) . "?page_id=" . $page_ID;                        
    } else {
      $gallery_temp_uri = '';
    }

		$defaults = array (
      'new_install' => 'TRUE',
      'gallery_folder' => 'wp-content/lg-gallery/',
      'gallery_prev' => $gallery_temp_uri,
      'gallery_id' => $page_ID,
      'excluded_folders'=>array('cgi-bin', 'thumbs', 'slides', '_vti_cnf', '.svn'),
      'sort_alphabetically' => 'TRUE',
      'pictwidth' => 400,
      'pictheight' => 300,
      'thumbwidth' => 200,
      'thumbheight' => 150,
      'thumbs_page' => 16,
      'folders_page' => 0,
      'folders_columns'=> 4,
      'thumbs_columns'=> 3,
      'thumb_folder' => 'thumbs/',
      'slide_folder' => 'slides/',
      'folder_image' => 'none',
      'use_slides_popup' => 'FALSE',
      'disable_full_size' => 'FALSE',
      'enable_cache' => 'FALSE',
      'enable_slides_cache' => 'FALSE',
      'use_cropping' => 'FALSE',
      'resample_quality' => '85',
      'enable_captions' => 'TRUE',
      'use_folder_captions' => 'FALSE',
      'allow_comments' => 'FALSE',
      'enable_lb_sidebar_support' => 'FALSE',
      'enable_lb_posts_support' => 'FALSE',
      'enable_tb_sidebar_support' => 'FALSE',
      'enable_tb_posts_support' => 'FALSE',
      'enable_exif' => 'FALSE',           // other exif options removed as of 0.16.0
      'fileupload_allowedtypes' => 'jpg jpeg gif png',
      'manager_roles'=>array( 'administrator', 'editor' ), // - WordPress roles allowed to manage lazyest gallery
      'enable_mwp_support' => 'FALSE',
      'wizard_user' => 'test',
      'wizard_password' => 'secret',
      'image_indexing' => '0',
      'allow_comments' => 'FALSE',
      'link_to_gallery' => 'FALSE',
      'captions_length' => '-1',    
      'enable_slide_show' => 'TRUE',
      'allow_comments' => 'FALSE',
      'link_to_gallery' => 'FALSE',
      'enable_slide_show' => 'TRUE',
      'link_to_gallery' => 'FALSE',
      'gallery_secure' => '0.0.0',      
      'use_permalinks' => 'FALSE',        // since 0.16.0
      'on_thumb_click' => 'slide',        // since 0.16.0 - nothing, fullimg, slide, lightslide, thickslide, lightbox, thickbox
      'on_slide_click' => 'fullimg',      // since 0.16.0 - nothing, fullimg, lightbox, thickbox
      'count_subfolders' => 'none',       // since 0.16.0 - none, include, separate
      'random_subfolder' => 'FALSE',      // since 0.16.0 - random folder image from subfolder
      'style_css' => 'lazyest-style.css', // since 0.16.0 - stylesheet filename
      'listed_as' => 'photos',          // since 0.16.0 - display in thumbs view "10 photos"
      'show_credits' => 'FALSE'           // since 0.16.0 - show powered by Lazyest Gallery or not
      
    );
    return $defaults;
  }
  
 
  /**
   * LazyestGallery::init()
   * 
   * @return void
   */
  function init() {
		if ( !get_option( 'lazyest-gallery' ) ) {
			add_option( 'lazyest-gallery' , $this->defaults() );
    }        
    $this->check_upgrade();
	}
  
  function _build_folders_array( $root = '' ) {
    if ( $root == '' ) {
        $root = $this->root;
    }
    $folders = array();
    if ( $dir_handler = @opendir( $root ) ) {
      $forbidden = array();
      $forbidden = $this->get_option( 'excluded_folders' );
      array_push( $forbidden, '..' );
      array_push( $forbidden, '.' );
      array_push( $forbidden, 'captions.xml' );
      while ( $afile = readdir( $dir_handler ) ) {
        if ( !in_array($afile, $forbidden ) ) {
          if ( is_dir( $root . trailingslashit( $afile ) ) ) {
            $folders[] = $root . $afile;
              $folders = array_merge( $folders, $this->_build_folders_array( $root . trailingslashit( $afile ) ) );
          } else {
            continue;
          }
        }
      }
      return $folders;
    } 
  }
     
  function _move_option( $option ) {
    if ( ( $option == 'new_install' ) || ( $option == 'gallery_prev' ) ) return; // new_install is not in previous versions; gallery_prev is needed to set id at wordpress init
    $value = get_option( 'lg_' . $option );
    $this->change_option( $option, $value );
    delete_option( 'lg_' . $option );
  }   
     
  /**
   * LazyestGallery::check_upgrade()
   * 
   * @return void
   */
  function check_upgrade() {
    
    $gallery_secure = $this->get_option( 'gallery_secure' ); 

    if ( version_compare( $gallery_secure, LG_SECURE_VERSION, '<' ) ) { 
      $old_secure = get_option( 'lg_gallery_secure' );
      $old_install = get_option(  'lg_gallery_folder' );
      
      $newinstall = !$old_install && ( $gallery_secure == '0.0.0' );
      
      if ( ( $gallery_secure == '0.0.0' ) && $old_secure )  { //upgrading from a pre-0.15.0 version
        $gallery_secure = $old_secure;
      }
      
      if ( version_compare($gallery_secure, "0.10.4.4", '<' ) ) {
      
        $folders = $this->_build_folders_array();
        for ( $i = 0; $i < count( $folders ); $i++ ) {
            $folder = $folders[$i];
            $stat = stat( dirname( $folder ) );
            $fperms = $stat['mode'] & 0000666;
            $dperms = $stat['mode'] & 0000777;
            $captions_file = $folder . "/captions.xml";
            if ( file_exists( $captions_file ) ) {
                @chmod( $captions_file, $fperms );
            }
            $thumbs_dir = trailingslashit( $folder  ) . $this->get_option( 'thumb_folder' );
            if ( is_dir( $thumbs_dir ) ) {
                @chmod($thumbs_dir, $dperms);
            }
            $slides_dir = trailingslashit( $folder ) . $this->get_option('slide_folder');
            if ( is_dir( $slides_dir ) ) {
                @chmod( $slides_dir, $dperms );
            }
        }
      }
      
      if ( version_compare($gallery_secure, '0.15', '<' ) && $old_install ) {
        
        foreach( $this->options as $key => $value ) { 
          $this->_move_option( $key );          
        }        
        add_action( 'init', 'prev_to_id', 1 );
        delete_option( 'lg_gallery_uri' ); // delete obsolete options ( if any )
        delete_option( 'lg_buffer_size' );
        delete_option( 'lg_force_lb_support' );    
        delete_option( 'lg_force_tb_support' );
        delete_option( 'lg_fileupload_minlevel ' );
        $this->change_option( 'new_install', 'FALSE' );
      }       
      if ( version_compare( $gallery_secure, '0.16', '<') ) { 
        $this->update_option( 'use_permalinks', 'FALSE' );
        $this->update_option( 'style_css', 'lazyest-style.css' );        
        $this->update_option( 'listed_as', 'photos' ); 
        if ( 'TRUE' == $this->get_option( 'force_popup_plugin' ) ) {
          $this->update_option( 'on_thumb_click', 'fullimg' );
        } else {          
          $this->update_option( 'on_thumb_click', 'slide' );
        }
        if ( 'TRUE' == $this->get_option( 'enable_lb_thumbs_support' ) ) {
          $this->update_option( 'on_thumb_click', 'lightbox' ); 
        }
        if ( 'TRUE' == $this->get_option( 'enable_tb_thumbs_support' ) ) {
          $this->update_option( 'on_thumb_click', 'thickbox' ); 
        }       
        if ( 'TRUE' == $this->get_option( 'disable_full_size' ) ) {
          $this->update_option( 'on_slide_click', 'nothing' );
        } else {
          $this->update_option( 'on_slide_click', 'fullimg' );
        }
        if ( 'TRUE' == $this->get_option( 'use_slides_popup' ) ) {          
          $this->update_option( 'on_slide_click', 'popup' );
        }
        if ( 'TRUE' == $this->get_option( 'enable_lb_slides_support' ) ) {                    
          $this->update_option( 'on_slide_click', 'lightbox' );
        }
        if ( 'TRUE' == $this->get_option( 'enable_tb_slides_support' ) ) {                    
          $this->update_option( 'on_slide_click', 'thickbox' );
        }
      }       
      $this->update_option("gallery_secure", LG_SECURE_VERSION);
    }
  }
  
  /**
   * LazyestGallery::prev_to_html_id()
   * translates the gallery page URI to a page ID
   * this function is called only in the update from a pre-0.15.0 version
   * 
   * @return void
   */
  function prev_to_id() {
    $value =  get_option( 'lg_gallery_prev' );
    $ID = lg_get_page_id( $value );
    $this->update_option( 'gallery_id', $ID );
    delete_option( 'lg_gallery_prev' );
  }
  
  /**
   * LazyestGallery::get_page_id()
   * 
   * @param mixed $full_uri
   * @return
   */
  function get_page_id( $full_uri ) {  
  	$page_ID = '';
  	$permalink = get_option('permalink_structure');
  	if (strlen( $permalink ) != 0){
  		$site_url = get_option('siteurl');
  		if ( strpos( $permalink, 'index.php' ) > 0 ) {
  			$site_url .= '/index.php';
  		}
  		$page_path = rtrim( $full_uri, '?&amp;' );		
  		if ( strpos( $full_uri, '?') > 0 ) {
  			$page_path = substr( $full_uri, 0, strpos($full_uri, '?') );
  		}
  		$page_path = substr( $page_path, strlen( $site_url ) );
  		$page = get_page_by_path( $page_path );
  		$page_ID = $page->ID;
  	} else {
  		$has_get = strpos( $full_uri, '?' );
  		if ( !$has_get === false ) {		
  			$parts = explode( '?', $full_uri );
  			$gets = explode( '&', $parts[1] );		
  			foreach ( $gets as $get ) {
  				$is_page = substr( $get, 0, 7 ) == 'page_id';
  				if ( !$is_page === false ) {
  					$page_ID = substr( $get, 8 );
  				}
  			}
  		}
  			
  	}
  	return $page_ID;
  }
  
  /**
   * LazyestGallery::add_capabilities()
   * 
   * @return
   */
  function add_capabilities() {
    global $wp_roles;
    if ( is_null( $wp_roles ) )
        return;
    $roles = $this->get_option( 'manager_roles' );
    if ( $roles ) {
        foreach ( $roles as $role ) {
            $manager = $wp_roles->get_role( $role );
            $manager->add_cap( 'manage_lazyest_files' );
        }
    }
  }
  
  /**
   * LazyestGallery::set_gallery_prev()
   * 
   * @return void
   */
  function set_gallery_prev() {
    $apage = get_page( $this->get_option( 'gallery_id' ) );  
    $this->update_option( 'gallery_prev', get_page_link( $apage->ID  ) );      
    unset($apage);  
  }
  
  function is_gallery() {
    return false;
  }
  
    /**
   * LazyestGallery::uri()
   * 
   * @return
   */
  function uri( $widget = 'none') {
    if ( is_admin() ) {      
      return $this->get_option( 'gallery_prev' );
    }
    if ( ( 'TRUE' == $this->get_option( 'link_to_gallery' ) ) || $this->is_gallery() || ( 'widget' == $widget ) ) {
      return $this->get_option( 'gallery_prev' );
    }    
		$protocol = 'http' . ( ( isset( $_SERVER['HTTPS'] ) && ( 'on' == strtolower( $_SERVER['HTTPS'] ) ) ) ? 's' : '' ) . '://';
		$server = isset( $_SERVER['HTTP_HOST'] ) ? $_SERVER['HTTP_HOST'] : $_SERVER['SERVER_NAME'];
		$gallery_uri = $protocol . $server . $_SERVER['REQUEST_URI'];
		if ( 0 < count( $_GET ) ) {
			$gallery_uri = substr( $gallery_uri, 0, strpos( $gallery_uri, '?' ) +1 );				
			foreach( $_GET as $key => $value) {
				if ( ( $key != 'file' ) && ( $key != 'lg_show' ) && ( $key != 'lg_comment' ) && ( $key != 'offset' ) ) {
					$gallery_uri .= $key . '=' . $value . '&amp;';
				}
			}        
		}
    rtrim( $gallery_uri, '&amp;' ); 
    return $gallery_uri;    	  
  }
  
  /**
   * LazyestGallery::_compare_f()
   * 
   * @param mixed $f1
   * @param mixed $f2
   * @return
   */
  function _compare_f( $f1, $f2 ) {
    switch ( $this->get_option( 'sort_alphabetically' ) ) {
      case 'TRUE' : $id = 'curdir';
        break;
      case 'FALSE' : $id = 'datetime';
        break;
      case 'MANUAL' : $id = 'order';
        break;  
    }       
    if ( $f1->$id == $f2->$id ) {
      return 0;
    }    
    return ( $f1->$id < $f2->$id) ? -1 : 1; 
  }
  
  /**
   * LazyestGallery::_subfolders()
   * 
   * @param mixed $folders
   * @param mixed $folder
   * @param mixed $show
   * @return
   */
  function _subfolders( $folderlist, $folder, $show ) {
    $subfolders = $folder->subfolders();
    if ( 0 < count( $subfolders ) ) {
      foreach ( $subfolders as $subfolder ) {          
        if ( ( ( 'hidden' ==  $show ) && ( 'hidden' == $subfolder->visibility ) ) || ( 'visible' == $subfolder->visibility ) ) {
          $folderlist[] = $subfolder;
          $folderlist = $this->_subfolders( $folderlist, $subfolder, $show );
        }
      }
    }
    return $folderlist;
  }
  
  /**
   * LazyestGallery::folders()
   * returns an array containing LazyestFolder objects
   * 
   * @param string $sub: either 'root' (include only gallery root folders) or 'subfolders' (include all subfolders) 
   * @param string $show: either 'hidden' (include hidden folders) or 'visible' (include visible folders only)
   * @return
   */
  function folders( $sub = 'root', $show = 'hidden' ) {
            
    $list = array();    
		if ( $dir_content = @opendir( $this->root ) ) {
			while ( false != ( $subdir = readdir( $dir_content ) ) ) {
				if ( is_dir( $this->root . $subdir ) ) {
				  $folder = new LazyestFolder( $subdir );          
          if ( $folder->valid() ) {
            $folder->open();            
            if ( ( ( 'hidden' ==  $show ) && ( 'hidden' == $folder->visibility ) )|| ( 'visible' == $folder->visibility ) ) {
              $list[] = $folder;
            }
          }            
        }
			}          
		  @closedir( $dir_content );
    } 
    usort( $list, array( &$this, '_compare_f' ) );      
    foreach( $list as $folder ) {
      $folderlist[] = $folder;
      if ( 'subfolders' == $sub ) {
        $folderlist = $this->_subfolders( $folderlist, $folder, $show );
      }
    }     
    return $folderlist;
  }
  
  /**
   * LazyestGallery::random_image()
   * 
   * @param string $folder
   * @param string $sub
   * @param integer $count
   * @return
   */
  function random_image( $folder = '', $sub = 'subfolders', $count = 1 ) {
    if ( '' == $folder ) $sub = 'subfolders';
    $images_list = array();
    $counted = 0;
    if ( '' == $folder ) {
      $folderlist = $this->folders( 'subfolders', 'visible' );
      while ( ( $counted < $count ) && ( 0 < count( $folderlist ) ) ) {
        $folder_key = array_rand( $folderlist );
        $folder = $folderlist[$folder_key];
        $random_images = $folder->random_image( 'subfolders', $count - $counted );
        $counted += count( $random_images );
        if ( 0 < count( $random_images ) ) {
          foreach( $random_images as $image ) {
            $images_list[] = $image;
          }
        }
        unset( $folderlist[$folder_key] );
      } 
    } else {
      $ifolder = new LazyestFrontendFolder( $folder );
      if ( $ifolder->valid() ) {
        $images_list = $ifolder->random_image( $sub, $count );
      }
    } 
    return $images_list;
  } 
  
  /**
   * LazyestGallery::is_image()
   * 
   * @param string $filevar path of file relative to gallery root
   * @return bool
   */
  function is_image( $filevar ) { 
    if ( '' == $filevar ) {
      return false;
    }
  	$filevar = $filevar;
  	$afile = $this->root . $filevar;
    $abase = basename( $afile );
    return ( file_exists( $afile ) && !is_dir( $afile ) && ( 0 < preg_match( "/^.*\.(jpg|gif|png|jpeg)$/i", $afile ) ) && ( '.' != $abase[0] ) );
  }
  
  /**
   * LazyestGallery::is_folder()
   * 
   * @param mixed $filevar
   * @return
   */
  function is_folder( $filevar ) { 
    if ( '' == $filevar ) {
      return false;
    }
    $filevar = $filevar;
    $folder = new LazyestFolder( $filevar );
    $valid = $folder->valid();
    unset( $folder );
    return $valid;
  }
     
} // LazyestGallery class


$lg_plugin_dir = dirname ( __FILE__ );
 
require_once ( $lg_plugin_dir . '/inc/version.php' );   
require_once ( $lg_plugin_dir . '/inc/image.php' );    
require_once ( $lg_plugin_dir . '/inc/folder.php' ); 
require_once ( $lg_plugin_dir . '/inc/functions.php' );
require_once ( $lg_plugin_dir . '/inc/widgets.php' );  

global $lg_gallery;

if ( is_admin() ) {  
	require_once ( $lg_plugin_dir . '/inc/admin.php' );
  $lg_gallery = new LazyestAdmin(); 
} else {
  require_once ( $lg_plugin_dir . '/inc/frontend.php' );
  $lg_gallery = new LazyestFrontend();
}

?>