<?php
/**
 * Uninstalls the lazyest-galery options when an uninstall has been requested 
 * from the WordPress admin
 *
 * @package lazyest-gallery
 * @subpackage uninstall
 * @since 0.15.0
 */
 
$lg_gallery = get_option('lazyest-gallery');
$gallery_root = str_replace("\\", "/", ABSPATH . $lg_gallery['gallery_folder']);

function lgu_clear_directory($path) {
  if ( !file_exists($path) ) {
    return true; // don't attempt to remove a non-existant directory
  }  
	if($dir_handle = @opendir($path)) {
		while($file = readdir($dir_handle)) {
			if(is_dir($path.$file) && $file != "." && $file != ".."){				
				$filvar = substr( $path, strlen( $gallery_root ) );
				lgu_clear_directory($path.$file.'/');
				lgu_remove_directory($path.$file.'/');
			} else {
				if($file == "." || $file == "..") {
					continue;
				} else {
					unlink($path.$file);
				}
			}
		}
		closedir($dir_handle);
		return true;
	// all files deleted
	} else {
		return false;
	}
}

function lgu_remove_directory($path) {
  if ( !file_exists($path) ) {
    return true; // don't attempt to remove a non-existant directory
  }
	if(lgu_clear_directory($path)){
		if(rmdir($path)){
			return true;
		// directory removed
		} else {
			return false;
		// directory couldn't removed
		}
	} else {
		return false;
	// no empty directory
	}
}
 
function lgu_folders_array($root = '') {
    global $gallery_root, $lg_gallery;

    if ($root == '') {
        $root = $gallery_root;
    }
    $folders = array();
    // Open gallery root
    if ($dir_handler = opendir($root)) {

        $forbidden = array();
        $forbidden = $lg_gallery['excluded_folders'];
        array_push($forbidden, "..");
        array_push($forbidden, ".");
        array_push($forbidden, "captions.xml");
        while ($file = readdir($dir_handler)) {
            if (!in_array($file, $forbidden)) {
                // Do not remove the trailing slash (/)
                if (is_dir($root . $file . '/')) {
                    $folders[] = $root . $file;

                    $folders = array_merge($folders, lgu_build_folders_array($root . $file . '/'));
                } else {
                    continue;
                }
            }
        }
        return $folders;
    } 
}

function lgu_remove_captions() {
  global $gallery_root;
	$folders = lgu_folders_array();
  $captions = 'captions.xml'; 
  $success = true; 
	if (count($folders)!= 0) { 
	 	for ($i = 0; $i != count($folders); $i++) {
	 	  $path = $folders[$i];
      if ( file_exists( $path . $captions ) ) {
        if ( @unlink( $path . $captions ) == false )
          $success =  false;
      }
 	  }
  }  
  return $success;
}

// If uninstall/delete not called from WordPress then exit
if( ! defined ( 'ABSPATH' ) && ! defined ( 'WP_UNINSTALL_PLUGIN' ) )
	exit ();
global $wpdb;  
// Delete all thumbs and slides directories
$folders = lgu_folders_array("", true, true);
$thumbs = $lg_gallery['thumb_folder'];
$slides = $lg_gallery['slide_folder']; 
$success = true; 
if (count($folders)!= 0) { 
 	for ($i = 0; $i != count($folders); $i++) {
 	  $path = $folders[$i];
    if ( file_exists( $path . $thumbs ) ) {
      if ( lgu_remove_directory( $path . $thumbs) == false )
        $success =  false;
    }
  }      
  if ( (  'all' == $what ) || ( 'slides' == $what ) ) {
    if ( file_exists( $path . $slides) ) {
      if ( lgu_remove_directory( $path . $slides ) == false ) 
        $success = false;
    }
  }  	 	 
}

// Remove all captions.xml files
lgu_remove_captions();
// Delete lazyest-gallery option from options table and drop lazyest-gallery comments table
delete_option( 'lazyest-gallery' );
$lg_tb_comments = $wpdb->prefix . 'lg_comments2image';
if($wpdb->get_var("show tables like '$lg_tb_comments'") == $lg_tb_comments) {
  $wpdb->query("DROP TABLE $lg_tb_comments");
}

?>